Class: Google::Cloud::AIPlatform::V1::AutoraterConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/aiplatform/v1/evaluation_service.rb

Overview

The configs for autorater. This is applicable to both EvaluateInstances and EvaluateDataset.

Instance Attribute Summary collapse

Instance Attribute Details

#autorater_model::String

Returns Optional. The fully qualified name of the publisher model or tuned autorater endpoint to use.

Publisher model format: projects/{project}/locations/{location}/publishers/*/models/*

Tuned model endpoint format: projects/{project}/locations/{location}/endpoints/{endpoint}.

Returns:

  • (::String)

    Optional. The fully qualified name of the publisher model or tuned autorater endpoint to use.

    Publisher model format: projects/{project}/locations/{location}/publishers/*/models/*

    Tuned model endpoint format: projects/{project}/locations/{location}/endpoints/{endpoint}



280
281
282
283
# File 'proto_docs/google/cloud/aiplatform/v1/evaluation_service.rb', line 280

class AutoraterConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#flip_enabled::Boolean

Returns Optional. Default is true. Whether to flip the candidate and baseline responses. This is only applicable to the pairwise metric. If enabled, also provide PairwiseMetricSpec.candidate_response_field_name and PairwiseMetricSpec.baseline_response_field_name. When rendering PairwiseMetricSpec.metric_prompt_template, the candidate and baseline fields will be flipped for half of the samples to reduce bias.

Returns:

  • (::Boolean)

    Optional. Default is true. Whether to flip the candidate and baseline responses. This is only applicable to the pairwise metric. If enabled, also provide PairwiseMetricSpec.candidate_response_field_name and PairwiseMetricSpec.baseline_response_field_name. When rendering PairwiseMetricSpec.metric_prompt_template, the candidate and baseline fields will be flipped for half of the samples to reduce bias.



280
281
282
283
# File 'proto_docs/google/cloud/aiplatform/v1/evaluation_service.rb', line 280

class AutoraterConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#generation_config::Google::Cloud::AIPlatform::V1::GenerationConfig

Returns Optional. Configuration options for model generation and outputs.

Returns:



280
281
282
283
# File 'proto_docs/google/cloud/aiplatform/v1/evaluation_service.rb', line 280

class AutoraterConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#sampling_count::Integer

Returns Optional. Number of samples for each instance in the dataset. If not specified, the default is 4. Minimum value is 1, maximum value is 32.

Returns:

  • (::Integer)

    Optional. Number of samples for each instance in the dataset. If not specified, the default is 4. Minimum value is 1, maximum value is 32.



280
281
282
283
# File 'proto_docs/google/cloud/aiplatform/v1/evaluation_service.rb', line 280

class AutoraterConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end