Class: Google::Cloud::AIPlatform::V1::BatchPredictionJob::InputConfig
- Inherits:
-
Object
- Object
- Google::Cloud::AIPlatform::V1::BatchPredictionJob::InputConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/aiplatform/v1/batch_prediction_job.rb
Overview
Configures the input to BatchPredictionJob. See Model.supported_input_storage_formats for Model's supported input formats, and how instances should be expressed via any of them.
Instance Attribute Summary collapse
-
#bigquery_source ⇒ ::Google::Cloud::AIPlatform::V1::BigQuerySource
The BigQuery location of the input table.
-
#gcs_source ⇒ ::Google::Cloud::AIPlatform::V1::GcsSource
The Cloud Storage location for the input instances.
-
#instances_format ⇒ ::String
Required.
-
#vertex_multimodal_dataset_source ⇒ ::Google::Cloud::AIPlatform::V1::VertexMultimodalDatasetSource
A Vertex Managed Dataset.
Instance Attribute Details
#bigquery_source ⇒ ::Google::Cloud::AIPlatform::V1::BigQuerySource
Returns The BigQuery location of the input table. The schema of the table should be in the format described by the given context OpenAPI Schema, if one is provided. The table may contain additional columns that are not described by the schema, and they will be ignored.
Note: The following fields are mutually exclusive: bigquery_source, gcs_source, vertex_multimodal_dataset_source. If a field in that set is populated, all other fields in the set will automatically be cleared.
258 259 260 261 |
# File 'proto_docs/google/cloud/aiplatform/v1/batch_prediction_job.rb', line 258 class InputConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#gcs_source ⇒ ::Google::Cloud::AIPlatform::V1::GcsSource
Returns The Cloud Storage location for the input instances.
Note: The following fields are mutually exclusive: gcs_source, bigquery_source, vertex_multimodal_dataset_source. If a field in that set is populated, all other fields in the set will automatically be cleared.
258 259 260 261 |
# File 'proto_docs/google/cloud/aiplatform/v1/batch_prediction_job.rb', line 258 class InputConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#instances_format ⇒ ::String
Returns Required. The format in which instances are given, must be one of the [Model's][google.cloud.aiplatform.v1.BatchPredictionJob.model] supported_input_storage_formats.
258 259 260 261 |
# File 'proto_docs/google/cloud/aiplatform/v1/batch_prediction_job.rb', line 258 class InputConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#vertex_multimodal_dataset_source ⇒ ::Google::Cloud::AIPlatform::V1::VertexMultimodalDatasetSource
Returns A Vertex Managed Dataset. Currently, only datasets of type Multimodal are supported.
Note: The following fields are mutually exclusive: vertex_multimodal_dataset_source, gcs_source, bigquery_source. If a field in that set is populated, all other fields in the set will automatically be cleared.
258 259 260 261 |
# File 'proto_docs/google/cloud/aiplatform/v1/batch_prediction_job.rb', line 258 class InputConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |