Class: Google::Cloud::AIPlatform::V1::CancelAsyncQueryReasoningEngineRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/aiplatform/v1/reasoning_engine_execution_service.rb

Overview

Instance Attribute Summary collapse

Instance Attribute Details

#name::String

Returns Required. The name of the ReasoningEngine resource to use. Format: projects/{project}/locations/{location}/reasoningEngines/{reasoning_engine}.

Returns:

  • (::String)

    Required. The name of the ReasoningEngine resource to use. Format: projects/{project}/locations/{location}/reasoningEngines/{reasoning_engine}



122
123
124
125
# File 'proto_docs/google/cloud/aiplatform/v1/reasoning_engine_execution_service.rb', line 122

class CancelAsyncQueryReasoningEngineRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#operation_name::String

Returns Required. The name of the longrunning operation returned from AsyncQueryReasoningEngine. Format: projects/{project}/locations/{location}/operations/{operation}.

Returns:

  • (::String)

    Required. The name of the longrunning operation returned from AsyncQueryReasoningEngine. Format: projects/{project}/locations/{location}/operations/{operation}



122
123
124
125
# File 'proto_docs/google/cloud/aiplatform/v1/reasoning_engine_execution_service.rb', line 122

class CancelAsyncQueryReasoningEngineRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end