Class: Google::Cloud::AIPlatform::V1::EvaluateDatasetRun
- Inherits:
-
Object
- Object
- Google::Cloud::AIPlatform::V1::EvaluateDatasetRun
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/aiplatform/v1/tuning_job.rb
Overview
Evaluate Dataset Run Result for Tuning Job.
Instance Attribute Summary collapse
-
#checkpoint_id ⇒ ::String
readonly
Output only.
-
#error ⇒ ::Google::Rpc::Status
readonly
Output only.
-
#evaluate_dataset_response ⇒ ::Google::Cloud::AIPlatform::V1::EvaluateDatasetResponse
readonly
Output only.
-
#evaluation_run ⇒ ::String
readonly
Output only.
-
#operation_name ⇒ ::String
readonly
deprecated
Deprecated.
This field is deprecated and may be removed in the next major version update.
Instance Attribute Details
#checkpoint_id ⇒ ::String (readonly)
Returns Output only. The checkpoint id used in the evaluation run. Only populated when evaluating checkpoints.
400 401 402 403 |
# File 'proto_docs/google/cloud/aiplatform/v1/tuning_job.rb', line 400 class EvaluateDatasetRun include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#error ⇒ ::Google::Rpc::Status (readonly)
Returns Output only. The error of the evaluation run if any.
400 401 402 403 |
# File 'proto_docs/google/cloud/aiplatform/v1/tuning_job.rb', line 400 class EvaluateDatasetRun include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#evaluate_dataset_response ⇒ ::Google::Cloud::AIPlatform::V1::EvaluateDatasetResponse (readonly)
Returns Output only. Results for EvaluationService.
400 401 402 403 |
# File 'proto_docs/google/cloud/aiplatform/v1/tuning_job.rb', line 400 class EvaluateDatasetRun include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#evaluation_run ⇒ ::String (readonly)
Returns Output only. The resource name of the evaluation run. Format:
projects/{project}/locations/{location}/evaluationRuns/{evaluation_run_id}.
400 401 402 403 |
# File 'proto_docs/google/cloud/aiplatform/v1/tuning_job.rb', line 400 class EvaluateDatasetRun include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#operation_name ⇒ ::String (readonly)
Deprecated.
This field is deprecated and may be removed in the next major version update.
Returns Output only. Deprecated: The updated architecture uses evaluation_run instead.
400 401 402 403 |
# File 'proto_docs/google/cloud/aiplatform/v1/tuning_job.rb', line 400 class EvaluateDatasetRun include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |