Class: Google::Cloud::AIPlatform::V1::EventActions

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/aiplatform/v1/session.rb

Overview

Actions are parts of events that are executed by the agent.

Defined Under Namespace

Classes: ArtifactDeltaEntry

Instance Attribute Summary collapse

Instance Attribute Details

#artifact_delta::Google::Protobuf::Map{::String => ::Integer}

Returns Optional. Indicates that the event is updating an artifact. key is the filename, value is the version.

Returns:

  • (::Google::Protobuf::Map{::String => ::Integer})

    Optional. Indicates that the event is updating an artifact. key is the filename, value is the version.



187
188
189
190
191
192
193
194
195
196
197
198
199
# File 'proto_docs/google/cloud/aiplatform/v1/session.rb', line 187

class EventActions
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Integer]
  class ArtifactDeltaEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#escalate::Boolean

Returns Optional. The agent is escalating to a higher level agent.

Returns:

  • (::Boolean)

    Optional. The agent is escalating to a higher level agent.



187
188
189
190
191
192
193
194
195
196
197
198
199
# File 'proto_docs/google/cloud/aiplatform/v1/session.rb', line 187

class EventActions
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Integer]
  class ArtifactDeltaEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#requested_auth_configs::Google::Protobuf::Struct

Returns Optional. Will only be set by a tool response indicating tool request euc. Struct key is the function call id since one function call response (from model) could correspond to multiple function calls. Struct value is the required auth config, which can be another struct.

Returns:

  • (::Google::Protobuf::Struct)

    Optional. Will only be set by a tool response indicating tool request euc. Struct key is the function call id since one function call response (from model) could correspond to multiple function calls. Struct value is the required auth config, which can be another struct.



187
188
189
190
191
192
193
194
195
196
197
198
199
# File 'proto_docs/google/cloud/aiplatform/v1/session.rb', line 187

class EventActions
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Integer]
  class ArtifactDeltaEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#skip_summarization::Boolean

Returns Optional. If true, it won't call model to summarize function response. Only used for function_response event.

Returns:

  • (::Boolean)

    Optional. If true, it won't call model to summarize function response. Only used for function_response event.



187
188
189
190
191
192
193
194
195
196
197
198
199
# File 'proto_docs/google/cloud/aiplatform/v1/session.rb', line 187

class EventActions
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Integer]
  class ArtifactDeltaEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#state_delta::Google::Protobuf::Struct

Returns Optional. Indicates that the event is updating the state with the given delta.

Returns:



187
188
189
190
191
192
193
194
195
196
197
198
199
# File 'proto_docs/google/cloud/aiplatform/v1/session.rb', line 187

class EventActions
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Integer]
  class ArtifactDeltaEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#transfer_agent::String

Returns Optional. If set, the event transfers to the specified agent.

Returns:

  • (::String)

    Optional. If set, the event transfers to the specified agent.



187
188
189
190
191
192
193
194
195
196
197
198
199
# File 'proto_docs/google/cloud/aiplatform/v1/session.rb', line 187

class EventActions
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::Integer]
  class ArtifactDeltaEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end