Class: Google::Cloud::AIPlatform::V1::FunctionCall
- Inherits:
-
Object
- Object
- Google::Cloud::AIPlatform::V1::FunctionCall
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/aiplatform/v1/tool.rb
Overview
A predicted [FunctionCall] returned from the model that contains a string representing the [FunctionDeclaration.name] and a structured JSON object containing the parameters and their values.
Instance Attribute Summary collapse
-
#args ⇒ ::Google::Protobuf::Struct
Optional.
-
#name ⇒ ::String
Optional.
-
#partial_args ⇒ ::Array<::Google::Cloud::AIPlatform::V1::PartialArg>
Optional.
-
#will_continue ⇒ ::Boolean
Optional.
Instance Attribute Details
#args ⇒ ::Google::Protobuf::Struct
Returns Optional. The function parameters and values in JSON object format. See [FunctionDeclaration.parameters] for parameter details.
254 255 256 257 |
# File 'proto_docs/google/cloud/aiplatform/v1/tool.rb', line 254 class FunctionCall include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#name ⇒ ::String
Returns Optional. The name of the function to call. Matches [FunctionDeclaration.name].
254 255 256 257 |
# File 'proto_docs/google/cloud/aiplatform/v1/tool.rb', line 254 class FunctionCall include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#partial_args ⇒ ::Array<::Google::Cloud::AIPlatform::V1::PartialArg>
Returns Optional. The partial argument value of the function call. If provided, represents the arguments/fields that are streamed incrementally.
254 255 256 257 |
# File 'proto_docs/google/cloud/aiplatform/v1/tool.rb', line 254 class FunctionCall include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#will_continue ⇒ ::Boolean
Returns Optional. Whether this is the last part of the FunctionCall. If true, another partial message for the current FunctionCall is expected to follow.
254 255 256 257 |
# File 'proto_docs/google/cloud/aiplatform/v1/tool.rb', line 254 class FunctionCall include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |