Class: Google::Cloud::AIPlatform::V1::GenerateContentResponse::UsageMetadata

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/aiplatform/v1/prediction_service.rb

Overview

Usage metadata about response(s).

Defined Under Namespace

Modules: TrafficType

Instance Attribute Summary collapse

Instance Attribute Details

#cache_tokens_details::Array<::Google::Cloud::AIPlatform::V1::ModalityTokenCount> (readonly)

Returns Output only. List of modalities of the cached content in the request input.

Returns:



674
675
676
677
678
679
680
681
682
683
684
685
686
687
688
689
690
691
692
693
694
695
696
# File 'proto_docs/google/cloud/aiplatform/v1/prediction_service.rb', line 674

class UsageMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of traffic that this request was processed with, indicating
  # which quota is consumed.
  module TrafficType
    # Unspecified request traffic type.
    TRAFFIC_TYPE_UNSPECIFIED = 0

    # The request was processed using Pay-As-You-Go quota.
    ON_DEMAND = 1

    # Type for Priority Pay-As-You-Go traffic.
    ON_DEMAND_PRIORITY = 3

    # Type for Flex traffic.
    ON_DEMAND_FLEX = 4

    # Type for Provisioned Throughput traffic.
    PROVISIONED_THROUGHPUT = 2
  end
end

#cached_content_token_count::Integer (readonly)

Returns Output only. Number of tokens in the cached part in the input (the cached content).

Returns:

  • (::Integer)

    Output only. Number of tokens in the cached part in the input (the cached content).



674
675
676
677
678
679
680
681
682
683
684
685
686
687
688
689
690
691
692
693
694
695
696
# File 'proto_docs/google/cloud/aiplatform/v1/prediction_service.rb', line 674

class UsageMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of traffic that this request was processed with, indicating
  # which quota is consumed.
  module TrafficType
    # Unspecified request traffic type.
    TRAFFIC_TYPE_UNSPECIFIED = 0

    # The request was processed using Pay-As-You-Go quota.
    ON_DEMAND = 1

    # Type for Priority Pay-As-You-Go traffic.
    ON_DEMAND_PRIORITY = 3

    # Type for Flex traffic.
    ON_DEMAND_FLEX = 4

    # Type for Provisioned Throughput traffic.
    PROVISIONED_THROUGHPUT = 2
  end
end

#candidates_token_count::Integer

Returns Number of tokens in the response(s).

Returns:

  • (::Integer)

    Number of tokens in the response(s).



674
675
676
677
678
679
680
681
682
683
684
685
686
687
688
689
690
691
692
693
694
695
696
# File 'proto_docs/google/cloud/aiplatform/v1/prediction_service.rb', line 674

class UsageMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of traffic that this request was processed with, indicating
  # which quota is consumed.
  module TrafficType
    # Unspecified request traffic type.
    TRAFFIC_TYPE_UNSPECIFIED = 0

    # The request was processed using Pay-As-You-Go quota.
    ON_DEMAND = 1

    # Type for Priority Pay-As-You-Go traffic.
    ON_DEMAND_PRIORITY = 3

    # Type for Flex traffic.
    ON_DEMAND_FLEX = 4

    # Type for Provisioned Throughput traffic.
    PROVISIONED_THROUGHPUT = 2
  end
end

#candidates_tokens_details::Array<::Google::Cloud::AIPlatform::V1::ModalityTokenCount> (readonly)

Returns Output only. List of modalities that were returned in the response.

Returns:



674
675
676
677
678
679
680
681
682
683
684
685
686
687
688
689
690
691
692
693
694
695
696
# File 'proto_docs/google/cloud/aiplatform/v1/prediction_service.rb', line 674

class UsageMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of traffic that this request was processed with, indicating
  # which quota is consumed.
  module TrafficType
    # Unspecified request traffic type.
    TRAFFIC_TYPE_UNSPECIFIED = 0

    # The request was processed using Pay-As-You-Go quota.
    ON_DEMAND = 1

    # Type for Priority Pay-As-You-Go traffic.
    ON_DEMAND_PRIORITY = 3

    # Type for Flex traffic.
    ON_DEMAND_FLEX = 4

    # Type for Provisioned Throughput traffic.
    PROVISIONED_THROUGHPUT = 2
  end
end

#prompt_token_count::Integer

Returns Number of tokens in the request. When cached_content is set, this is still the total effective prompt size meaning this includes the number of tokens in the cached content.

Returns:

  • (::Integer)

    Number of tokens in the request. When cached_content is set, this is still the total effective prompt size meaning this includes the number of tokens in the cached content.



674
675
676
677
678
679
680
681
682
683
684
685
686
687
688
689
690
691
692
693
694
695
696
# File 'proto_docs/google/cloud/aiplatform/v1/prediction_service.rb', line 674

class UsageMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of traffic that this request was processed with, indicating
  # which quota is consumed.
  module TrafficType
    # Unspecified request traffic type.
    TRAFFIC_TYPE_UNSPECIFIED = 0

    # The request was processed using Pay-As-You-Go quota.
    ON_DEMAND = 1

    # Type for Priority Pay-As-You-Go traffic.
    ON_DEMAND_PRIORITY = 3

    # Type for Flex traffic.
    ON_DEMAND_FLEX = 4

    # Type for Provisioned Throughput traffic.
    PROVISIONED_THROUGHPUT = 2
  end
end

#prompt_tokens_details::Array<::Google::Cloud::AIPlatform::V1::ModalityTokenCount> (readonly)

Returns Output only. List of modalities that were processed in the request input.

Returns:



674
675
676
677
678
679
680
681
682
683
684
685
686
687
688
689
690
691
692
693
694
695
696
# File 'proto_docs/google/cloud/aiplatform/v1/prediction_service.rb', line 674

class UsageMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of traffic that this request was processed with, indicating
  # which quota is consumed.
  module TrafficType
    # Unspecified request traffic type.
    TRAFFIC_TYPE_UNSPECIFIED = 0

    # The request was processed using Pay-As-You-Go quota.
    ON_DEMAND = 1

    # Type for Priority Pay-As-You-Go traffic.
    ON_DEMAND_PRIORITY = 3

    # Type for Flex traffic.
    ON_DEMAND_FLEX = 4

    # Type for Provisioned Throughput traffic.
    PROVISIONED_THROUGHPUT = 2
  end
end

#thoughts_token_count::Integer (readonly)

Returns Output only. Number of tokens present in thoughts output.

Returns:

  • (::Integer)

    Output only. Number of tokens present in thoughts output.



674
675
676
677
678
679
680
681
682
683
684
685
686
687
688
689
690
691
692
693
694
695
696
# File 'proto_docs/google/cloud/aiplatform/v1/prediction_service.rb', line 674

class UsageMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of traffic that this request was processed with, indicating
  # which quota is consumed.
  module TrafficType
    # Unspecified request traffic type.
    TRAFFIC_TYPE_UNSPECIFIED = 0

    # The request was processed using Pay-As-You-Go quota.
    ON_DEMAND = 1

    # Type for Priority Pay-As-You-Go traffic.
    ON_DEMAND_PRIORITY = 3

    # Type for Flex traffic.
    ON_DEMAND_FLEX = 4

    # Type for Provisioned Throughput traffic.
    PROVISIONED_THROUGHPUT = 2
  end
end

#tool_use_prompt_tokens_details::Array<::Google::Cloud::AIPlatform::V1::ModalityTokenCount> (readonly)

Returns Output only. A detailed breakdown by modality of the token counts from the results of tool executions, which are provided back to the model as input.

Returns:



674
675
676
677
678
679
680
681
682
683
684
685
686
687
688
689
690
691
692
693
694
695
696
# File 'proto_docs/google/cloud/aiplatform/v1/prediction_service.rb', line 674

class UsageMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of traffic that this request was processed with, indicating
  # which quota is consumed.
  module TrafficType
    # Unspecified request traffic type.
    TRAFFIC_TYPE_UNSPECIFIED = 0

    # The request was processed using Pay-As-You-Go quota.
    ON_DEMAND = 1

    # Type for Priority Pay-As-You-Go traffic.
    ON_DEMAND_PRIORITY = 3

    # Type for Flex traffic.
    ON_DEMAND_FLEX = 4

    # Type for Provisioned Throughput traffic.
    PROVISIONED_THROUGHPUT = 2
  end
end

#total_token_count::Integer

Returns Total token count for prompt and response candidates.

Returns:

  • (::Integer)

    Total token count for prompt and response candidates.



674
675
676
677
678
679
680
681
682
683
684
685
686
687
688
689
690
691
692
693
694
695
696
# File 'proto_docs/google/cloud/aiplatform/v1/prediction_service.rb', line 674

class UsageMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of traffic that this request was processed with, indicating
  # which quota is consumed.
  module TrafficType
    # Unspecified request traffic type.
    TRAFFIC_TYPE_UNSPECIFIED = 0

    # The request was processed using Pay-As-You-Go quota.
    ON_DEMAND = 1

    # Type for Priority Pay-As-You-Go traffic.
    ON_DEMAND_PRIORITY = 3

    # Type for Flex traffic.
    ON_DEMAND_FLEX = 4

    # Type for Provisioned Throughput traffic.
    PROVISIONED_THROUGHPUT = 2
  end
end

#traffic_type::Google::Cloud::AIPlatform::V1::GenerateContentResponse::UsageMetadata::TrafficType (readonly)

Returns Output only. The traffic type for this request.

Returns:



674
675
676
677
678
679
680
681
682
683
684
685
686
687
688
689
690
691
692
693
694
695
696
# File 'proto_docs/google/cloud/aiplatform/v1/prediction_service.rb', line 674

class UsageMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The type of traffic that this request was processed with, indicating
  # which quota is consumed.
  module TrafficType
    # Unspecified request traffic type.
    TRAFFIC_TYPE_UNSPECIFIED = 0

    # The request was processed using Pay-As-You-Go quota.
    ON_DEMAND = 1

    # Type for Priority Pay-As-You-Go traffic.
    ON_DEMAND_PRIORITY = 3

    # Type for Flex traffic.
    ON_DEMAND_FLEX = 4

    # Type for Provisioned Throughput traffic.
    PROVISIONED_THROUGHPUT = 2
  end
end