Class: Google::Cloud::AIPlatform::V1::GroundingMetadata

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/aiplatform/v1/content.rb

Overview

Metadata returned to client when grounding is enabled.

Defined Under Namespace

Classes: SourceFlaggingUri

Instance Attribute Summary collapse

Instance Attribute Details

#google_maps_widget_context_token::String (readonly)

Returns Optional. Output only. Resource name of the Google Maps widget context token to be used with the PlacesContextElement widget to render contextual data. This is populated only for Google Maps grounding.

Returns:

  • (::String)

    Optional. Output only. Resource name of the Google Maps widget context token to be used with the PlacesContextElement widget to render contextual data. This is populated only for Google Maps grounding.



1030
1031
1032
1033
1034
1035
1036
1037
1038
1039
1040
1041
1042
1043
1044
1045
1046
1047
1048
1049
# File 'proto_docs/google/cloud/aiplatform/v1/content.rb', line 1030

class GroundingMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Source content flagging uri for a place or review. This is currently
  # populated only for Google Maps grounding.
  # @!attribute [rw] source_id
  #   @return [::String]
  #     Id of the place or review.
  # @!attribute [rw] flag_content_uri
  #   @return [::String]
  #     A link where users can flag a problem with the source (place or review).
  #     (-- The link is generated by Google and it does not contain
  #     information from the user query. It may contain information of the
  #     content it is flagging, which can be used to identify places. --)
  class SourceFlaggingUri
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#grounding_chunks::Array<::Google::Cloud::AIPlatform::V1::GroundingChunk>

Returns List of supporting references retrieved from specified grounding source.

Returns:



1030
1031
1032
1033
1034
1035
1036
1037
1038
1039
1040
1041
1042
1043
1044
1045
1046
1047
1048
1049
# File 'proto_docs/google/cloud/aiplatform/v1/content.rb', line 1030

class GroundingMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Source content flagging uri for a place or review. This is currently
  # populated only for Google Maps grounding.
  # @!attribute [rw] source_id
  #   @return [::String]
  #     Id of the place or review.
  # @!attribute [rw] flag_content_uri
  #   @return [::String]
  #     A link where users can flag a problem with the source (place or review).
  #     (-- The link is generated by Google and it does not contain
  #     information from the user query. It may contain information of the
  #     content it is flagging, which can be used to identify places. --)
  class SourceFlaggingUri
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#grounding_supports::Array<::Google::Cloud::AIPlatform::V1::GroundingSupport>

Returns Optional. List of grounding support.

Returns:



1030
1031
1032
1033
1034
1035
1036
1037
1038
1039
1040
1041
1042
1043
1044
1045
1046
1047
1048
1049
# File 'proto_docs/google/cloud/aiplatform/v1/content.rb', line 1030

class GroundingMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Source content flagging uri for a place or review. This is currently
  # populated only for Google Maps grounding.
  # @!attribute [rw] source_id
  #   @return [::String]
  #     Id of the place or review.
  # @!attribute [rw] flag_content_uri
  #   @return [::String]
  #     A link where users can flag a problem with the source (place or review).
  #     (-- The link is generated by Google and it does not contain
  #     information from the user query. It may contain information of the
  #     content it is flagging, which can be used to identify places. --)
  class SourceFlaggingUri
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#retrieval_metadata::Google::Cloud::AIPlatform::V1::RetrievalMetadata (readonly)

Returns Optional. Output only. Retrieval metadata.

Returns:



1030
1031
1032
1033
1034
1035
1036
1037
1038
1039
1040
1041
1042
1043
1044
1045
1046
1047
1048
1049
# File 'proto_docs/google/cloud/aiplatform/v1/content.rb', line 1030

class GroundingMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Source content flagging uri for a place or review. This is currently
  # populated only for Google Maps grounding.
  # @!attribute [rw] source_id
  #   @return [::String]
  #     Id of the place or review.
  # @!attribute [rw] flag_content_uri
  #   @return [::String]
  #     A link where users can flag a problem with the source (place or review).
  #     (-- The link is generated by Google and it does not contain
  #     information from the user query. It may contain information of the
  #     content it is flagging, which can be used to identify places. --)
  class SourceFlaggingUri
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#search_entry_point::Google::Cloud::AIPlatform::V1::SearchEntryPoint

Returns Optional. Google search entry for the following-up web searches.

Returns:



1030
1031
1032
1033
1034
1035
1036
1037
1038
1039
1040
1041
1042
1043
1044
1045
1046
1047
1048
1049
# File 'proto_docs/google/cloud/aiplatform/v1/content.rb', line 1030

class GroundingMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Source content flagging uri for a place or review. This is currently
  # populated only for Google Maps grounding.
  # @!attribute [rw] source_id
  #   @return [::String]
  #     Id of the place or review.
  # @!attribute [rw] flag_content_uri
  #   @return [::String]
  #     A link where users can flag a problem with the source (place or review).
  #     (-- The link is generated by Google and it does not contain
  #     information from the user query. It may contain information of the
  #     content it is flagging, which can be used to identify places. --)
  class SourceFlaggingUri
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#source_flagging_uris::Array<::Google::Cloud::AIPlatform::V1::GroundingMetadata::SourceFlaggingUri>

Returns List of source flagging uris. This is currently populated only for Google Maps grounding.

Returns:



1030
1031
1032
1033
1034
1035
1036
1037
1038
1039
1040
1041
1042
1043
1044
1045
1046
1047
1048
1049
# File 'proto_docs/google/cloud/aiplatform/v1/content.rb', line 1030

class GroundingMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Source content flagging uri for a place or review. This is currently
  # populated only for Google Maps grounding.
  # @!attribute [rw] source_id
  #   @return [::String]
  #     Id of the place or review.
  # @!attribute [rw] flag_content_uri
  #   @return [::String]
  #     A link where users can flag a problem with the source (place or review).
  #     (-- The link is generated by Google and it does not contain
  #     information from the user query. It may contain information of the
  #     content it is flagging, which can be used to identify places. --)
  class SourceFlaggingUri
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#web_search_queries::Array<::String>

Returns Optional. Web search queries for the following-up web search.

Returns:

  • (::Array<::String>)

    Optional. Web search queries for the following-up web search.



1030
1031
1032
1033
1034
1035
1036
1037
1038
1039
1040
1041
1042
1043
1044
1045
1046
1047
1048
1049
# File 'proto_docs/google/cloud/aiplatform/v1/content.rb', line 1030

class GroundingMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Source content flagging uri for a place or review. This is currently
  # populated only for Google Maps grounding.
  # @!attribute [rw] source_id
  #   @return [::String]
  #     Id of the place or review.
  # @!attribute [rw] flag_content_uri
  #   @return [::String]
  #     A link where users can flag a problem with the source (place or review).
  #     (-- The link is generated by Google and it does not contain
  #     information from the user query. It may contain information of the
  #     content it is flagging, which can be used to identify places. --)
  class SourceFlaggingUri
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end