Class: Google::Cloud::AIPlatform::V1::ImageConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/aiplatform/v1/content.rb

Overview

Config for image generation features.

Defined Under Namespace

Modules: PersonGeneration Classes: ImageOutputOptions

Instance Attribute Summary collapse

Instance Attribute Details

#aspect_ratio::String

Returns Optional. The desired aspect ratio for the generated images. The following aspect ratios are supported:

"1:1" "2:3", "3:2" "3:4", "4:3" "4:5", "5:4" "9:16", "16:9" "21:9".

Returns:

  • (::String)

    Optional. The desired aspect ratio for the generated images. The following aspect ratios are supported:

    "1:1" "2:3", "3:2" "3:4", "4:3" "4:5", "5:4" "9:16", "16:9" "21:9"



284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
# File 'proto_docs/google/cloud/aiplatform/v1/content.rb', line 284

class ImageConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The image output format for generated images.
  # @!attribute [rw] mime_type
  #   @return [::String]
  #     Optional. The image format that the output should be saved as.
  # @!attribute [rw] compression_quality
  #   @return [::Integer]
  #     Optional. The compression quality of the output image.
  class ImageOutputOptions
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Enum for controlling the generation of people in images.
  module PersonGeneration
    # The default behavior is unspecified. The model will decide whether to
    # generate images of people.
    PERSON_GENERATION_UNSPECIFIED = 0

    # Allows the model to generate images of people, including adults and
    # children.
    ALLOW_ALL = 1

    # Allows the model to generate images of adults, but not children.
    ALLOW_ADULT = 2

    # Prevents the model from generating images of people.
    ALLOW_NONE = 3
  end
end

#image_output_options::Google::Cloud::AIPlatform::V1::ImageConfig::ImageOutputOptions

Returns Optional. The image output format for generated images.

Returns:



284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
# File 'proto_docs/google/cloud/aiplatform/v1/content.rb', line 284

class ImageConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The image output format for generated images.
  # @!attribute [rw] mime_type
  #   @return [::String]
  #     Optional. The image format that the output should be saved as.
  # @!attribute [rw] compression_quality
  #   @return [::Integer]
  #     Optional. The compression quality of the output image.
  class ImageOutputOptions
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Enum for controlling the generation of people in images.
  module PersonGeneration
    # The default behavior is unspecified. The model will decide whether to
    # generate images of people.
    PERSON_GENERATION_UNSPECIFIED = 0

    # Allows the model to generate images of people, including adults and
    # children.
    ALLOW_ALL = 1

    # Allows the model to generate images of adults, but not children.
    ALLOW_ADULT = 2

    # Prevents the model from generating images of people.
    ALLOW_NONE = 3
  end
end

#image_size::String

Returns Optional. Specifies the size of generated images. Supported values are 1K, 2K, 4K. If not specified, the model will use default value 1K.

Returns:

  • (::String)

    Optional. Specifies the size of generated images. Supported values are 1K, 2K, 4K. If not specified, the model will use default value 1K.



284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
# File 'proto_docs/google/cloud/aiplatform/v1/content.rb', line 284

class ImageConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The image output format for generated images.
  # @!attribute [rw] mime_type
  #   @return [::String]
  #     Optional. The image format that the output should be saved as.
  # @!attribute [rw] compression_quality
  #   @return [::Integer]
  #     Optional. The compression quality of the output image.
  class ImageOutputOptions
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Enum for controlling the generation of people in images.
  module PersonGeneration
    # The default behavior is unspecified. The model will decide whether to
    # generate images of people.
    PERSON_GENERATION_UNSPECIFIED = 0

    # Allows the model to generate images of people, including adults and
    # children.
    ALLOW_ALL = 1

    # Allows the model to generate images of adults, but not children.
    ALLOW_ADULT = 2

    # Prevents the model from generating images of people.
    ALLOW_NONE = 3
  end
end

#person_generation::Google::Cloud::AIPlatform::V1::ImageConfig::PersonGeneration

Returns Optional. Controls whether the model can generate people.

Returns:



284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
# File 'proto_docs/google/cloud/aiplatform/v1/content.rb', line 284

class ImageConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The image output format for generated images.
  # @!attribute [rw] mime_type
  #   @return [::String]
  #     Optional. The image format that the output should be saved as.
  # @!attribute [rw] compression_quality
  #   @return [::Integer]
  #     Optional. The compression quality of the output image.
  class ImageOutputOptions
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Enum for controlling the generation of people in images.
  module PersonGeneration
    # The default behavior is unspecified. The model will decide whether to
    # generate images of people.
    PERSON_GENERATION_UNSPECIFIED = 0

    # Allows the model to generate images of people, including adults and
    # children.
    ALLOW_ALL = 1

    # Allows the model to generate images of adults, but not children.
    ALLOW_ADULT = 2

    # Prevents the model from generating images of people.
    ALLOW_NONE = 3
  end
end