Class: Google::Cloud::AIPlatform::V1::ImageConfig::ImageOutputOptions

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/aiplatform/v1/content.rb

Overview

The image output format for generated images.

Instance Attribute Summary collapse

Instance Attribute Details

#compression_quality::Integer

Returns Optional. The compression quality of the output image.

Returns:

  • (::Integer)

    Optional. The compression quality of the output image.



295
296
297
298
# File 'proto_docs/google/cloud/aiplatform/v1/content.rb', line 295

class ImageOutputOptions
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#mime_type::String

Returns Optional. The image format that the output should be saved as.

Returns:

  • (::String)

    Optional. The image format that the output should be saved as.



295
296
297
298
# File 'proto_docs/google/cloud/aiplatform/v1/content.rb', line 295

class ImageOutputOptions
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end