Class: Google::Cloud::AIPlatform::V1::LLMBasedMetricSpec

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/aiplatform/v1/evaluation_service.rb

Overview

Specification for an LLM based metric.

Instance Attribute Summary collapse

Instance Attribute Details

#additional_config::Google::Protobuf::Struct

Returns Optional. Optional additional configuration for the metric.

Returns:



605
606
607
608
# File 'proto_docs/google/cloud/aiplatform/v1/evaluation_service.rb', line 605

class LLMBasedMetricSpec
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#judge_autorater_config::Google::Cloud::AIPlatform::V1::AutoraterConfig

Returns Optional. Optional configuration for the judge LLM (Autorater).

Returns:



605
606
607
608
# File 'proto_docs/google/cloud/aiplatform/v1/evaluation_service.rb', line 605

class LLMBasedMetricSpec
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#metric_prompt_template::String

Returns Required. Template for the prompt sent to the judge model.

Returns:

  • (::String)

    Required. Template for the prompt sent to the judge model.



605
606
607
608
# File 'proto_docs/google/cloud/aiplatform/v1/evaluation_service.rb', line 605

class LLMBasedMetricSpec
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#predefined_rubric_generation_spec::Google::Cloud::AIPlatform::V1::PredefinedMetricSpec

Returns Dynamically generate rubrics using a predefined spec.

Note: The following fields are mutually exclusive: predefined_rubric_generation_spec, rubric_group_key. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::AIPlatform::V1::PredefinedMetricSpec)

    Dynamically generate rubrics using a predefined spec.

    Note: The following fields are mutually exclusive: predefined_rubric_generation_spec, rubric_group_key. If a field in that set is populated, all other fields in the set will automatically be cleared.



605
606
607
608
# File 'proto_docs/google/cloud/aiplatform/v1/evaluation_service.rb', line 605

class LLMBasedMetricSpec
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#rubric_group_key::String

Returns Use a pre-defined group of rubrics associated with the input. Refers to a key in the rubric_groups map of EvaluationInstance.

Note: The following fields are mutually exclusive: rubric_group_key, predefined_rubric_generation_spec. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::String)

    Use a pre-defined group of rubrics associated with the input. Refers to a key in the rubric_groups map of EvaluationInstance.

    Note: The following fields are mutually exclusive: rubric_group_key, predefined_rubric_generation_spec. If a field in that set is populated, all other fields in the set will automatically be cleared.



605
606
607
608
# File 'proto_docs/google/cloud/aiplatform/v1/evaluation_service.rb', line 605

class LLMBasedMetricSpec
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#system_instruction::String

Returns Optional. System instructions for the judge model.

Returns:

  • (::String)

    Optional. System instructions for the judge model.



605
606
607
608
# File 'proto_docs/google/cloud/aiplatform/v1/evaluation_service.rb', line 605

class LLMBasedMetricSpec
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end