Class: Google::Cloud::AIPlatform::V1::ListSessionsRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/aiplatform/v1/session_service.rb

Overview

Request message for SessionService.ListSessions.

Instance Attribute Summary collapse

Instance Attribute Details

#filter::String

Returns Optional. The standard list filter. Supported fields:

  • display_name
  • user_id
  • labels

Example: display_name="abc", user_id="123", labels.key="value".

Returns:

  • (::String)

    Optional. The standard list filter. Supported fields:

    • display_name
    • user_id
    • labels

    Example: display_name="abc", user_id="123", labels.key="value".



107
108
109
110
# File 'proto_docs/google/cloud/aiplatform/v1/session_service.rb', line 107

class ListSessionsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#order_by::String

Returns Optional. A comma-separated list of fields to order by, sorted in ascending order. Use "desc" after a field name for descending. Supported fields:

  • create_time
  • update_time

Example: create_time desc.

Returns:

  • (::String)

    Optional. A comma-separated list of fields to order by, sorted in ascending order. Use "desc" after a field name for descending. Supported fields:

    • create_time
    • update_time

    Example: create_time desc.



107
108
109
110
# File 'proto_docs/google/cloud/aiplatform/v1/session_service.rb', line 107

class ListSessionsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_size::Integer

Optional. The maximum number of sessions to return. The service may return fewer than this value. If unspecified, at most 100 sessions will be returned.

Returns:

  • (::Integer)

    Optional. The maximum number of sessions to return. The service may return fewer than this value. If unspecified, at most 100 sessions will be returned.



107
108
109
110
# File 'proto_docs/google/cloud/aiplatform/v1/session_service.rb', line 107

class ListSessionsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_token::String

Returns Optional. The next_page_token value returned from a previous list SessionService.ListSessions call.

Returns:



107
108
109
110
# File 'proto_docs/google/cloud/aiplatform/v1/session_service.rb', line 107

class ListSessionsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent::String

Returns Required. The resource name of the location to list sessions from. Format: projects/{project}/locations/{location}/reasoningEngines/{reasoning_engine}.

Returns:

  • (::String)

    Required. The resource name of the location to list sessions from. Format: projects/{project}/locations/{location}/reasoningEngines/{reasoning_engine}



107
108
109
110
# File 'proto_docs/google/cloud/aiplatform/v1/session_service.rb', line 107

class ListSessionsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end