Class: Google::Cloud::AIPlatform::V1::ListSessionsResponse

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/aiplatform/v1/session_service.rb

Overview

Response message for SessionService.ListSessions.

Instance Attribute Summary collapse

Instance Attribute Details

#next_page_token::String

Returns A token, which can be sent as ListSessionsRequest.page_token to retrieve the next page. Absence of this field indicates there are no subsequent pages.

Returns:

  • (::String)

    A token, which can be sent as ListSessionsRequest.page_token to retrieve the next page. Absence of this field indicates there are no subsequent pages.



123
124
125
126
# File 'proto_docs/google/cloud/aiplatform/v1/session_service.rb', line 123

class ListSessionsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#sessions::Array<::Google::Cloud::AIPlatform::V1::Session>

Returns A list of sessions matching the request.

Returns:



123
124
125
126
# File 'proto_docs/google/cloud/aiplatform/v1/session_service.rb', line 123

class ListSessionsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end