Class: Google::Cloud::AIPlatform::V1::LogprobsResult
- Inherits:
-
Object
- Object
- Google::Cloud::AIPlatform::V1::LogprobsResult
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/aiplatform/v1/content.rb
Overview
Logprobs Result
Defined Under Namespace
Classes: Candidate, TopCandidates
Instance Attribute Summary collapse
-
#chosen_candidates ⇒ ::Array<::Google::Cloud::AIPlatform::V1::LogprobsResult::Candidate>
Length = total number of decoding steps.
-
#top_candidates ⇒ ::Array<::Google::Cloud::AIPlatform::V1::LogprobsResult::TopCandidates>
Length = total number of decoding steps.
Instance Attribute Details
#chosen_candidates ⇒ ::Array<::Google::Cloud::AIPlatform::V1::LogprobsResult::Candidate>
Returns Length = total number of decoding steps. The chosen candidates may or may not be in top_candidates.
833 834 835 836 837 838 839 840 841 842 843 844 845 846 847 848 849 850 851 852 853 854 855 856 857 858 859 860 |
# File 'proto_docs/google/cloud/aiplatform/v1/content.rb', line 833 class LogprobsResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Candidate for the logprobs token and score. # @!attribute [rw] token # @return [::String] # The candidate’s token string value. # @!attribute [rw] token_id # @return [::Integer] # The candidate’s token id value. # @!attribute [rw] log_probability # @return [::Float] # The candidate's log probability. class Candidate include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Candidates with top log probabilities at each decoding step. # @!attribute [rw] candidates # @return [::Array<::Google::Cloud::AIPlatform::V1::LogprobsResult::Candidate>] # Sorted by log probability in descending order. class TopCandidates include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#top_candidates ⇒ ::Array<::Google::Cloud::AIPlatform::V1::LogprobsResult::TopCandidates>
Returns Length = total number of decoding steps.
833 834 835 836 837 838 839 840 841 842 843 844 845 846 847 848 849 850 851 852 853 854 855 856 857 858 859 860 |
# File 'proto_docs/google/cloud/aiplatform/v1/content.rb', line 833 class LogprobsResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Candidate for the logprobs token and score. # @!attribute [rw] token # @return [::String] # The candidate’s token string value. # @!attribute [rw] token_id # @return [::Integer] # The candidate’s token id value. # @!attribute [rw] log_probability # @return [::Float] # The candidate's log probability. class Candidate include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Candidates with top log probabilities at each decoding step. # @!attribute [rw] candidates # @return [::Array<::Google::Cloud::AIPlatform::V1::LogprobsResult::Candidate>] # Sorted by log probability in descending order. class TopCandidates include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |