Class: Google::Cloud::AIPlatform::V1::LustreMount

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/aiplatform/v1/machine_resources.rb

Overview

Represents a mount configuration for Lustre file system.

Instance Attribute Summary collapse

Instance Attribute Details

#filesystem::String

Returns Required. The name of the Lustre filesystem.

Returns:

  • (::String)

    Required. The name of the Lustre filesystem.



266
267
268
269
# File 'proto_docs/google/cloud/aiplatform/v1/machine_resources.rb', line 266

class LustreMount
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#instance_ip::String

Returns Required. IP address of the Lustre instance.

Returns:

  • (::String)

    Required. IP address of the Lustre instance.



266
267
268
269
# File 'proto_docs/google/cloud/aiplatform/v1/machine_resources.rb', line 266

class LustreMount
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#mount_point::String

Returns Required. Destination mount path. The Lustre file system will be mounted for the user under /mnt/lustre/.

Returns:

  • (::String)

    Required. Destination mount path. The Lustre file system will be mounted for the user under /mnt/lustre/



266
267
268
269
# File 'proto_docs/google/cloud/aiplatform/v1/machine_resources.rb', line 266

class LustreMount
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#volume_handle::String

Returns Required. The unique identifier of the Lustre volume.

Returns:

  • (::String)

    Required. The unique identifier of the Lustre volume.



266
267
268
269
# File 'proto_docs/google/cloud/aiplatform/v1/machine_resources.rb', line 266

class LustreMount
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end