Class: Google::Cloud::AIPlatform::V1::Metric

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/aiplatform/v1/evaluation_service.rb

Overview

The metric used for running evaluations.

Defined Under Namespace

Modules: AggregationMetric

Instance Attribute Summary collapse

Instance Attribute Details

#aggregation_metrics::Array<::Google::Cloud::AIPlatform::V1::Metric::AggregationMetric>

Returns Optional. The aggregation metrics to use.

Returns:



210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
# File 'proto_docs/google/cloud/aiplatform/v1/evaluation_service.rb', line 210

class Metric
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The per-metric statistics on evaluation results supported by
  # `EvaluationService.EvaluateDataset`.
  module AggregationMetric
    # Unspecified aggregation metric.
    AGGREGATION_METRIC_UNSPECIFIED = 0

    # Average aggregation metric. Not supported for Pairwise metric.
    AVERAGE = 1

    # Mode aggregation metric.
    MODE = 2

    # Standard deviation aggregation metric. Not supported for pairwise metric.
    STANDARD_DEVIATION = 3

    # Variance aggregation metric. Not supported for pairwise metric.
    VARIANCE = 4

    # Minimum aggregation metric. Not supported for pairwise metric.
    MINIMUM = 5

    # Maximum aggregation metric. Not supported for pairwise metric.
    MAXIMUM = 6

    # Median aggregation metric. Not supported for pairwise metric.
    MEDIAN = 7

    # 90th percentile aggregation metric. Not supported for pairwise metric.
    PERCENTILE_P90 = 8

    # 95th percentile aggregation metric. Not supported for pairwise metric.
    PERCENTILE_P95 = 9

    # 99th percentile aggregation metric. Not supported for pairwise metric.
    PERCENTILE_P99 = 10
  end
end

#bleu_spec::Google::Cloud::AIPlatform::V1::BleuSpec

Returns Spec for bleu metric.

Note: The following fields are mutually exclusive: bleu_spec, predefined_metric_spec, computation_based_metric_spec, llm_based_metric_spec, pointwise_metric_spec, pairwise_metric_spec, exact_match_spec, rouge_spec. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::AIPlatform::V1::BleuSpec)

    Spec for bleu metric.

    Note: The following fields are mutually exclusive: bleu_spec, predefined_metric_spec, computation_based_metric_spec, llm_based_metric_spec, pointwise_metric_spec, pairwise_metric_spec, exact_match_spec, rouge_spec. If a field in that set is populated, all other fields in the set will automatically be cleared.



210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
# File 'proto_docs/google/cloud/aiplatform/v1/evaluation_service.rb', line 210

class Metric
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The per-metric statistics on evaluation results supported by
  # `EvaluationService.EvaluateDataset`.
  module AggregationMetric
    # Unspecified aggregation metric.
    AGGREGATION_METRIC_UNSPECIFIED = 0

    # Average aggregation metric. Not supported for Pairwise metric.
    AVERAGE = 1

    # Mode aggregation metric.
    MODE = 2

    # Standard deviation aggregation metric. Not supported for pairwise metric.
    STANDARD_DEVIATION = 3

    # Variance aggregation metric. Not supported for pairwise metric.
    VARIANCE = 4

    # Minimum aggregation metric. Not supported for pairwise metric.
    MINIMUM = 5

    # Maximum aggregation metric. Not supported for pairwise metric.
    MAXIMUM = 6

    # Median aggregation metric. Not supported for pairwise metric.
    MEDIAN = 7

    # 90th percentile aggregation metric. Not supported for pairwise metric.
    PERCENTILE_P90 = 8

    # 95th percentile aggregation metric. Not supported for pairwise metric.
    PERCENTILE_P95 = 9

    # 99th percentile aggregation metric. Not supported for pairwise metric.
    PERCENTILE_P99 = 10
  end
end

#computation_based_metric_spec::Google::Cloud::AIPlatform::V1::ComputationBasedMetricSpec

Returns Spec for a computation based metric.

Note: The following fields are mutually exclusive: computation_based_metric_spec, predefined_metric_spec, llm_based_metric_spec, pointwise_metric_spec, pairwise_metric_spec, exact_match_spec, bleu_spec, rouge_spec. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::AIPlatform::V1::ComputationBasedMetricSpec)

    Spec for a computation based metric.

    Note: The following fields are mutually exclusive: computation_based_metric_spec, predefined_metric_spec, llm_based_metric_spec, pointwise_metric_spec, pairwise_metric_spec, exact_match_spec, bleu_spec, rouge_spec. If a field in that set is populated, all other fields in the set will automatically be cleared.



210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
# File 'proto_docs/google/cloud/aiplatform/v1/evaluation_service.rb', line 210

class Metric
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The per-metric statistics on evaluation results supported by
  # `EvaluationService.EvaluateDataset`.
  module AggregationMetric
    # Unspecified aggregation metric.
    AGGREGATION_METRIC_UNSPECIFIED = 0

    # Average aggregation metric. Not supported for Pairwise metric.
    AVERAGE = 1

    # Mode aggregation metric.
    MODE = 2

    # Standard deviation aggregation metric. Not supported for pairwise metric.
    STANDARD_DEVIATION = 3

    # Variance aggregation metric. Not supported for pairwise metric.
    VARIANCE = 4

    # Minimum aggregation metric. Not supported for pairwise metric.
    MINIMUM = 5

    # Maximum aggregation metric. Not supported for pairwise metric.
    MAXIMUM = 6

    # Median aggregation metric. Not supported for pairwise metric.
    MEDIAN = 7

    # 90th percentile aggregation metric. Not supported for pairwise metric.
    PERCENTILE_P90 = 8

    # 95th percentile aggregation metric. Not supported for pairwise metric.
    PERCENTILE_P95 = 9

    # 99th percentile aggregation metric. Not supported for pairwise metric.
    PERCENTILE_P99 = 10
  end
end

#exact_match_spec::Google::Cloud::AIPlatform::V1::ExactMatchSpec

Returns Spec for exact match metric.

Note: The following fields are mutually exclusive: exact_match_spec, predefined_metric_spec, computation_based_metric_spec, llm_based_metric_spec, pointwise_metric_spec, pairwise_metric_spec, bleu_spec, rouge_spec. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::AIPlatform::V1::ExactMatchSpec)

    Spec for exact match metric.

    Note: The following fields are mutually exclusive: exact_match_spec, predefined_metric_spec, computation_based_metric_spec, llm_based_metric_spec, pointwise_metric_spec, pairwise_metric_spec, bleu_spec, rouge_spec. If a field in that set is populated, all other fields in the set will automatically be cleared.



210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
# File 'proto_docs/google/cloud/aiplatform/v1/evaluation_service.rb', line 210

class Metric
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The per-metric statistics on evaluation results supported by
  # `EvaluationService.EvaluateDataset`.
  module AggregationMetric
    # Unspecified aggregation metric.
    AGGREGATION_METRIC_UNSPECIFIED = 0

    # Average aggregation metric. Not supported for Pairwise metric.
    AVERAGE = 1

    # Mode aggregation metric.
    MODE = 2

    # Standard deviation aggregation metric. Not supported for pairwise metric.
    STANDARD_DEVIATION = 3

    # Variance aggregation metric. Not supported for pairwise metric.
    VARIANCE = 4

    # Minimum aggregation metric. Not supported for pairwise metric.
    MINIMUM = 5

    # Maximum aggregation metric. Not supported for pairwise metric.
    MAXIMUM = 6

    # Median aggregation metric. Not supported for pairwise metric.
    MEDIAN = 7

    # 90th percentile aggregation metric. Not supported for pairwise metric.
    PERCENTILE_P90 = 8

    # 95th percentile aggregation metric. Not supported for pairwise metric.
    PERCENTILE_P95 = 9

    # 99th percentile aggregation metric. Not supported for pairwise metric.
    PERCENTILE_P99 = 10
  end
end

#llm_based_metric_spec::Google::Cloud::AIPlatform::V1::LLMBasedMetricSpec

Returns Spec for an LLM based metric.

Note: The following fields are mutually exclusive: llm_based_metric_spec, predefined_metric_spec, computation_based_metric_spec, pointwise_metric_spec, pairwise_metric_spec, exact_match_spec, bleu_spec, rouge_spec. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::AIPlatform::V1::LLMBasedMetricSpec)

    Spec for an LLM based metric.

    Note: The following fields are mutually exclusive: llm_based_metric_spec, predefined_metric_spec, computation_based_metric_spec, pointwise_metric_spec, pairwise_metric_spec, exact_match_spec, bleu_spec, rouge_spec. If a field in that set is populated, all other fields in the set will automatically be cleared.



210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
# File 'proto_docs/google/cloud/aiplatform/v1/evaluation_service.rb', line 210

class Metric
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The per-metric statistics on evaluation results supported by
  # `EvaluationService.EvaluateDataset`.
  module AggregationMetric
    # Unspecified aggregation metric.
    AGGREGATION_METRIC_UNSPECIFIED = 0

    # Average aggregation metric. Not supported for Pairwise metric.
    AVERAGE = 1

    # Mode aggregation metric.
    MODE = 2

    # Standard deviation aggregation metric. Not supported for pairwise metric.
    STANDARD_DEVIATION = 3

    # Variance aggregation metric. Not supported for pairwise metric.
    VARIANCE = 4

    # Minimum aggregation metric. Not supported for pairwise metric.
    MINIMUM = 5

    # Maximum aggregation metric. Not supported for pairwise metric.
    MAXIMUM = 6

    # Median aggregation metric. Not supported for pairwise metric.
    MEDIAN = 7

    # 90th percentile aggregation metric. Not supported for pairwise metric.
    PERCENTILE_P90 = 8

    # 95th percentile aggregation metric. Not supported for pairwise metric.
    PERCENTILE_P95 = 9

    # 99th percentile aggregation metric. Not supported for pairwise metric.
    PERCENTILE_P99 = 10
  end
end

#pairwise_metric_spec::Google::Cloud::AIPlatform::V1::PairwiseMetricSpec

Returns Spec for pairwise metric.

Note: The following fields are mutually exclusive: pairwise_metric_spec, predefined_metric_spec, computation_based_metric_spec, llm_based_metric_spec, pointwise_metric_spec, exact_match_spec, bleu_spec, rouge_spec. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::AIPlatform::V1::PairwiseMetricSpec)

    Spec for pairwise metric.

    Note: The following fields are mutually exclusive: pairwise_metric_spec, predefined_metric_spec, computation_based_metric_spec, llm_based_metric_spec, pointwise_metric_spec, exact_match_spec, bleu_spec, rouge_spec. If a field in that set is populated, all other fields in the set will automatically be cleared.



210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
# File 'proto_docs/google/cloud/aiplatform/v1/evaluation_service.rb', line 210

class Metric
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The per-metric statistics on evaluation results supported by
  # `EvaluationService.EvaluateDataset`.
  module AggregationMetric
    # Unspecified aggregation metric.
    AGGREGATION_METRIC_UNSPECIFIED = 0

    # Average aggregation metric. Not supported for Pairwise metric.
    AVERAGE = 1

    # Mode aggregation metric.
    MODE = 2

    # Standard deviation aggregation metric. Not supported for pairwise metric.
    STANDARD_DEVIATION = 3

    # Variance aggregation metric. Not supported for pairwise metric.
    VARIANCE = 4

    # Minimum aggregation metric. Not supported for pairwise metric.
    MINIMUM = 5

    # Maximum aggregation metric. Not supported for pairwise metric.
    MAXIMUM = 6

    # Median aggregation metric. Not supported for pairwise metric.
    MEDIAN = 7

    # 90th percentile aggregation metric. Not supported for pairwise metric.
    PERCENTILE_P90 = 8

    # 95th percentile aggregation metric. Not supported for pairwise metric.
    PERCENTILE_P95 = 9

    # 99th percentile aggregation metric. Not supported for pairwise metric.
    PERCENTILE_P99 = 10
  end
end

#pointwise_metric_spec::Google::Cloud::AIPlatform::V1::PointwiseMetricSpec

Returns Spec for pointwise metric.

Note: The following fields are mutually exclusive: pointwise_metric_spec, predefined_metric_spec, computation_based_metric_spec, llm_based_metric_spec, pairwise_metric_spec, exact_match_spec, bleu_spec, rouge_spec. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::AIPlatform::V1::PointwiseMetricSpec)

    Spec for pointwise metric.

    Note: The following fields are mutually exclusive: pointwise_metric_spec, predefined_metric_spec, computation_based_metric_spec, llm_based_metric_spec, pairwise_metric_spec, exact_match_spec, bleu_spec, rouge_spec. If a field in that set is populated, all other fields in the set will automatically be cleared.



210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
# File 'proto_docs/google/cloud/aiplatform/v1/evaluation_service.rb', line 210

class Metric
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The per-metric statistics on evaluation results supported by
  # `EvaluationService.EvaluateDataset`.
  module AggregationMetric
    # Unspecified aggregation metric.
    AGGREGATION_METRIC_UNSPECIFIED = 0

    # Average aggregation metric. Not supported for Pairwise metric.
    AVERAGE = 1

    # Mode aggregation metric.
    MODE = 2

    # Standard deviation aggregation metric. Not supported for pairwise metric.
    STANDARD_DEVIATION = 3

    # Variance aggregation metric. Not supported for pairwise metric.
    VARIANCE = 4

    # Minimum aggregation metric. Not supported for pairwise metric.
    MINIMUM = 5

    # Maximum aggregation metric. Not supported for pairwise metric.
    MAXIMUM = 6

    # Median aggregation metric. Not supported for pairwise metric.
    MEDIAN = 7

    # 90th percentile aggregation metric. Not supported for pairwise metric.
    PERCENTILE_P90 = 8

    # 95th percentile aggregation metric. Not supported for pairwise metric.
    PERCENTILE_P95 = 9

    # 99th percentile aggregation metric. Not supported for pairwise metric.
    PERCENTILE_P99 = 10
  end
end

#predefined_metric_spec::Google::Cloud::AIPlatform::V1::PredefinedMetricSpec

Returns The spec for a pre-defined metric.

Note: The following fields are mutually exclusive: predefined_metric_spec, computation_based_metric_spec, llm_based_metric_spec, pointwise_metric_spec, pairwise_metric_spec, exact_match_spec, bleu_spec, rouge_spec. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::AIPlatform::V1::PredefinedMetricSpec)

    The spec for a pre-defined metric.

    Note: The following fields are mutually exclusive: predefined_metric_spec, computation_based_metric_spec, llm_based_metric_spec, pointwise_metric_spec, pairwise_metric_spec, exact_match_spec, bleu_spec, rouge_spec. If a field in that set is populated, all other fields in the set will automatically be cleared.



210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
# File 'proto_docs/google/cloud/aiplatform/v1/evaluation_service.rb', line 210

class Metric
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The per-metric statistics on evaluation results supported by
  # `EvaluationService.EvaluateDataset`.
  module AggregationMetric
    # Unspecified aggregation metric.
    AGGREGATION_METRIC_UNSPECIFIED = 0

    # Average aggregation metric. Not supported for Pairwise metric.
    AVERAGE = 1

    # Mode aggregation metric.
    MODE = 2

    # Standard deviation aggregation metric. Not supported for pairwise metric.
    STANDARD_DEVIATION = 3

    # Variance aggregation metric. Not supported for pairwise metric.
    VARIANCE = 4

    # Minimum aggregation metric. Not supported for pairwise metric.
    MINIMUM = 5

    # Maximum aggregation metric. Not supported for pairwise metric.
    MAXIMUM = 6

    # Median aggregation metric. Not supported for pairwise metric.
    MEDIAN = 7

    # 90th percentile aggregation metric. Not supported for pairwise metric.
    PERCENTILE_P90 = 8

    # 95th percentile aggregation metric. Not supported for pairwise metric.
    PERCENTILE_P95 = 9

    # 99th percentile aggregation metric. Not supported for pairwise metric.
    PERCENTILE_P99 = 10
  end
end

#rouge_spec::Google::Cloud::AIPlatform::V1::RougeSpec

Returns Spec for rouge metric.

Note: The following fields are mutually exclusive: rouge_spec, predefined_metric_spec, computation_based_metric_spec, llm_based_metric_spec, pointwise_metric_spec, pairwise_metric_spec, exact_match_spec, bleu_spec. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::AIPlatform::V1::RougeSpec)

    Spec for rouge metric.

    Note: The following fields are mutually exclusive: rouge_spec, predefined_metric_spec, computation_based_metric_spec, llm_based_metric_spec, pointwise_metric_spec, pairwise_metric_spec, exact_match_spec, bleu_spec. If a field in that set is populated, all other fields in the set will automatically be cleared.



210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
# File 'proto_docs/google/cloud/aiplatform/v1/evaluation_service.rb', line 210

class Metric
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The per-metric statistics on evaluation results supported by
  # `EvaluationService.EvaluateDataset`.
  module AggregationMetric
    # Unspecified aggregation metric.
    AGGREGATION_METRIC_UNSPECIFIED = 0

    # Average aggregation metric. Not supported for Pairwise metric.
    AVERAGE = 1

    # Mode aggregation metric.
    MODE = 2

    # Standard deviation aggregation metric. Not supported for pairwise metric.
    STANDARD_DEVIATION = 3

    # Variance aggregation metric. Not supported for pairwise metric.
    VARIANCE = 4

    # Minimum aggregation metric. Not supported for pairwise metric.
    MINIMUM = 5

    # Maximum aggregation metric. Not supported for pairwise metric.
    MAXIMUM = 6

    # Median aggregation metric. Not supported for pairwise metric.
    MEDIAN = 7

    # 90th percentile aggregation metric. Not supported for pairwise metric.
    PERCENTILE_P90 = 8

    # 95th percentile aggregation metric. Not supported for pairwise metric.
    PERCENTILE_P95 = 9

    # 99th percentile aggregation metric. Not supported for pairwise metric.
    PERCENTILE_P99 = 10
  end
end