Class: Google::Cloud::AIPlatform::V1::OutputInfo
- Inherits:
-
Object
- Object
- Google::Cloud::AIPlatform::V1::OutputInfo
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/aiplatform/v1/evaluation_service.rb
Overview
Describes the info for output of EvaluationService.
Instance Attribute Summary collapse
-
#gcs_output_directory ⇒ ::String
readonly
Output only.
Instance Attribute Details
#gcs_output_directory ⇒ ::String (readonly)
Returns Output only. The full path of the Cloud Storage directory created, into which the evaluation results and aggregation results are written.
489 490 491 492 |
# File 'proto_docs/google/cloud/aiplatform/v1/evaluation_service.rb', line 489 class OutputInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |