Class: Google::Cloud::AIPlatform::V1::PairwiseMetricInstance

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/aiplatform/v1/evaluation_service.rb

Overview

Pairwise metric instance. Usually one instance corresponds to one row in an evaluation dataset.

Instance Attribute Summary collapse

Instance Attribute Details

#content_map_instance::Google::Cloud::AIPlatform::V1::ContentMap

Returns Key-value contents for the mutlimodality input, including text, image, video, audio, and pdf, etc. The key is placeholder in metric prompt template, and the value is the multimodal content.

Note: The following fields are mutually exclusive: content_map_instance, json_instance. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::AIPlatform::V1::ContentMap)

    Key-value contents for the mutlimodality input, including text, image, video, audio, and pdf, etc. The key is placeholder in metric prompt template, and the value is the multimodal content.

    Note: The following fields are mutually exclusive: content_map_instance, json_instance. If a field in that set is populated, all other fields in the set will automatically be cleared.



1653
1654
1655
1656
# File 'proto_docs/google/cloud/aiplatform/v1/evaluation_service.rb', line 1653

class PairwiseMetricInstance
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#json_instance::String

Returns Instance specified as a json string. String key-value pairs are expected in the json_instance to render PairwiseMetricSpec.instance_prompt_template.

Note: The following fields are mutually exclusive: json_instance, content_map_instance. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::String)

    Instance specified as a json string. String key-value pairs are expected in the json_instance to render PairwiseMetricSpec.instance_prompt_template.

    Note: The following fields are mutually exclusive: json_instance, content_map_instance. If a field in that set is populated, all other fields in the set will automatically be cleared.



1653
1654
1655
1656
# File 'proto_docs/google/cloud/aiplatform/v1/evaluation_service.rb', line 1653

class PairwiseMetricInstance
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end