Class: Google::Cloud::AIPlatform::V1::PartialArg

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/aiplatform/v1/tool.rb

Overview

Partial argument value of the function call.

Instance Attribute Summary collapse

Instance Attribute Details

#bool_value::Boolean

Returns Optional. Represents a boolean value.

Note: The following fields are mutually exclusive: bool_value, null_value, number_value, string_value. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Boolean)

    Optional. Represents a boolean value.

    Note: The following fields are mutually exclusive: bool_value, null_value, number_value, string_value. If a field in that set is populated, all other fields in the set will automatically be cleared.



289
290
291
292
# File 'proto_docs/google/cloud/aiplatform/v1/tool.rb', line 289

class PartialArg
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#json_path::String

Returns Required. A JSON Path (RFC 9535) to the argument being streamed. https://datatracker.ietf.org/doc/html/rfc9535. e.g. "$.foo.bar[0].data".

Returns:



289
290
291
292
# File 'proto_docs/google/cloud/aiplatform/v1/tool.rb', line 289

class PartialArg
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#null_value::Google::Protobuf::NullValue

Returns Optional. Represents a null value.

Note: The following fields are mutually exclusive: null_value, number_value, string_value, bool_value. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Protobuf::NullValue)

    Optional. Represents a null value.

    Note: The following fields are mutually exclusive: null_value, number_value, string_value, bool_value. If a field in that set is populated, all other fields in the set will automatically be cleared.



289
290
291
292
# File 'proto_docs/google/cloud/aiplatform/v1/tool.rb', line 289

class PartialArg
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#number_value::Float

Returns Optional. Represents a double value.

Note: The following fields are mutually exclusive: number_value, null_value, string_value, bool_value. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Float)

    Optional. Represents a double value.

    Note: The following fields are mutually exclusive: number_value, null_value, string_value, bool_value. If a field in that set is populated, all other fields in the set will automatically be cleared.



289
290
291
292
# File 'proto_docs/google/cloud/aiplatform/v1/tool.rb', line 289

class PartialArg
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#string_value::String

Returns Optional. Represents a string value.

Note: The following fields are mutually exclusive: string_value, null_value, number_value, bool_value. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::String)

    Optional. Represents a string value.

    Note: The following fields are mutually exclusive: string_value, null_value, number_value, bool_value. If a field in that set is populated, all other fields in the set will automatically be cleared.



289
290
291
292
# File 'proto_docs/google/cloud/aiplatform/v1/tool.rb', line 289

class PartialArg
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#will_continue::Boolean

Returns Optional. Whether this is not the last part of the same json_path. If true, another PartialArg message for the current json_path is expected to follow.

Returns:

  • (::Boolean)

    Optional. Whether this is not the last part of the same json_path. If true, another PartialArg message for the current json_path is expected to follow.



289
290
291
292
# File 'proto_docs/google/cloud/aiplatform/v1/tool.rb', line 289

class PartialArg
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end