Class: Google::Cloud::AIPlatform::V1::PointwiseMetricSpec

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/aiplatform/v1/evaluation_service.rb

Overview

Spec for pointwise metric.

Instance Attribute Summary collapse

Instance Attribute Details

#custom_output_format_config::Google::Cloud::AIPlatform::V1::CustomOutputFormatConfig

Returns Optional. CustomOutputFormatConfig allows customization of metric output. By default, metrics return a score and explanation. When this config is set, the default output is replaced with either:

  • The raw output string.
  • A parsed output based on a user-defined schema. If a custom format is chosen, the score and explanation fields in the corresponding metric result will be empty.

Returns:

  • (::Google::Cloud::AIPlatform::V1::CustomOutputFormatConfig)

    Optional. CustomOutputFormatConfig allows customization of metric output. By default, metrics return a score and explanation. When this config is set, the default output is replaced with either:

    • The raw output string.
    • A parsed output based on a user-defined schema. If a custom format is chosen, the score and explanation fields in the corresponding metric result will be empty.


1578
1579
1580
1581
# File 'proto_docs/google/cloud/aiplatform/v1/evaluation_service.rb', line 1578

class PointwiseMetricSpec
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#metric_prompt_template::String

Returns Required. Metric prompt template for pointwise metric.

Returns:

  • (::String)

    Required. Metric prompt template for pointwise metric.



1578
1579
1580
1581
# File 'proto_docs/google/cloud/aiplatform/v1/evaluation_service.rb', line 1578

class PointwiseMetricSpec
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#system_instruction::String

Returns Optional. System instructions for pointwise metric.

Returns:

  • (::String)

    Optional. System instructions for pointwise metric.



1578
1579
1580
1581
# File 'proto_docs/google/cloud/aiplatform/v1/evaluation_service.rb', line 1578

class PointwiseMetricSpec
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end