Class: Google::Cloud::AIPlatform::V1::RagRetrievalConfig::Ranking
- Inherits:
-
Object
- Object
- Google::Cloud::AIPlatform::V1::RagRetrievalConfig::Ranking
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/aiplatform/v1/tool.rb
Overview
Config for ranking and reranking.
Defined Under Namespace
Classes: LlmRanker, RankService
Instance Attribute Summary collapse
-
#llm_ranker ⇒ ::Google::Cloud::AIPlatform::V1::RagRetrievalConfig::Ranking::LlmRanker
Optional.
-
#rank_service ⇒ ::Google::Cloud::AIPlatform::V1::RagRetrievalConfig::Ranking::RankService
Optional.
Instance Attribute Details
#llm_ranker ⇒ ::Google::Cloud::AIPlatform::V1::RagRetrievalConfig::Ranking::LlmRanker
Returns Optional. Config for LlmRanker.
Note: The following fields are mutually exclusive: llm_ranker, rank_service. If a field in that set is populated, all other fields in the set will automatically be cleared.
716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 735 736 737 738 739 |
# File 'proto_docs/google/cloud/aiplatform/v1/tool.rb', line 716 class Ranking include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Config for Rank Service. # @!attribute [rw] model_name # @return [::String] # Optional. The model name of the rank service. # Format: `semantic-ranker-512@latest` class RankService include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Config for LlmRanker. # @!attribute [rw] model_name # @return [::String] # Optional. The model name used for ranking. # Format: `gemini-1.5-pro` class LlmRanker include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#rank_service ⇒ ::Google::Cloud::AIPlatform::V1::RagRetrievalConfig::Ranking::RankService
Returns Optional. Config for Rank Service.
Note: The following fields are mutually exclusive: rank_service, llm_ranker. If a field in that set is populated, all other fields in the set will automatically be cleared.
716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 735 736 737 738 739 |
# File 'proto_docs/google/cloud/aiplatform/v1/tool.rb', line 716 class Ranking include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Config for Rank Service. # @!attribute [rw] model_name # @return [::String] # Optional. The model name of the rank service. # Format: `semantic-ranker-512@latest` class RankService include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Config for LlmRanker. # @!attribute [rw] model_name # @return [::String] # Optional. The model name used for ranking. # Format: `gemini-1.5-pro` class LlmRanker include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |