Class: Google::Cloud::AIPlatform::V1::ReasoningEngineSpec::ContainerSpec

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/aiplatform/v1/reasoning_engine.rb

Overview

Specification for deploying from a container image.

Instance Attribute Summary collapse

Instance Attribute Details

#image_uri::String

Returns Required. The Artifact Registry Docker image URI (e.g., us-central1-docker.pkg.dev/my-project/my-repo/my-image:tag) of the container image that is to be run on each worker replica.

Returns:

  • (::String)

    Required. The Artifact Registry Docker image URI (e.g., us-central1-docker.pkg.dev/my-project/my-repo/my-image:tag) of the container image that is to be run on each worker replica.



264
265
266
267
# File 'proto_docs/google/cloud/aiplatform/v1/reasoning_engine.rb', line 264

class ContainerSpec
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end