Class: Google::Cloud::AIPlatform::V1::ReasoningEngineSpec::DeploymentSpec
- Inherits:
-
Object
- Object
- Google::Cloud::AIPlatform::V1::ReasoningEngineSpec::DeploymentSpec
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/aiplatform/v1/reasoning_engine.rb
Overview
The specification of a Reasoning Engine deployment.
Defined Under Namespace
Classes: ResourceLimitsEntry
Instance Attribute Summary collapse
-
#container_concurrency ⇒ ::Integer
Optional.
-
#env ⇒ ::Array<::Google::Cloud::AIPlatform::V1::EnvVar>
Optional.
-
#max_instances ⇒ ::Integer
Optional.
-
#min_instances ⇒ ::Integer
Optional.
-
#psc_interface_config ⇒ ::Google::Cloud::AIPlatform::V1::PscInterfaceConfig
Optional.
-
#resource_limits ⇒ ::Google::Protobuf::Map{::String => ::String}
Optional.
-
#secret_env ⇒ ::Array<::Google::Cloud::AIPlatform::V1::SecretEnvVar>
Optional.
Instance Attribute Details
#container_concurrency ⇒ ::Integer
Returns Optional. Concurrency for each container and agent server. Recommended value: 2 * cpu + 1. Defaults to 9.
128 129 130 131 132 133 134 135 136 137 138 139 140 |
# File 'proto_docs/google/cloud/aiplatform/v1/reasoning_engine.rb', line 128 class DeploymentSpec include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class ResourceLimitsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#env ⇒ ::Array<::Google::Cloud::AIPlatform::V1::EnvVar>
Returns Optional. Environment variables to be set with the Reasoning Engine deployment. The environment variables can be updated through the UpdateReasoningEngine API.
128 129 130 131 132 133 134 135 136 137 138 139 140 |
# File 'proto_docs/google/cloud/aiplatform/v1/reasoning_engine.rb', line 128 class DeploymentSpec include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class ResourceLimitsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#max_instances ⇒ ::Integer
Returns Optional. The maximum number of application instances that can be launched to handle increased traffic. Defaults to 100. Range: [1, 1000].
If VPC-SC or PSC-I is enabled, the acceptable range is [1, 100].
128 129 130 131 132 133 134 135 136 137 138 139 140 |
# File 'proto_docs/google/cloud/aiplatform/v1/reasoning_engine.rb', line 128 class DeploymentSpec include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class ResourceLimitsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#min_instances ⇒ ::Integer
Returns Optional. The minimum number of application instances that will be kept running at all times. Defaults to 1. Range: [0, 10].
128 129 130 131 132 133 134 135 136 137 138 139 140 |
# File 'proto_docs/google/cloud/aiplatform/v1/reasoning_engine.rb', line 128 class DeploymentSpec include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class ResourceLimitsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#psc_interface_config ⇒ ::Google::Cloud::AIPlatform::V1::PscInterfaceConfig
Returns Optional. Configuration for PSC-I.
128 129 130 131 132 133 134 135 136 137 138 139 140 |
# File 'proto_docs/google/cloud/aiplatform/v1/reasoning_engine.rb', line 128 class DeploymentSpec include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class ResourceLimitsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#resource_limits ⇒ ::Google::Protobuf::Map{::String => ::String}
Returns Optional. Resource limits for each container. Only 'cpu' and 'memory' keys are supported. Defaults to {"cpu": "4", "memory": "4Gi"}.
- The only supported values for CPU are '1', '2', '4', '6' and '8'. For more information, go to https://cloud.google.com/run/docs/configuring/cpu.
- The only supported values for memory are '1Gi', '2Gi', ... '32 Gi'.
- For required cpu on different memory values, go to https://cloud.google.com/run/docs/configuring/memory-limits.
128 129 130 131 132 133 134 135 136 137 138 139 140 |
# File 'proto_docs/google/cloud/aiplatform/v1/reasoning_engine.rb', line 128 class DeploymentSpec include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class ResourceLimitsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#secret_env ⇒ ::Array<::Google::Cloud::AIPlatform::V1::SecretEnvVar>
Returns Optional. Environment variables where the value is a secret in Cloud Secret Manager. To use this feature, add 'Secret Manager Secret Accessor' role (roles/secretmanager.secretAccessor) to AI Platform Reasoning Engine Service Agent.
128 129 130 131 132 133 134 135 136 137 138 139 140 |
# File 'proto_docs/google/cloud/aiplatform/v1/reasoning_engine.rb', line 128 class DeploymentSpec include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class ResourceLimitsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |