Class: Google::Cloud::AIPlatform::V1::ReasoningEngineSpec::SourceCodeSpec::InlineSource

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/aiplatform/v1/reasoning_engine.rb

Overview

Specifies source code provided as a byte stream.

Instance Attribute Summary collapse

Instance Attribute Details

#source_archive::String

Returns Required. Input only. The application source code archive, provided as a compressed tarball (.tar.gz) file.

Returns:

  • (::String)

    Required. Input only. The application source code archive, provided as a compressed tarball (.tar.gz) file.



172
173
174
175
# File 'proto_docs/google/cloud/aiplatform/v1/reasoning_engine.rb', line 172

class InlineSource
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end