Class: Google::Cloud::AIPlatform::V1::SafetyRating

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/aiplatform/v1/content.rb

Overview

Safety rating corresponding to the generated content.

Defined Under Namespace

Modules: HarmProbability, HarmSeverity

Instance Attribute Summary collapse

Instance Attribute Details

#blocked::Boolean (readonly)

Returns Output only. Indicates whether the content was filtered out because of this rating.

Returns:

  • (::Boolean)

    Output only. Indicates whether the content was filtered out because of this rating.



632
633
634
635
636
637
638
639
640
641
642
643
644
645
646
647
648
649
650
651
652
653
654
655
656
657
658
659
660
661
662
663
664
665
666
667
668
669
670
671
# File 'proto_docs/google/cloud/aiplatform/v1/content.rb', line 632

class SafetyRating
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Harm probability levels in the content.
  module HarmProbability
    # Harm probability unspecified.
    HARM_PROBABILITY_UNSPECIFIED = 0

    # Negligible level of harm.
    NEGLIGIBLE = 1

    # Low level of harm.
    LOW = 2

    # Medium level of harm.
    MEDIUM = 3

    # High level of harm.
    HIGH = 4
  end

  # Harm severity levels.
  module HarmSeverity
    # Harm severity unspecified.
    HARM_SEVERITY_UNSPECIFIED = 0

    # Negligible level of harm severity.
    HARM_SEVERITY_NEGLIGIBLE = 1

    # Low level of harm severity.
    HARM_SEVERITY_LOW = 2

    # Medium level of harm severity.
    HARM_SEVERITY_MEDIUM = 3

    # High level of harm severity.
    HARM_SEVERITY_HIGH = 4
  end
end

#category::Google::Cloud::AIPlatform::V1::HarmCategory (readonly)

Returns Output only. Harm category.

Returns:



632
633
634
635
636
637
638
639
640
641
642
643
644
645
646
647
648
649
650
651
652
653
654
655
656
657
658
659
660
661
662
663
664
665
666
667
668
669
670
671
# File 'proto_docs/google/cloud/aiplatform/v1/content.rb', line 632

class SafetyRating
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Harm probability levels in the content.
  module HarmProbability
    # Harm probability unspecified.
    HARM_PROBABILITY_UNSPECIFIED = 0

    # Negligible level of harm.
    NEGLIGIBLE = 1

    # Low level of harm.
    LOW = 2

    # Medium level of harm.
    MEDIUM = 3

    # High level of harm.
    HIGH = 4
  end

  # Harm severity levels.
  module HarmSeverity
    # Harm severity unspecified.
    HARM_SEVERITY_UNSPECIFIED = 0

    # Negligible level of harm severity.
    HARM_SEVERITY_NEGLIGIBLE = 1

    # Low level of harm severity.
    HARM_SEVERITY_LOW = 2

    # Medium level of harm severity.
    HARM_SEVERITY_MEDIUM = 3

    # High level of harm severity.
    HARM_SEVERITY_HIGH = 4
  end
end

#probability::Google::Cloud::AIPlatform::V1::SafetyRating::HarmProbability (readonly)

Returns Output only. Harm probability levels in the content.

Returns:



632
633
634
635
636
637
638
639
640
641
642
643
644
645
646
647
648
649
650
651
652
653
654
655
656
657
658
659
660
661
662
663
664
665
666
667
668
669
670
671
# File 'proto_docs/google/cloud/aiplatform/v1/content.rb', line 632

class SafetyRating
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Harm probability levels in the content.
  module HarmProbability
    # Harm probability unspecified.
    HARM_PROBABILITY_UNSPECIFIED = 0

    # Negligible level of harm.
    NEGLIGIBLE = 1

    # Low level of harm.
    LOW = 2

    # Medium level of harm.
    MEDIUM = 3

    # High level of harm.
    HIGH = 4
  end

  # Harm severity levels.
  module HarmSeverity
    # Harm severity unspecified.
    HARM_SEVERITY_UNSPECIFIED = 0

    # Negligible level of harm severity.
    HARM_SEVERITY_NEGLIGIBLE = 1

    # Low level of harm severity.
    HARM_SEVERITY_LOW = 2

    # Medium level of harm severity.
    HARM_SEVERITY_MEDIUM = 3

    # High level of harm severity.
    HARM_SEVERITY_HIGH = 4
  end
end

#probability_score::Float (readonly)

Returns Output only. Harm probability score.

Returns:

  • (::Float)

    Output only. Harm probability score.



632
633
634
635
636
637
638
639
640
641
642
643
644
645
646
647
648
649
650
651
652
653
654
655
656
657
658
659
660
661
662
663
664
665
666
667
668
669
670
671
# File 'proto_docs/google/cloud/aiplatform/v1/content.rb', line 632

class SafetyRating
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Harm probability levels in the content.
  module HarmProbability
    # Harm probability unspecified.
    HARM_PROBABILITY_UNSPECIFIED = 0

    # Negligible level of harm.
    NEGLIGIBLE = 1

    # Low level of harm.
    LOW = 2

    # Medium level of harm.
    MEDIUM = 3

    # High level of harm.
    HIGH = 4
  end

  # Harm severity levels.
  module HarmSeverity
    # Harm severity unspecified.
    HARM_SEVERITY_UNSPECIFIED = 0

    # Negligible level of harm severity.
    HARM_SEVERITY_NEGLIGIBLE = 1

    # Low level of harm severity.
    HARM_SEVERITY_LOW = 2

    # Medium level of harm severity.
    HARM_SEVERITY_MEDIUM = 3

    # High level of harm severity.
    HARM_SEVERITY_HIGH = 4
  end
end

#severity::Google::Cloud::AIPlatform::V1::SafetyRating::HarmSeverity (readonly)

Returns Output only. Harm severity levels in the content.

Returns:



632
633
634
635
636
637
638
639
640
641
642
643
644
645
646
647
648
649
650
651
652
653
654
655
656
657
658
659
660
661
662
663
664
665
666
667
668
669
670
671
# File 'proto_docs/google/cloud/aiplatform/v1/content.rb', line 632

class SafetyRating
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Harm probability levels in the content.
  module HarmProbability
    # Harm probability unspecified.
    HARM_PROBABILITY_UNSPECIFIED = 0

    # Negligible level of harm.
    NEGLIGIBLE = 1

    # Low level of harm.
    LOW = 2

    # Medium level of harm.
    MEDIUM = 3

    # High level of harm.
    HIGH = 4
  end

  # Harm severity levels.
  module HarmSeverity
    # Harm severity unspecified.
    HARM_SEVERITY_UNSPECIFIED = 0

    # Negligible level of harm severity.
    HARM_SEVERITY_NEGLIGIBLE = 1

    # Low level of harm severity.
    HARM_SEVERITY_LOW = 2

    # Medium level of harm severity.
    HARM_SEVERITY_MEDIUM = 3

    # High level of harm severity.
    HARM_SEVERITY_HIGH = 4
  end
end

#severity_score::Float (readonly)

Returns Output only. Harm severity score.

Returns:

  • (::Float)

    Output only. Harm severity score.



632
633
634
635
636
637
638
639
640
641
642
643
644
645
646
647
648
649
650
651
652
653
654
655
656
657
658
659
660
661
662
663
664
665
666
667
668
669
670
671
# File 'proto_docs/google/cloud/aiplatform/v1/content.rb', line 632

class SafetyRating
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Harm probability levels in the content.
  module HarmProbability
    # Harm probability unspecified.
    HARM_PROBABILITY_UNSPECIFIED = 0

    # Negligible level of harm.
    NEGLIGIBLE = 1

    # Low level of harm.
    LOW = 2

    # Medium level of harm.
    MEDIUM = 3

    # High level of harm.
    HIGH = 4
  end

  # Harm severity levels.
  module HarmSeverity
    # Harm severity unspecified.
    HARM_SEVERITY_UNSPECIFIED = 0

    # Negligible level of harm severity.
    HARM_SEVERITY_NEGLIGIBLE = 1

    # Low level of harm severity.
    HARM_SEVERITY_LOW = 2

    # Medium level of harm severity.
    HARM_SEVERITY_MEDIUM = 3

    # High level of harm severity.
    HARM_SEVERITY_HIGH = 4
  end
end