Class: Google::Cloud::AIPlatform::V1::SessionEvent

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/aiplatform/v1/session.rb

Overview

An event represents a message from either the user or agent.

Instance Attribute Summary collapse

Instance Attribute Details

#actions::Google::Cloud::AIPlatform::V1::EventActions

Returns Optional. Actions executed by the agent.

Returns:



115
116
117
118
# File 'proto_docs/google/cloud/aiplatform/v1/session.rb', line 115

class SessionEvent
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#author::String

Returns Required. The name of the agent that sent the event, or user.

Returns:

  • (::String)

    Required. The name of the agent that sent the event, or user.



115
116
117
118
# File 'proto_docs/google/cloud/aiplatform/v1/session.rb', line 115

class SessionEvent
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#content::Google::Cloud::AIPlatform::V1::Content

Returns Optional. Content of the event provided by the author.

Returns:



115
116
117
118
# File 'proto_docs/google/cloud/aiplatform/v1/session.rb', line 115

class SessionEvent
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#error_code::String

Returns Optional. Error code if the response is an error. Code varies by model.

Returns:

  • (::String)

    Optional. Error code if the response is an error. Code varies by model.



115
116
117
118
# File 'proto_docs/google/cloud/aiplatform/v1/session.rb', line 115

class SessionEvent
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#error_message::String

Returns Optional. Error message if the response is an error.

Returns:

  • (::String)

    Optional. Error message if the response is an error.



115
116
117
118
# File 'proto_docs/google/cloud/aiplatform/v1/session.rb', line 115

class SessionEvent
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#event_metadata::Google::Cloud::AIPlatform::V1::EventMetadata

Returns Optional. Metadata relating to this event.

Returns:



115
116
117
118
# File 'proto_docs/google/cloud/aiplatform/v1/session.rb', line 115

class SessionEvent
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#invocation_id::String

Returns Required. The invocation id of the event, multiple events can have the same invocation id.

Returns:

  • (::String)

    Required. The invocation id of the event, multiple events can have the same invocation id.



115
116
117
118
# File 'proto_docs/google/cloud/aiplatform/v1/session.rb', line 115

class SessionEvent
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#name::String

Returns Identifier. The resource name of the event. Format:projects/{project}/locations/{location}/reasoningEngines/{reasoning_engine}/sessions/{session}/events/{event}.

Returns:

  • (::String)

    Identifier. The resource name of the event. Format:projects/{project}/locations/{location}/reasoningEngines/{reasoning_engine}/sessions/{session}/events/{event}.



115
116
117
118
# File 'proto_docs/google/cloud/aiplatform/v1/session.rb', line 115

class SessionEvent
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#raw_event::Google::Protobuf::Struct

Returns Optional. Weakly typed raw event data in proto struct format.

Returns:



115
116
117
118
# File 'proto_docs/google/cloud/aiplatform/v1/session.rb', line 115

class SessionEvent
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#timestamp::Google::Protobuf::Timestamp

Returns Required. Timestamp when the event was created on client side.

Returns:



115
116
117
118
# File 'proto_docs/google/cloud/aiplatform/v1/session.rb', line 115

class SessionEvent
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end