Class: Google::Cloud::AIPlatform::V1::SupervisedTuningSpec
- Inherits:
-
Object
- Object
- Google::Cloud::AIPlatform::V1::SupervisedTuningSpec
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/aiplatform/v1/tuning_job.rb
Overview
Tuning Spec for Supervised Tuning for first party models.
Instance Attribute Summary collapse
-
#evaluation_config ⇒ ::Google::Cloud::AIPlatform::V1::EvaluationConfig
Optional.
-
#export_last_checkpoint_only ⇒ ::Boolean
Optional.
-
#hyper_parameters ⇒ ::Google::Cloud::AIPlatform::V1::SupervisedHyperParameters
Optional.
-
#training_dataset_uri ⇒ ::String
Required.
-
#validation_dataset_uri ⇒ ::String
Optional.
Instance Attribute Details
#evaluation_config ⇒ ::Google::Cloud::AIPlatform::V1::EvaluationConfig
Returns Optional. Evaluation Config for Tuning Job.
333 334 335 336 |
# File 'proto_docs/google/cloud/aiplatform/v1/tuning_job.rb', line 333 class SupervisedTuningSpec include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#export_last_checkpoint_only ⇒ ::Boolean
Returns Optional. If set to true, disable intermediate checkpoints for SFT and only the last checkpoint will be exported. Otherwise, enable intermediate checkpoints for SFT. Default is false.
333 334 335 336 |
# File 'proto_docs/google/cloud/aiplatform/v1/tuning_job.rb', line 333 class SupervisedTuningSpec include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#hyper_parameters ⇒ ::Google::Cloud::AIPlatform::V1::SupervisedHyperParameters
Returns Optional. Hyperparameters for SFT.
333 334 335 336 |
# File 'proto_docs/google/cloud/aiplatform/v1/tuning_job.rb', line 333 class SupervisedTuningSpec include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#training_dataset_uri ⇒ ::String
Returns Required. Cloud Storage path to file containing training dataset for tuning. The dataset must be formatted as a JSONL file.
333 334 335 336 |
# File 'proto_docs/google/cloud/aiplatform/v1/tuning_job.rb', line 333 class SupervisedTuningSpec include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#validation_dataset_uri ⇒ ::String
Returns Optional. Cloud Storage path to file containing validation dataset for tuning. The dataset must be formatted as a JSONL file.
333 334 335 336 |
# File 'proto_docs/google/cloud/aiplatform/v1/tuning_job.rb', line 333 class SupervisedTuningSpec include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |