Class: Google::Cloud::AIPlatform::V1::Tool
- Inherits:
-
Object
- Object
- Google::Cloud::AIPlatform::V1::Tool
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/aiplatform/v1/tool.rb
Overview
Tool details that the model may use to generate response.
A Tool is a piece of code that enables the system to interact with
external systems to perform an action, or set of actions, outside of
knowledge and scope of the model. A Tool object should contain exactly
one type of Tool (e.g FunctionDeclaration, Retrieval or
GoogleSearchRetrieval).
Defined Under Namespace
Modules: PhishBlockThreshold Classes: CodeExecution, ComputerUse, GoogleSearch, ParallelAiSearch
Instance Attribute Summary collapse
-
#code_execution ⇒ ::Google::Cloud::AIPlatform::V1::Tool::CodeExecution
Optional.
-
#computer_use ⇒ ::Google::Cloud::AIPlatform::V1::Tool::ComputerUse
Optional.
-
#enterprise_web_search ⇒ ::Google::Cloud::AIPlatform::V1::EnterpriseWebSearch
Optional.
-
#function_declarations ⇒ ::Array<::Google::Cloud::AIPlatform::V1::FunctionDeclaration>
Optional.
-
#google_maps ⇒ ::Google::Cloud::AIPlatform::V1::GoogleMaps
Optional.
-
#google_search ⇒ ::Google::Cloud::AIPlatform::V1::Tool::GoogleSearch
Optional.
-
#google_search_retrieval ⇒ ::Google::Cloud::AIPlatform::V1::GoogleSearchRetrieval
Optional.
-
#parallel_ai_search ⇒ ::Google::Cloud::AIPlatform::V1::Tool::ParallelAiSearch
Optional.
-
#retrieval ⇒ ::Google::Cloud::AIPlatform::V1::Retrieval
Optional.
-
#url_context ⇒ ::Google::Cloud::AIPlatform::V1::UrlContext
Optional.
Instance Attribute Details
#code_execution ⇒ ::Google::Cloud::AIPlatform::V1::Tool::CodeExecution
Returns Optional. CodeExecution tool type. Enables the model to execute code as part of generation.
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 |
# File 'proto_docs/google/cloud/aiplatform/v1/tool.rb', line 81 class Tool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # GoogleSearch tool type. # Tool to support Google Search in Model. Powered by Google. # @!attribute [rw] exclude_domains # @return [::Array<::String>] # Optional. List of domains to be excluded from the search results. # The default limit is 2000 domains. # Example: ["amazon.com", "facebook.com"]. # @!attribute [rw] blocking_confidence # @return [::Google::Cloud::AIPlatform::V1::Tool::PhishBlockThreshold] # Optional. Sites with confidence level chosen & above this value will be # blocked from the search results. class GoogleSearch include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # ParallelAiSearch tool type. # A tool that uses the Parallel.ai search engine for grounding. # @!attribute [rw] api_key # @return [::String] # Optional. The API key for ParallelAiSearch. # If an API key is not provided, the system will attempt to verify access # by checking for an active Parallel.ai subscription through the Google # Cloud Marketplace. # See https://docs.parallel.ai/search/search-quickstart for more details. # @!attribute [rw] custom_configs # @return [::Google::Protobuf::Struct] # Optional. Custom configs for ParallelAiSearch. # This field can be used to pass any parameter from the Parallel.ai # Search API. # See the Parallel.ai documentation for the full list of available # parameters and their usage: # https://docs.parallel.ai/api-reference/search-beta/search # Currently only `source_policy`, `excerpts`, `max_results`, `mode`, # `fetch_policy` can be set via this field. For example: # { # "source_policy": { # "include_domains": ["google.com", "wikipedia.org"], # "exclude_domains": ["example.com"] # }, # "fetch_policy": { # "max_age_seconds": 3600 # } # } class ParallelAiSearch include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Tool that executes code generated by the model, and automatically returns # the result to the model. # # See also [ExecutableCode]and [CodeExecutionResult] which are input and # output to this tool. class CodeExecution include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Tool to support computer use. # @!attribute [rw] environment # @return [::Google::Cloud::AIPlatform::V1::Tool::ComputerUse::Environment] # Required. The environment being operated. # @!attribute [rw] excluded_predefined_functions # @return [::Array<::String>] # Optional. By default, [predefined # functions](https://cloud.google.com/vertex-ai/generative-ai/docs/computer-use#supported-actions) # are included in the final model call. Some of them can be explicitly # excluded from being automatically included. This can serve two purposes: # 1. Using a more restricted / different action space. # 2. Improving the definitions / instructions of predefined functions. class ComputerUse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents the environment being operated, such as a web browser. module Environment # Defaults to browser. ENVIRONMENT_UNSPECIFIED = 0 # Operates in a web browser. ENVIRONMENT_BROWSER = 1 end end # These are available confidence level user can set to block malicious urls # with chosen confidence and above. For understanding different confidence of # webrisk, please refer to # https://cloud.google.com/web-risk/docs/reference/rpc/google.cloud.webrisk.v1eap1#confidencelevel module PhishBlockThreshold # Defaults to unspecified. PHISH_BLOCK_THRESHOLD_UNSPECIFIED = 0 # Blocks Low and above confidence URL that is risky. BLOCK_LOW_AND_ABOVE = 30 # Blocks Medium and above confidence URL that is risky. BLOCK_MEDIUM_AND_ABOVE = 40 # Blocks High and above confidence URL that is risky. BLOCK_HIGH_AND_ABOVE = 50 # Blocks Higher and above confidence URL that is risky. BLOCK_HIGHER_AND_ABOVE = 55 # Blocks Very high and above confidence URL that is risky. BLOCK_VERY_HIGH_AND_ABOVE = 60 # Blocks Extremely high confidence URL that is risky. BLOCK_ONLY_EXTREMELY_HIGH = 100 end end |
#computer_use ⇒ ::Google::Cloud::AIPlatform::V1::Tool::ComputerUse
Returns Optional. Tool to support the model interacting directly with the computer. If enabled, it automatically populates computer-use specific Function Declarations.
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 |
# File 'proto_docs/google/cloud/aiplatform/v1/tool.rb', line 81 class Tool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # GoogleSearch tool type. # Tool to support Google Search in Model. Powered by Google. # @!attribute [rw] exclude_domains # @return [::Array<::String>] # Optional. List of domains to be excluded from the search results. # The default limit is 2000 domains. # Example: ["amazon.com", "facebook.com"]. # @!attribute [rw] blocking_confidence # @return [::Google::Cloud::AIPlatform::V1::Tool::PhishBlockThreshold] # Optional. Sites with confidence level chosen & above this value will be # blocked from the search results. class GoogleSearch include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # ParallelAiSearch tool type. # A tool that uses the Parallel.ai search engine for grounding. # @!attribute [rw] api_key # @return [::String] # Optional. The API key for ParallelAiSearch. # If an API key is not provided, the system will attempt to verify access # by checking for an active Parallel.ai subscription through the Google # Cloud Marketplace. # See https://docs.parallel.ai/search/search-quickstart for more details. # @!attribute [rw] custom_configs # @return [::Google::Protobuf::Struct] # Optional. Custom configs for ParallelAiSearch. # This field can be used to pass any parameter from the Parallel.ai # Search API. # See the Parallel.ai documentation for the full list of available # parameters and their usage: # https://docs.parallel.ai/api-reference/search-beta/search # Currently only `source_policy`, `excerpts`, `max_results`, `mode`, # `fetch_policy` can be set via this field. For example: # { # "source_policy": { # "include_domains": ["google.com", "wikipedia.org"], # "exclude_domains": ["example.com"] # }, # "fetch_policy": { # "max_age_seconds": 3600 # } # } class ParallelAiSearch include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Tool that executes code generated by the model, and automatically returns # the result to the model. # # See also [ExecutableCode]and [CodeExecutionResult] which are input and # output to this tool. class CodeExecution include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Tool to support computer use. # @!attribute [rw] environment # @return [::Google::Cloud::AIPlatform::V1::Tool::ComputerUse::Environment] # Required. The environment being operated. # @!attribute [rw] excluded_predefined_functions # @return [::Array<::String>] # Optional. By default, [predefined # functions](https://cloud.google.com/vertex-ai/generative-ai/docs/computer-use#supported-actions) # are included in the final model call. Some of them can be explicitly # excluded from being automatically included. This can serve two purposes: # 1. Using a more restricted / different action space. # 2. Improving the definitions / instructions of predefined functions. class ComputerUse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents the environment being operated, such as a web browser. module Environment # Defaults to browser. ENVIRONMENT_UNSPECIFIED = 0 # Operates in a web browser. ENVIRONMENT_BROWSER = 1 end end # These are available confidence level user can set to block malicious urls # with chosen confidence and above. For understanding different confidence of # webrisk, please refer to # https://cloud.google.com/web-risk/docs/reference/rpc/google.cloud.webrisk.v1eap1#confidencelevel module PhishBlockThreshold # Defaults to unspecified. PHISH_BLOCK_THRESHOLD_UNSPECIFIED = 0 # Blocks Low and above confidence URL that is risky. BLOCK_LOW_AND_ABOVE = 30 # Blocks Medium and above confidence URL that is risky. BLOCK_MEDIUM_AND_ABOVE = 40 # Blocks High and above confidence URL that is risky. BLOCK_HIGH_AND_ABOVE = 50 # Blocks Higher and above confidence URL that is risky. BLOCK_HIGHER_AND_ABOVE = 55 # Blocks Very high and above confidence URL that is risky. BLOCK_VERY_HIGH_AND_ABOVE = 60 # Blocks Extremely high confidence URL that is risky. BLOCK_ONLY_EXTREMELY_HIGH = 100 end end |
#enterprise_web_search ⇒ ::Google::Cloud::AIPlatform::V1::EnterpriseWebSearch
Returns Optional. Tool to support searching public web data, powered by Vertex AI Search and Sec4 compliance.
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 |
# File 'proto_docs/google/cloud/aiplatform/v1/tool.rb', line 81 class Tool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # GoogleSearch tool type. # Tool to support Google Search in Model. Powered by Google. # @!attribute [rw] exclude_domains # @return [::Array<::String>] # Optional. List of domains to be excluded from the search results. # The default limit is 2000 domains. # Example: ["amazon.com", "facebook.com"]. # @!attribute [rw] blocking_confidence # @return [::Google::Cloud::AIPlatform::V1::Tool::PhishBlockThreshold] # Optional. Sites with confidence level chosen & above this value will be # blocked from the search results. class GoogleSearch include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # ParallelAiSearch tool type. # A tool that uses the Parallel.ai search engine for grounding. # @!attribute [rw] api_key # @return [::String] # Optional. The API key for ParallelAiSearch. # If an API key is not provided, the system will attempt to verify access # by checking for an active Parallel.ai subscription through the Google # Cloud Marketplace. # See https://docs.parallel.ai/search/search-quickstart for more details. # @!attribute [rw] custom_configs # @return [::Google::Protobuf::Struct] # Optional. Custom configs for ParallelAiSearch. # This field can be used to pass any parameter from the Parallel.ai # Search API. # See the Parallel.ai documentation for the full list of available # parameters and their usage: # https://docs.parallel.ai/api-reference/search-beta/search # Currently only `source_policy`, `excerpts`, `max_results`, `mode`, # `fetch_policy` can be set via this field. For example: # { # "source_policy": { # "include_domains": ["google.com", "wikipedia.org"], # "exclude_domains": ["example.com"] # }, # "fetch_policy": { # "max_age_seconds": 3600 # } # } class ParallelAiSearch include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Tool that executes code generated by the model, and automatically returns # the result to the model. # # See also [ExecutableCode]and [CodeExecutionResult] which are input and # output to this tool. class CodeExecution include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Tool to support computer use. # @!attribute [rw] environment # @return [::Google::Cloud::AIPlatform::V1::Tool::ComputerUse::Environment] # Required. The environment being operated. # @!attribute [rw] excluded_predefined_functions # @return [::Array<::String>] # Optional. By default, [predefined # functions](https://cloud.google.com/vertex-ai/generative-ai/docs/computer-use#supported-actions) # are included in the final model call. Some of them can be explicitly # excluded from being automatically included. This can serve two purposes: # 1. Using a more restricted / different action space. # 2. Improving the definitions / instructions of predefined functions. class ComputerUse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents the environment being operated, such as a web browser. module Environment # Defaults to browser. ENVIRONMENT_UNSPECIFIED = 0 # Operates in a web browser. ENVIRONMENT_BROWSER = 1 end end # These are available confidence level user can set to block malicious urls # with chosen confidence and above. For understanding different confidence of # webrisk, please refer to # https://cloud.google.com/web-risk/docs/reference/rpc/google.cloud.webrisk.v1eap1#confidencelevel module PhishBlockThreshold # Defaults to unspecified. PHISH_BLOCK_THRESHOLD_UNSPECIFIED = 0 # Blocks Low and above confidence URL that is risky. BLOCK_LOW_AND_ABOVE = 30 # Blocks Medium and above confidence URL that is risky. BLOCK_MEDIUM_AND_ABOVE = 40 # Blocks High and above confidence URL that is risky. BLOCK_HIGH_AND_ABOVE = 50 # Blocks Higher and above confidence URL that is risky. BLOCK_HIGHER_AND_ABOVE = 55 # Blocks Very high and above confidence URL that is risky. BLOCK_VERY_HIGH_AND_ABOVE = 60 # Blocks Extremely high confidence URL that is risky. BLOCK_ONLY_EXTREMELY_HIGH = 100 end end |
#function_declarations ⇒ ::Array<::Google::Cloud::AIPlatform::V1::FunctionDeclaration>
Returns Optional. Function tool type. One or more function declarations to be passed to the model along with the current user query. Model may decide to call a subset of these functions by populating FunctionCall in the response. User should provide a FunctionResponse for each function call in the next turn. Based on the function responses, Model will generate the final response back to the user. Maximum 128 function declarations can be provided.
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 |
# File 'proto_docs/google/cloud/aiplatform/v1/tool.rb', line 81 class Tool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # GoogleSearch tool type. # Tool to support Google Search in Model. Powered by Google. # @!attribute [rw] exclude_domains # @return [::Array<::String>] # Optional. List of domains to be excluded from the search results. # The default limit is 2000 domains. # Example: ["amazon.com", "facebook.com"]. # @!attribute [rw] blocking_confidence # @return [::Google::Cloud::AIPlatform::V1::Tool::PhishBlockThreshold] # Optional. Sites with confidence level chosen & above this value will be # blocked from the search results. class GoogleSearch include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # ParallelAiSearch tool type. # A tool that uses the Parallel.ai search engine for grounding. # @!attribute [rw] api_key # @return [::String] # Optional. The API key for ParallelAiSearch. # If an API key is not provided, the system will attempt to verify access # by checking for an active Parallel.ai subscription through the Google # Cloud Marketplace. # See https://docs.parallel.ai/search/search-quickstart for more details. # @!attribute [rw] custom_configs # @return [::Google::Protobuf::Struct] # Optional. Custom configs for ParallelAiSearch. # This field can be used to pass any parameter from the Parallel.ai # Search API. # See the Parallel.ai documentation for the full list of available # parameters and their usage: # https://docs.parallel.ai/api-reference/search-beta/search # Currently only `source_policy`, `excerpts`, `max_results`, `mode`, # `fetch_policy` can be set via this field. For example: # { # "source_policy": { # "include_domains": ["google.com", "wikipedia.org"], # "exclude_domains": ["example.com"] # }, # "fetch_policy": { # "max_age_seconds": 3600 # } # } class ParallelAiSearch include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Tool that executes code generated by the model, and automatically returns # the result to the model. # # See also [ExecutableCode]and [CodeExecutionResult] which are input and # output to this tool. class CodeExecution include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Tool to support computer use. # @!attribute [rw] environment # @return [::Google::Cloud::AIPlatform::V1::Tool::ComputerUse::Environment] # Required. The environment being operated. # @!attribute [rw] excluded_predefined_functions # @return [::Array<::String>] # Optional. By default, [predefined # functions](https://cloud.google.com/vertex-ai/generative-ai/docs/computer-use#supported-actions) # are included in the final model call. Some of them can be explicitly # excluded from being automatically included. This can serve two purposes: # 1. Using a more restricted / different action space. # 2. Improving the definitions / instructions of predefined functions. class ComputerUse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents the environment being operated, such as a web browser. module Environment # Defaults to browser. ENVIRONMENT_UNSPECIFIED = 0 # Operates in a web browser. ENVIRONMENT_BROWSER = 1 end end # These are available confidence level user can set to block malicious urls # with chosen confidence and above. For understanding different confidence of # webrisk, please refer to # https://cloud.google.com/web-risk/docs/reference/rpc/google.cloud.webrisk.v1eap1#confidencelevel module PhishBlockThreshold # Defaults to unspecified. PHISH_BLOCK_THRESHOLD_UNSPECIFIED = 0 # Blocks Low and above confidence URL that is risky. BLOCK_LOW_AND_ABOVE = 30 # Blocks Medium and above confidence URL that is risky. BLOCK_MEDIUM_AND_ABOVE = 40 # Blocks High and above confidence URL that is risky. BLOCK_HIGH_AND_ABOVE = 50 # Blocks Higher and above confidence URL that is risky. BLOCK_HIGHER_AND_ABOVE = 55 # Blocks Very high and above confidence URL that is risky. BLOCK_VERY_HIGH_AND_ABOVE = 60 # Blocks Extremely high confidence URL that is risky. BLOCK_ONLY_EXTREMELY_HIGH = 100 end end |
#google_maps ⇒ ::Google::Cloud::AIPlatform::V1::GoogleMaps
Returns Optional. GoogleMaps tool type. Tool to support Google Maps in Model.
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 |
# File 'proto_docs/google/cloud/aiplatform/v1/tool.rb', line 81 class Tool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # GoogleSearch tool type. # Tool to support Google Search in Model. Powered by Google. # @!attribute [rw] exclude_domains # @return [::Array<::String>] # Optional. List of domains to be excluded from the search results. # The default limit is 2000 domains. # Example: ["amazon.com", "facebook.com"]. # @!attribute [rw] blocking_confidence # @return [::Google::Cloud::AIPlatform::V1::Tool::PhishBlockThreshold] # Optional. Sites with confidence level chosen & above this value will be # blocked from the search results. class GoogleSearch include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # ParallelAiSearch tool type. # A tool that uses the Parallel.ai search engine for grounding. # @!attribute [rw] api_key # @return [::String] # Optional. The API key for ParallelAiSearch. # If an API key is not provided, the system will attempt to verify access # by checking for an active Parallel.ai subscription through the Google # Cloud Marketplace. # See https://docs.parallel.ai/search/search-quickstart for more details. # @!attribute [rw] custom_configs # @return [::Google::Protobuf::Struct] # Optional. Custom configs for ParallelAiSearch. # This field can be used to pass any parameter from the Parallel.ai # Search API. # See the Parallel.ai documentation for the full list of available # parameters and their usage: # https://docs.parallel.ai/api-reference/search-beta/search # Currently only `source_policy`, `excerpts`, `max_results`, `mode`, # `fetch_policy` can be set via this field. For example: # { # "source_policy": { # "include_domains": ["google.com", "wikipedia.org"], # "exclude_domains": ["example.com"] # }, # "fetch_policy": { # "max_age_seconds": 3600 # } # } class ParallelAiSearch include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Tool that executes code generated by the model, and automatically returns # the result to the model. # # See also [ExecutableCode]and [CodeExecutionResult] which are input and # output to this tool. class CodeExecution include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Tool to support computer use. # @!attribute [rw] environment # @return [::Google::Cloud::AIPlatform::V1::Tool::ComputerUse::Environment] # Required. The environment being operated. # @!attribute [rw] excluded_predefined_functions # @return [::Array<::String>] # Optional. By default, [predefined # functions](https://cloud.google.com/vertex-ai/generative-ai/docs/computer-use#supported-actions) # are included in the final model call. Some of them can be explicitly # excluded from being automatically included. This can serve two purposes: # 1. Using a more restricted / different action space. # 2. Improving the definitions / instructions of predefined functions. class ComputerUse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents the environment being operated, such as a web browser. module Environment # Defaults to browser. ENVIRONMENT_UNSPECIFIED = 0 # Operates in a web browser. ENVIRONMENT_BROWSER = 1 end end # These are available confidence level user can set to block malicious urls # with chosen confidence and above. For understanding different confidence of # webrisk, please refer to # https://cloud.google.com/web-risk/docs/reference/rpc/google.cloud.webrisk.v1eap1#confidencelevel module PhishBlockThreshold # Defaults to unspecified. PHISH_BLOCK_THRESHOLD_UNSPECIFIED = 0 # Blocks Low and above confidence URL that is risky. BLOCK_LOW_AND_ABOVE = 30 # Blocks Medium and above confidence URL that is risky. BLOCK_MEDIUM_AND_ABOVE = 40 # Blocks High and above confidence URL that is risky. BLOCK_HIGH_AND_ABOVE = 50 # Blocks Higher and above confidence URL that is risky. BLOCK_HIGHER_AND_ABOVE = 55 # Blocks Very high and above confidence URL that is risky. BLOCK_VERY_HIGH_AND_ABOVE = 60 # Blocks Extremely high confidence URL that is risky. BLOCK_ONLY_EXTREMELY_HIGH = 100 end end |
#google_search ⇒ ::Google::Cloud::AIPlatform::V1::Tool::GoogleSearch
Returns Optional. GoogleSearch tool type. Tool to support Google Search in Model. Powered by Google.
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 |
# File 'proto_docs/google/cloud/aiplatform/v1/tool.rb', line 81 class Tool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # GoogleSearch tool type. # Tool to support Google Search in Model. Powered by Google. # @!attribute [rw] exclude_domains # @return [::Array<::String>] # Optional. List of domains to be excluded from the search results. # The default limit is 2000 domains. # Example: ["amazon.com", "facebook.com"]. # @!attribute [rw] blocking_confidence # @return [::Google::Cloud::AIPlatform::V1::Tool::PhishBlockThreshold] # Optional. Sites with confidence level chosen & above this value will be # blocked from the search results. class GoogleSearch include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # ParallelAiSearch tool type. # A tool that uses the Parallel.ai search engine for grounding. # @!attribute [rw] api_key # @return [::String] # Optional. The API key for ParallelAiSearch. # If an API key is not provided, the system will attempt to verify access # by checking for an active Parallel.ai subscription through the Google # Cloud Marketplace. # See https://docs.parallel.ai/search/search-quickstart for more details. # @!attribute [rw] custom_configs # @return [::Google::Protobuf::Struct] # Optional. Custom configs for ParallelAiSearch. # This field can be used to pass any parameter from the Parallel.ai # Search API. # See the Parallel.ai documentation for the full list of available # parameters and their usage: # https://docs.parallel.ai/api-reference/search-beta/search # Currently only `source_policy`, `excerpts`, `max_results`, `mode`, # `fetch_policy` can be set via this field. For example: # { # "source_policy": { # "include_domains": ["google.com", "wikipedia.org"], # "exclude_domains": ["example.com"] # }, # "fetch_policy": { # "max_age_seconds": 3600 # } # } class ParallelAiSearch include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Tool that executes code generated by the model, and automatically returns # the result to the model. # # See also [ExecutableCode]and [CodeExecutionResult] which are input and # output to this tool. class CodeExecution include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Tool to support computer use. # @!attribute [rw] environment # @return [::Google::Cloud::AIPlatform::V1::Tool::ComputerUse::Environment] # Required. The environment being operated. # @!attribute [rw] excluded_predefined_functions # @return [::Array<::String>] # Optional. By default, [predefined # functions](https://cloud.google.com/vertex-ai/generative-ai/docs/computer-use#supported-actions) # are included in the final model call. Some of them can be explicitly # excluded from being automatically included. This can serve two purposes: # 1. Using a more restricted / different action space. # 2. Improving the definitions / instructions of predefined functions. class ComputerUse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents the environment being operated, such as a web browser. module Environment # Defaults to browser. ENVIRONMENT_UNSPECIFIED = 0 # Operates in a web browser. ENVIRONMENT_BROWSER = 1 end end # These are available confidence level user can set to block malicious urls # with chosen confidence and above. For understanding different confidence of # webrisk, please refer to # https://cloud.google.com/web-risk/docs/reference/rpc/google.cloud.webrisk.v1eap1#confidencelevel module PhishBlockThreshold # Defaults to unspecified. PHISH_BLOCK_THRESHOLD_UNSPECIFIED = 0 # Blocks Low and above confidence URL that is risky. BLOCK_LOW_AND_ABOVE = 30 # Blocks Medium and above confidence URL that is risky. BLOCK_MEDIUM_AND_ABOVE = 40 # Blocks High and above confidence URL that is risky. BLOCK_HIGH_AND_ABOVE = 50 # Blocks Higher and above confidence URL that is risky. BLOCK_HIGHER_AND_ABOVE = 55 # Blocks Very high and above confidence URL that is risky. BLOCK_VERY_HIGH_AND_ABOVE = 60 # Blocks Extremely high confidence URL that is risky. BLOCK_ONLY_EXTREMELY_HIGH = 100 end end |
#google_search_retrieval ⇒ ::Google::Cloud::AIPlatform::V1::GoogleSearchRetrieval
Returns Optional. GoogleSearchRetrieval tool type. Specialized retrieval tool that is powered by Google search.
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 |
# File 'proto_docs/google/cloud/aiplatform/v1/tool.rb', line 81 class Tool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # GoogleSearch tool type. # Tool to support Google Search in Model. Powered by Google. # @!attribute [rw] exclude_domains # @return [::Array<::String>] # Optional. List of domains to be excluded from the search results. # The default limit is 2000 domains. # Example: ["amazon.com", "facebook.com"]. # @!attribute [rw] blocking_confidence # @return [::Google::Cloud::AIPlatform::V1::Tool::PhishBlockThreshold] # Optional. Sites with confidence level chosen & above this value will be # blocked from the search results. class GoogleSearch include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # ParallelAiSearch tool type. # A tool that uses the Parallel.ai search engine for grounding. # @!attribute [rw] api_key # @return [::String] # Optional. The API key for ParallelAiSearch. # If an API key is not provided, the system will attempt to verify access # by checking for an active Parallel.ai subscription through the Google # Cloud Marketplace. # See https://docs.parallel.ai/search/search-quickstart for more details. # @!attribute [rw] custom_configs # @return [::Google::Protobuf::Struct] # Optional. Custom configs for ParallelAiSearch. # This field can be used to pass any parameter from the Parallel.ai # Search API. # See the Parallel.ai documentation for the full list of available # parameters and their usage: # https://docs.parallel.ai/api-reference/search-beta/search # Currently only `source_policy`, `excerpts`, `max_results`, `mode`, # `fetch_policy` can be set via this field. For example: # { # "source_policy": { # "include_domains": ["google.com", "wikipedia.org"], # "exclude_domains": ["example.com"] # }, # "fetch_policy": { # "max_age_seconds": 3600 # } # } class ParallelAiSearch include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Tool that executes code generated by the model, and automatically returns # the result to the model. # # See also [ExecutableCode]and [CodeExecutionResult] which are input and # output to this tool. class CodeExecution include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Tool to support computer use. # @!attribute [rw] environment # @return [::Google::Cloud::AIPlatform::V1::Tool::ComputerUse::Environment] # Required. The environment being operated. # @!attribute [rw] excluded_predefined_functions # @return [::Array<::String>] # Optional. By default, [predefined # functions](https://cloud.google.com/vertex-ai/generative-ai/docs/computer-use#supported-actions) # are included in the final model call. Some of them can be explicitly # excluded from being automatically included. This can serve two purposes: # 1. Using a more restricted / different action space. # 2. Improving the definitions / instructions of predefined functions. class ComputerUse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents the environment being operated, such as a web browser. module Environment # Defaults to browser. ENVIRONMENT_UNSPECIFIED = 0 # Operates in a web browser. ENVIRONMENT_BROWSER = 1 end end # These are available confidence level user can set to block malicious urls # with chosen confidence and above. For understanding different confidence of # webrisk, please refer to # https://cloud.google.com/web-risk/docs/reference/rpc/google.cloud.webrisk.v1eap1#confidencelevel module PhishBlockThreshold # Defaults to unspecified. PHISH_BLOCK_THRESHOLD_UNSPECIFIED = 0 # Blocks Low and above confidence URL that is risky. BLOCK_LOW_AND_ABOVE = 30 # Blocks Medium and above confidence URL that is risky. BLOCK_MEDIUM_AND_ABOVE = 40 # Blocks High and above confidence URL that is risky. BLOCK_HIGH_AND_ABOVE = 50 # Blocks Higher and above confidence URL that is risky. BLOCK_HIGHER_AND_ABOVE = 55 # Blocks Very high and above confidence URL that is risky. BLOCK_VERY_HIGH_AND_ABOVE = 60 # Blocks Extremely high confidence URL that is risky. BLOCK_ONLY_EXTREMELY_HIGH = 100 end end |
#parallel_ai_search ⇒ ::Google::Cloud::AIPlatform::V1::Tool::ParallelAiSearch
Returns Optional. If specified, Vertex AI will use Parallel.ai to search for information to answer user queries. The search results will be grounded on Parallel.ai and presented to the model for response generation.
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 |
# File 'proto_docs/google/cloud/aiplatform/v1/tool.rb', line 81 class Tool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # GoogleSearch tool type. # Tool to support Google Search in Model. Powered by Google. # @!attribute [rw] exclude_domains # @return [::Array<::String>] # Optional. List of domains to be excluded from the search results. # The default limit is 2000 domains. # Example: ["amazon.com", "facebook.com"]. # @!attribute [rw] blocking_confidence # @return [::Google::Cloud::AIPlatform::V1::Tool::PhishBlockThreshold] # Optional. Sites with confidence level chosen & above this value will be # blocked from the search results. class GoogleSearch include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # ParallelAiSearch tool type. # A tool that uses the Parallel.ai search engine for grounding. # @!attribute [rw] api_key # @return [::String] # Optional. The API key for ParallelAiSearch. # If an API key is not provided, the system will attempt to verify access # by checking for an active Parallel.ai subscription through the Google # Cloud Marketplace. # See https://docs.parallel.ai/search/search-quickstart for more details. # @!attribute [rw] custom_configs # @return [::Google::Protobuf::Struct] # Optional. Custom configs for ParallelAiSearch. # This field can be used to pass any parameter from the Parallel.ai # Search API. # See the Parallel.ai documentation for the full list of available # parameters and their usage: # https://docs.parallel.ai/api-reference/search-beta/search # Currently only `source_policy`, `excerpts`, `max_results`, `mode`, # `fetch_policy` can be set via this field. For example: # { # "source_policy": { # "include_domains": ["google.com", "wikipedia.org"], # "exclude_domains": ["example.com"] # }, # "fetch_policy": { # "max_age_seconds": 3600 # } # } class ParallelAiSearch include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Tool that executes code generated by the model, and automatically returns # the result to the model. # # See also [ExecutableCode]and [CodeExecutionResult] which are input and # output to this tool. class CodeExecution include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Tool to support computer use. # @!attribute [rw] environment # @return [::Google::Cloud::AIPlatform::V1::Tool::ComputerUse::Environment] # Required. The environment being operated. # @!attribute [rw] excluded_predefined_functions # @return [::Array<::String>] # Optional. By default, [predefined # functions](https://cloud.google.com/vertex-ai/generative-ai/docs/computer-use#supported-actions) # are included in the final model call. Some of them can be explicitly # excluded from being automatically included. This can serve two purposes: # 1. Using a more restricted / different action space. # 2. Improving the definitions / instructions of predefined functions. class ComputerUse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents the environment being operated, such as a web browser. module Environment # Defaults to browser. ENVIRONMENT_UNSPECIFIED = 0 # Operates in a web browser. ENVIRONMENT_BROWSER = 1 end end # These are available confidence level user can set to block malicious urls # with chosen confidence and above. For understanding different confidence of # webrisk, please refer to # https://cloud.google.com/web-risk/docs/reference/rpc/google.cloud.webrisk.v1eap1#confidencelevel module PhishBlockThreshold # Defaults to unspecified. PHISH_BLOCK_THRESHOLD_UNSPECIFIED = 0 # Blocks Low and above confidence URL that is risky. BLOCK_LOW_AND_ABOVE = 30 # Blocks Medium and above confidence URL that is risky. BLOCK_MEDIUM_AND_ABOVE = 40 # Blocks High and above confidence URL that is risky. BLOCK_HIGH_AND_ABOVE = 50 # Blocks Higher and above confidence URL that is risky. BLOCK_HIGHER_AND_ABOVE = 55 # Blocks Very high and above confidence URL that is risky. BLOCK_VERY_HIGH_AND_ABOVE = 60 # Blocks Extremely high confidence URL that is risky. BLOCK_ONLY_EXTREMELY_HIGH = 100 end end |
#retrieval ⇒ ::Google::Cloud::AIPlatform::V1::Retrieval
Returns Optional. Retrieval tool type. System will always execute the provided retrieval tool(s) to get external knowledge to answer the prompt. Retrieval results are presented to the model for generation.
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 |
# File 'proto_docs/google/cloud/aiplatform/v1/tool.rb', line 81 class Tool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # GoogleSearch tool type. # Tool to support Google Search in Model. Powered by Google. # @!attribute [rw] exclude_domains # @return [::Array<::String>] # Optional. List of domains to be excluded from the search results. # The default limit is 2000 domains. # Example: ["amazon.com", "facebook.com"]. # @!attribute [rw] blocking_confidence # @return [::Google::Cloud::AIPlatform::V1::Tool::PhishBlockThreshold] # Optional. Sites with confidence level chosen & above this value will be # blocked from the search results. class GoogleSearch include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # ParallelAiSearch tool type. # A tool that uses the Parallel.ai search engine for grounding. # @!attribute [rw] api_key # @return [::String] # Optional. The API key for ParallelAiSearch. # If an API key is not provided, the system will attempt to verify access # by checking for an active Parallel.ai subscription through the Google # Cloud Marketplace. # See https://docs.parallel.ai/search/search-quickstart for more details. # @!attribute [rw] custom_configs # @return [::Google::Protobuf::Struct] # Optional. Custom configs for ParallelAiSearch. # This field can be used to pass any parameter from the Parallel.ai # Search API. # See the Parallel.ai documentation for the full list of available # parameters and their usage: # https://docs.parallel.ai/api-reference/search-beta/search # Currently only `source_policy`, `excerpts`, `max_results`, `mode`, # `fetch_policy` can be set via this field. For example: # { # "source_policy": { # "include_domains": ["google.com", "wikipedia.org"], # "exclude_domains": ["example.com"] # }, # "fetch_policy": { # "max_age_seconds": 3600 # } # } class ParallelAiSearch include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Tool that executes code generated by the model, and automatically returns # the result to the model. # # See also [ExecutableCode]and [CodeExecutionResult] which are input and # output to this tool. class CodeExecution include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Tool to support computer use. # @!attribute [rw] environment # @return [::Google::Cloud::AIPlatform::V1::Tool::ComputerUse::Environment] # Required. The environment being operated. # @!attribute [rw] excluded_predefined_functions # @return [::Array<::String>] # Optional. By default, [predefined # functions](https://cloud.google.com/vertex-ai/generative-ai/docs/computer-use#supported-actions) # are included in the final model call. Some of them can be explicitly # excluded from being automatically included. This can serve two purposes: # 1. Using a more restricted / different action space. # 2. Improving the definitions / instructions of predefined functions. class ComputerUse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents the environment being operated, such as a web browser. module Environment # Defaults to browser. ENVIRONMENT_UNSPECIFIED = 0 # Operates in a web browser. ENVIRONMENT_BROWSER = 1 end end # These are available confidence level user can set to block malicious urls # with chosen confidence and above. For understanding different confidence of # webrisk, please refer to # https://cloud.google.com/web-risk/docs/reference/rpc/google.cloud.webrisk.v1eap1#confidencelevel module PhishBlockThreshold # Defaults to unspecified. PHISH_BLOCK_THRESHOLD_UNSPECIFIED = 0 # Blocks Low and above confidence URL that is risky. BLOCK_LOW_AND_ABOVE = 30 # Blocks Medium and above confidence URL that is risky. BLOCK_MEDIUM_AND_ABOVE = 40 # Blocks High and above confidence URL that is risky. BLOCK_HIGH_AND_ABOVE = 50 # Blocks Higher and above confidence URL that is risky. BLOCK_HIGHER_AND_ABOVE = 55 # Blocks Very high and above confidence URL that is risky. BLOCK_VERY_HIGH_AND_ABOVE = 60 # Blocks Extremely high confidence URL that is risky. BLOCK_ONLY_EXTREMELY_HIGH = 100 end end |
#url_context ⇒ ::Google::Cloud::AIPlatform::V1::UrlContext
Returns Optional. Tool to support URL context retrieval.
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 |
# File 'proto_docs/google/cloud/aiplatform/v1/tool.rb', line 81 class Tool include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # GoogleSearch tool type. # Tool to support Google Search in Model. Powered by Google. # @!attribute [rw] exclude_domains # @return [::Array<::String>] # Optional. List of domains to be excluded from the search results. # The default limit is 2000 domains. # Example: ["amazon.com", "facebook.com"]. # @!attribute [rw] blocking_confidence # @return [::Google::Cloud::AIPlatform::V1::Tool::PhishBlockThreshold] # Optional. Sites with confidence level chosen & above this value will be # blocked from the search results. class GoogleSearch include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # ParallelAiSearch tool type. # A tool that uses the Parallel.ai search engine for grounding. # @!attribute [rw] api_key # @return [::String] # Optional. The API key for ParallelAiSearch. # If an API key is not provided, the system will attempt to verify access # by checking for an active Parallel.ai subscription through the Google # Cloud Marketplace. # See https://docs.parallel.ai/search/search-quickstart for more details. # @!attribute [rw] custom_configs # @return [::Google::Protobuf::Struct] # Optional. Custom configs for ParallelAiSearch. # This field can be used to pass any parameter from the Parallel.ai # Search API. # See the Parallel.ai documentation for the full list of available # parameters and their usage: # https://docs.parallel.ai/api-reference/search-beta/search # Currently only `source_policy`, `excerpts`, `max_results`, `mode`, # `fetch_policy` can be set via this field. For example: # { # "source_policy": { # "include_domains": ["google.com", "wikipedia.org"], # "exclude_domains": ["example.com"] # }, # "fetch_policy": { # "max_age_seconds": 3600 # } # } class ParallelAiSearch include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Tool that executes code generated by the model, and automatically returns # the result to the model. # # See also [ExecutableCode]and [CodeExecutionResult] which are input and # output to this tool. class CodeExecution include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Tool to support computer use. # @!attribute [rw] environment # @return [::Google::Cloud::AIPlatform::V1::Tool::ComputerUse::Environment] # Required. The environment being operated. # @!attribute [rw] excluded_predefined_functions # @return [::Array<::String>] # Optional. By default, [predefined # functions](https://cloud.google.com/vertex-ai/generative-ai/docs/computer-use#supported-actions) # are included in the final model call. Some of them can be explicitly # excluded from being automatically included. This can serve two purposes: # 1. Using a more restricted / different action space. # 2. Improving the definitions / instructions of predefined functions. class ComputerUse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents the environment being operated, such as a web browser. module Environment # Defaults to browser. ENVIRONMENT_UNSPECIFIED = 0 # Operates in a web browser. ENVIRONMENT_BROWSER = 1 end end # These are available confidence level user can set to block malicious urls # with chosen confidence and above. For understanding different confidence of # webrisk, please refer to # https://cloud.google.com/web-risk/docs/reference/rpc/google.cloud.webrisk.v1eap1#confidencelevel module PhishBlockThreshold # Defaults to unspecified. PHISH_BLOCK_THRESHOLD_UNSPECIFIED = 0 # Blocks Low and above confidence URL that is risky. BLOCK_LOW_AND_ABOVE = 30 # Blocks Medium and above confidence URL that is risky. BLOCK_MEDIUM_AND_ABOVE = 40 # Blocks High and above confidence URL that is risky. BLOCK_HIGH_AND_ABOVE = 50 # Blocks Higher and above confidence URL that is risky. BLOCK_HIGHER_AND_ABOVE = 55 # Blocks Very high and above confidence URL that is risky. BLOCK_VERY_HIGH_AND_ABOVE = 60 # Blocks Extremely high confidence URL that is risky. BLOCK_ONLY_EXTREMELY_HIGH = 100 end end |