Class: Google::Cloud::AIPlatform::V1::UpdateSessionRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/aiplatform/v1/session_service.rb

Overview

Request message for SessionService.UpdateSession.

Instance Attribute Summary collapse

Instance Attribute Details

#session::Google::Cloud::AIPlatform::V1::Session

Returns Required. The session to update. Format: projects/{project}/locations/{location}/reasoningEngines/{reasoning_engine}/sessions/{session}.

Returns:



139
140
141
142
# File 'proto_docs/google/cloud/aiplatform/v1/session_service.rb', line 139

class UpdateSessionRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#update_mask::Google::Protobuf::FieldMask

Returns Optional. Field mask is used to control which fields get updated. If the mask is not present, all fields will be updated.

Returns:

  • (::Google::Protobuf::FieldMask)

    Optional. Field mask is used to control which fields get updated. If the mask is not present, all fields will be updated.



139
140
141
142
# File 'proto_docs/google/cloud/aiplatform/v1/session_service.rb', line 139

class UpdateSessionRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end