Class: Google::Cloud::AIPlatform::V1::VertexMultimodalDatasetDestination
- Inherits:
-
Object
- Object
- Google::Cloud::AIPlatform::V1::VertexMultimodalDatasetDestination
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/aiplatform/v1/io.rb
Overview
The details for a Vertex Multimodal Dataset output.
Instance Attribute Summary collapse
-
#bigquery_destination ⇒ ::Google::Cloud::AIPlatform::V1::BigQueryDestination
Optional.
-
#display_name ⇒ ::String
Optional.
Instance Attribute Details
#bigquery_destination ⇒ ::Google::Cloud::AIPlatform::V1::BigQueryDestination
Returns Optional. The destination of the underlying BigQuery table that will be created for the output Multimodal Dataset. If not specified, the BigQuery table will be created in a default BigQuery dataset.
115 116 117 118 |
# File 'proto_docs/google/cloud/aiplatform/v1/io.rb', line 115 class VertexMultimodalDatasetDestination include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#display_name ⇒ ::String
Returns Optional. Display name of the output dataset.
115 116 117 118 |
# File 'proto_docs/google/cloud/aiplatform/v1/io.rb', line 115 class VertexMultimodalDatasetDestination include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |