Class: Google::Cloud::AIPlatform::V1::VertexRagStore
- Inherits:
-
Object
- Object
- Google::Cloud::AIPlatform::V1::VertexRagStore
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/aiplatform/v1/tool.rb
Overview
Retrieve from Vertex RAG Store for grounding.
Defined Under Namespace
Classes: RagResource
Instance Attribute Summary collapse
-
#rag_resources ⇒ ::Array<::Google::Cloud::AIPlatform::V1::VertexRagStore::RagResource>
Optional.
-
#rag_retrieval_config ⇒ ::Google::Cloud::AIPlatform::V1::RagRetrievalConfig
Optional.
-
#similarity_top_k ⇒ ::Integer
deprecated
Deprecated.
This field is deprecated and may be removed in the next major version update.
-
#vector_distance_threshold ⇒ ::Float
deprecated
Deprecated.
This field is deprecated and may be removed in the next major version update.
Instance Attribute Details
#rag_resources ⇒ ::Array<::Google::Cloud::AIPlatform::V1::VertexRagStore::RagResource>
Returns Optional. The representation of the rag source. It can be used to specify corpus only or ragfiles. Currently only support one corpus or multiple files from one corpus. In the future we may open up multiple corpora support.
520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 |
# File 'proto_docs/google/cloud/aiplatform/v1/tool.rb', line 520 class VertexRagStore include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The definition of the Rag resource. # @!attribute [rw] rag_corpus # @return [::String] # Optional. RagCorpora resource name. # Format: # `projects/{project}/locations/{location}/ragCorpora/{rag_corpus}` # @!attribute [rw] rag_file_ids # @return [::Array<::String>] # Optional. rag_file_id. The files should be in the same rag_corpus set in # rag_corpus field. class RagResource include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#rag_retrieval_config ⇒ ::Google::Cloud::AIPlatform::V1::RagRetrievalConfig
Returns Optional. The retrieval config for the Rag query.
520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 |
# File 'proto_docs/google/cloud/aiplatform/v1/tool.rb', line 520 class VertexRagStore include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The definition of the Rag resource. # @!attribute [rw] rag_corpus # @return [::String] # Optional. RagCorpora resource name. # Format: # `projects/{project}/locations/{location}/ragCorpora/{rag_corpus}` # @!attribute [rw] rag_file_ids # @return [::Array<::String>] # Optional. rag_file_id. The files should be in the same rag_corpus set in # rag_corpus field. class RagResource include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#similarity_top_k ⇒ ::Integer
This field is deprecated and may be removed in the next major version update.
Returns Optional. Number of top k results to return from the selected corpora.
520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 |
# File 'proto_docs/google/cloud/aiplatform/v1/tool.rb', line 520 class VertexRagStore include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The definition of the Rag resource. # @!attribute [rw] rag_corpus # @return [::String] # Optional. RagCorpora resource name. # Format: # `projects/{project}/locations/{location}/ragCorpora/{rag_corpus}` # @!attribute [rw] rag_file_ids # @return [::Array<::String>] # Optional. rag_file_id. The files should be in the same rag_corpus set in # rag_corpus field. class RagResource include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#vector_distance_threshold ⇒ ::Float
This field is deprecated and may be removed in the next major version update.
Returns Optional. Only return results with vector distance smaller than the threshold.
520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 |
# File 'proto_docs/google/cloud/aiplatform/v1/tool.rb', line 520 class VertexRagStore include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The definition of the Rag resource. # @!attribute [rw] rag_corpus # @return [::String] # Optional. RagCorpora resource name. # Format: # `projects/{project}/locations/{location}/ragCorpora/{rag_corpus}` # @!attribute [rw] rag_file_ids # @return [::Array<::String>] # Optional. rag_file_id. The files should be in the same rag_corpus set in # rag_corpus field. class RagResource include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |