Class: Google::Cloud::AIPlatform::V1::VideoMetadata

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/aiplatform/v1/content.rb

Overview

Metadata describes the input video content.

Instance Attribute Summary collapse

Instance Attribute Details

#end_offset::Google::Protobuf::Duration

Returns Optional. The end offset of the video.

Returns:



177
178
179
180
# File 'proto_docs/google/cloud/aiplatform/v1/content.rb', line 177

class VideoMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#fps::Float

Returns Optional. The frame rate of the video sent to the model. If not specified, the default value is 1.0. The valid range is (0.0, 24.0].

Returns:

  • (::Float)

    Optional. The frame rate of the video sent to the model. If not specified, the default value is 1.0. The valid range is (0.0, 24.0].



177
178
179
180
# File 'proto_docs/google/cloud/aiplatform/v1/content.rb', line 177

class VideoMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#start_offset::Google::Protobuf::Duration

Returns Optional. The start offset of the video.

Returns:



177
178
179
180
# File 'proto_docs/google/cloud/aiplatform/v1/content.rb', line 177

class VideoMetadata
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end