Class: Google::Type::LatLng
- Inherits:
-
Object
- Object
- Google::Type::LatLng
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/type/latlng.rb
Overview
An object that represents a latitude/longitude pair. This is expressed as a pair of doubles to represent degrees latitude and degrees longitude. Unless specified otherwise, this object must conform to the WGS84 standard. Values must be within normalized ranges.
Instance Attribute Summary collapse
-
#latitude ⇒ ::Float
The latitude in degrees.
-
#longitude ⇒ ::Float
The longitude in degrees.