Class: Google::Cloud::AIPlatform::V1::AggregationResult
- Inherits:
-
Object
- Object
- Google::Cloud::AIPlatform::V1::AggregationResult
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/aiplatform/v1/evaluation_service.rb
Overview
The aggregation result for a single metric.
Instance Attribute Summary collapse
-
#aggregation_metric ⇒ ::Google::Cloud::AIPlatform::V1::Metric::AggregationMetric
Aggregation metric.
-
#bleu_metric_value ⇒ ::Google::Cloud::AIPlatform::V1::BleuMetricValue
Results for bleu metric.
-
#exact_match_metric_value ⇒ ::Google::Cloud::AIPlatform::V1::ExactMatchMetricValue
Results for exact match metric.
-
#pairwise_metric_result ⇒ ::Google::Cloud::AIPlatform::V1::PairwiseMetricResult
Result for pairwise metric.
-
#pointwise_metric_result ⇒ ::Google::Cloud::AIPlatform::V1::PointwiseMetricResult
Result for pointwise metric.
-
#rouge_metric_value ⇒ ::Google::Cloud::AIPlatform::V1::RougeMetricValue
Results for rouge metric.
Instance Attribute Details
#aggregation_metric ⇒ ::Google::Cloud::AIPlatform::V1::Metric::AggregationMetric
Returns Aggregation metric.
535 536 537 538 |
# File 'proto_docs/google/cloud/aiplatform/v1/evaluation_service.rb', line 535 class AggregationResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#bleu_metric_value ⇒ ::Google::Cloud::AIPlatform::V1::BleuMetricValue
Returns Results for bleu metric.
Note: The following fields are mutually exclusive: bleu_metric_value, pointwise_metric_result, pairwise_metric_result, exact_match_metric_value, rouge_metric_value. If a field in that set is populated, all other fields in the set will automatically be cleared.
535 536 537 538 |
# File 'proto_docs/google/cloud/aiplatform/v1/evaluation_service.rb', line 535 class AggregationResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#exact_match_metric_value ⇒ ::Google::Cloud::AIPlatform::V1::ExactMatchMetricValue
Returns Results for exact match metric.
Note: The following fields are mutually exclusive: exact_match_metric_value, pointwise_metric_result, pairwise_metric_result, bleu_metric_value, rouge_metric_value. If a field in that set is populated, all other fields in the set will automatically be cleared.
535 536 537 538 |
# File 'proto_docs/google/cloud/aiplatform/v1/evaluation_service.rb', line 535 class AggregationResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#pairwise_metric_result ⇒ ::Google::Cloud::AIPlatform::V1::PairwiseMetricResult
Returns Result for pairwise metric.
Note: The following fields are mutually exclusive: pairwise_metric_result, pointwise_metric_result, exact_match_metric_value, bleu_metric_value, rouge_metric_value. If a field in that set is populated, all other fields in the set will automatically be cleared.
535 536 537 538 |
# File 'proto_docs/google/cloud/aiplatform/v1/evaluation_service.rb', line 535 class AggregationResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#pointwise_metric_result ⇒ ::Google::Cloud::AIPlatform::V1::PointwiseMetricResult
Returns Result for pointwise metric.
Note: The following fields are mutually exclusive: pointwise_metric_result, pairwise_metric_result, exact_match_metric_value, bleu_metric_value, rouge_metric_value. If a field in that set is populated, all other fields in the set will automatically be cleared.
535 536 537 538 |
# File 'proto_docs/google/cloud/aiplatform/v1/evaluation_service.rb', line 535 class AggregationResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#rouge_metric_value ⇒ ::Google::Cloud::AIPlatform::V1::RougeMetricValue
Returns Results for rouge metric.
Note: The following fields are mutually exclusive: rouge_metric_value, pointwise_metric_result, pairwise_metric_result, exact_match_metric_value, bleu_metric_value. If a field in that set is populated, all other fields in the set will automatically be cleared.
535 536 537 538 |
# File 'proto_docs/google/cloud/aiplatform/v1/evaluation_service.rb', line 535 class AggregationResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |