Class: Google::Cloud::AIPlatform::V1::AskContextsRequest
- Inherits:
-
Object
- Object
- Google::Cloud::AIPlatform::V1::AskContextsRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/aiplatform/v1/vertex_rag_service.rb
Overview
Agentic Retrieval Ask API for RAG. Request message for VertexRagService.AskContexts.
Instance Attribute Summary collapse
-
#parent ⇒ ::String
Required.
-
#query ⇒ ::Google::Cloud::AIPlatform::V1::RagQuery
Required.
-
#tools ⇒ ::Array<::Google::Cloud::AIPlatform::V1::Tool>
Optional.
Instance Attribute Details
#parent ⇒ ::String
Returns Required. The resource name of the Location from which to retrieve
RagContexts. The users must have permission to make a call in the project.
Format:
projects/{project}/locations/{location}.
298 299 300 301 |
# File 'proto_docs/google/cloud/aiplatform/v1/vertex_rag_service.rb', line 298 class AskContextsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#query ⇒ ::Google::Cloud::AIPlatform::V1::RagQuery
Returns Required. Single RAG retrieve query.
298 299 300 301 |
# File 'proto_docs/google/cloud/aiplatform/v1/vertex_rag_service.rb', line 298 class AskContextsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#tools ⇒ ::Array<::Google::Cloud::AIPlatform::V1::Tool>
Returns Optional. The tools to use for AskContexts.
298 299 300 301 |
# File 'proto_docs/google/cloud/aiplatform/v1/vertex_rag_service.rb', line 298 class AskContextsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |