Class: Google::Cloud::AIPlatform::V1::AutomaticResources
- Inherits:
-
Object
- Object
- Google::Cloud::AIPlatform::V1::AutomaticResources
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/aiplatform/v1/machine_resources.rb
Overview
A description of resources that to large degree are decided by Vertex AI, and require only a modest additional configuration. Each Model supporting these resources documents its specific guidelines.
Instance Attribute Summary collapse
-
#max_replica_count ⇒ ::Integer
Immutable.
-
#min_replica_count ⇒ ::Integer
Immutable.
Instance Attribute Details
#max_replica_count ⇒ ::Integer
Returns Immutable. The maximum number of replicas that may be deployed on when the traffic against it increases. If the requested value is too large, the deployment will error, but if deployment succeeds then the ability to scale to that many replicas is guaranteed (barring service outages). If traffic increases beyond what its replicas at maximum may handle, a portion of the traffic will be dropped. If this value is not provided, a no upper bound for scaling under heavy traffic will be assume, though Vertex AI may be unable to scale beyond certain replica number.
167 168 169 170 |
# File 'proto_docs/google/cloud/aiplatform/v1/machine_resources.rb', line 167 class AutomaticResources include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#min_replica_count ⇒ ::Integer
Returns Immutable. The minimum number of replicas that will be always deployed on. If traffic against it increases, it may dynamically be deployed onto more replicas up to max_replica_count, and as traffic decreases, some of these extra replicas may be freed. If the requested value is too large, the deployment will error.
167 168 169 170 |
# File 'proto_docs/google/cloud/aiplatform/v1/machine_resources.rb', line 167 class AutomaticResources include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |