Class: Google::Cloud::AIPlatform::V1::CodeExecutionResult
- Inherits:
-
Object
- Object
- Google::Cloud::AIPlatform::V1::CodeExecutionResult
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/aiplatform/v1/tool.rb
Overview
Result of executing the [ExecutableCode].
Always follows a part containing the [ExecutableCode].
Defined Under Namespace
Modules: Outcome
Instance Attribute Summary collapse
-
#outcome ⇒ ::Google::Cloud::AIPlatform::V1::CodeExecutionResult::Outcome
Required.
-
#output ⇒ ::String
Optional.
Instance Attribute Details
#outcome ⇒ ::Google::Cloud::AIPlatform::V1::CodeExecutionResult::Outcome
Returns Required. Outcome of the code execution.
458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 |
# File 'proto_docs/google/cloud/aiplatform/v1/tool.rb', line 458 class CodeExecutionResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enumeration of possible outcomes of the code execution. module Outcome # Unspecified status. This value should not be used. OUTCOME_UNSPECIFIED = 0 # Code execution completed successfully. OUTCOME_OK = 1 # Code execution finished but with a failure. `stderr` should contain the # reason. OUTCOME_FAILED = 2 # Code execution ran for too long, and was cancelled. There may or may not # be a partial output present. OUTCOME_DEADLINE_EXCEEDED = 3 end end |
#output ⇒ ::String
Returns Optional. Contains stdout when code execution is successful, stderr or other description otherwise.
458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 |
# File 'proto_docs/google/cloud/aiplatform/v1/tool.rb', line 458 class CodeExecutionResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enumeration of possible outcomes of the code execution. module Outcome # Unspecified status. This value should not be used. OUTCOME_UNSPECIFIED = 0 # Code execution completed successfully. OUTCOME_OK = 1 # Code execution finished but with a failure. `stderr` should contain the # reason. OUTCOME_FAILED = 2 # Code execution ran for too long, and was cancelled. There may or may not # be a partial output present. OUTCOME_DEADLINE_EXCEEDED = 3 end end |