Class: Google::Cloud::AIPlatform::V1::CodeExecutionResult

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/aiplatform/v1/tool.rb

Overview

Result of executing the [ExecutableCode].

Always follows a part containing the [ExecutableCode].

Defined Under Namespace

Modules: Outcome

Instance Attribute Summary collapse

Instance Attribute Details

#outcome::Google::Cloud::AIPlatform::V1::CodeExecutionResult::Outcome

Returns Required. Outcome of the code execution.

Returns:



420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
# File 'proto_docs/google/cloud/aiplatform/v1/tool.rb', line 420

class CodeExecutionResult
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enumeration of possible outcomes of the code execution.
  module Outcome
    # Unspecified status. This value should not be used.
    OUTCOME_UNSPECIFIED = 0

    # Code execution completed successfully.
    OUTCOME_OK = 1

    # Code execution finished but with a failure. `stderr` should contain the
    # reason.
    OUTCOME_FAILED = 2

    # Code execution ran for too long, and was cancelled. There may or may not
    # be a partial output present.
    OUTCOME_DEADLINE_EXCEEDED = 3
  end
end

#output::String

Returns Optional. Contains stdout when code execution is successful, stderr or other description otherwise.

Returns:

  • (::String)

    Optional. Contains stdout when code execution is successful, stderr or other description otherwise.



420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
# File 'proto_docs/google/cloud/aiplatform/v1/tool.rb', line 420

class CodeExecutionResult
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enumeration of possible outcomes of the code execution.
  module Outcome
    # Unspecified status. This value should not be used.
    OUTCOME_UNSPECIFIED = 0

    # Code execution completed successfully.
    OUTCOME_OK = 1

    # Code execution finished but with a failure. `stderr` should contain the
    # reason.
    OUTCOME_FAILED = 2

    # Code execution ran for too long, and was cancelled. There may or may not
    # be a partial output present.
    OUTCOME_DEADLINE_EXCEEDED = 3
  end
end