Class: Google::Cloud::AIPlatform::V1::CopyModelRequest
- Inherits:
-
Object
- Object
- Google::Cloud::AIPlatform::V1::CopyModelRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/aiplatform/v1/model_service.rb
Overview
Request message for ModelService.CopyModel.
Instance Attribute Summary collapse
-
#custom_service_account ⇒ ::String
Optional.
-
#encryption_spec ⇒ ::Google::Cloud::AIPlatform::V1::EncryptionSpec
Customer-managed encryption key options.
-
#model_id ⇒ ::String
Optional.
-
#parent ⇒ ::String
Required.
-
#parent_model ⇒ ::String
Optional.
-
#source_model ⇒ ::String
Required.
Instance Attribute Details
#custom_service_account ⇒ ::String
Returns Optional. The user-provided custom service account to use to do the copy
model. If empty, Vertex AI Service
Agent
will be used to access resources needed to upload the model. This account
must belong to the destination project where the model is copied to,
i.e., the project specified in the parent field of this request and
have the Vertex AI Service Agent role in the source project.
Requires the user copying the Model to have the
iam.serviceAccounts.actAs permission on this service account.
543 544 545 546 |
# File 'proto_docs/google/cloud/aiplatform/v1/model_service.rb', line 543 class CopyModelRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#encryption_spec ⇒ ::Google::Cloud::AIPlatform::V1::EncryptionSpec
Returns Customer-managed encryption key options. If this is set, then the Model copy will be encrypted with the provided encryption key.
543 544 545 546 |
# File 'proto_docs/google/cloud/aiplatform/v1/model_service.rb', line 543 class CopyModelRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#model_id ⇒ ::String
Returns Optional. Copy source_model into a new Model with this ID. The ID will become the final component of the model resource name.
This value may be up to 63 characters, and valid characters are
[a-z0-9_-]. The first character cannot be a number or hyphen.
Note: The following fields are mutually exclusive: model_id, parent_model. If a field in that set is populated, all other fields in the set will automatically be cleared.
543 544 545 546 |
# File 'proto_docs/google/cloud/aiplatform/v1/model_service.rb', line 543 class CopyModelRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#parent ⇒ ::String
Returns Required. The resource name of the Location into which to copy the Model.
Format: projects/{project}/locations/{location}.
543 544 545 546 |
# File 'proto_docs/google/cloud/aiplatform/v1/model_service.rb', line 543 class CopyModelRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#parent_model ⇒ ::String
Returns Optional. Specify this field to copy source_model into this existing
Model as a new version. Format:
projects/{project}/locations/{location}/models/{model}
Note: The following fields are mutually exclusive: parent_model, model_id. If a field in that set is populated, all other fields in the set will automatically be cleared.
543 544 545 546 |
# File 'proto_docs/google/cloud/aiplatform/v1/model_service.rb', line 543 class CopyModelRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#source_model ⇒ ::String
Returns Required. The resource name of the Model to copy. That Model must be in the
same Project. Format:
projects/{project}/locations/{location}/models/{model}.
543 544 545 546 |
# File 'proto_docs/google/cloud/aiplatform/v1/model_service.rb', line 543 class CopyModelRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |