Class: Google::Cloud::AIPlatform::V1::CreateSessionRequest
- Inherits:
-
Object
- Object
- Google::Cloud::AIPlatform::V1::CreateSessionRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/aiplatform/v1/session_service.rb
Overview
Request message for SessionService.CreateSession.
Instance Attribute Summary collapse
-
#parent ⇒ ::String
Required.
-
#session ⇒ ::Google::Cloud::AIPlatform::V1::Session
Required.
-
#session_id ⇒ ::String
Optional.
Instance Attribute Details
#parent ⇒ ::String
Returns Required. The resource name of the location to create the session in.
Format:
projects/{project}/locations/{location}/reasoningEngines/{reasoning_engine}.
43 44 45 46 |
# File 'proto_docs/google/cloud/aiplatform/v1/session_service.rb', line 43 class CreateSessionRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#session ⇒ ::Google::Cloud::AIPlatform::V1::Session
Returns Required. The session to create.
43 44 45 46 |
# File 'proto_docs/google/cloud/aiplatform/v1/session_service.rb', line 43 class CreateSessionRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#session_id ⇒ ::String
Returns Optional. The user defined ID to use for session, which will become the final component of the session resource name. If not provided, Vertex AI will generate a value for this ID.
This value may be up to 63 characters, and valid characters are
[a-z0-9-]. The first character must be a letter, and the last character
must be a letter or number.
43 44 45 46 |
# File 'proto_docs/google/cloud/aiplatform/v1/session_service.rb', line 43 class CreateSessionRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |