Class: Google::Cloud::AIPlatform::V1::EmbedContentRequest
- Inherits:
-
Object
- Object
- Google::Cloud::AIPlatform::V1::EmbedContentRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/aiplatform/v1/prediction_service.rb
Overview
Request message for PredictionService.EmbedContent.
Defined Under Namespace
Modules: EmbeddingTaskType
Instance Attribute Summary collapse
-
#auto_truncate ⇒ ::Boolean
Optional.
-
#content ⇒ ::Google::Cloud::AIPlatform::V1::Content
Required.
-
#model ⇒ ::String
Required.
-
#output_dimensionality ⇒ ::Integer
Optional.
-
#task_type ⇒ ::Google::Cloud::AIPlatform::V1::EmbedContentRequest::EmbeddingTaskType
Optional.
-
#title ⇒ ::String
Optional.
Instance Attribute Details
#auto_truncate ⇒ ::Boolean
Returns Optional. Whether to silently truncate the input content if it's longer than the maximum sequence length.
696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 |
# File 'proto_docs/google/cloud/aiplatform/v1/prediction_service.rb', line 696 class EmbedContentRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents a downstream task the embeddings will be used for. module EmbeddingTaskType # Unset value, which will default to one of the other enum values. UNSPECIFIED = 0 # Specifies the given text is a query in a search/retrieval setting. RETRIEVAL_QUERY = 2 # Specifies the given text is a document from the corpus being searched. RETRIEVAL_DOCUMENT = 3 # Specifies the given text will be used for STS. SEMANTIC_SIMILARITY = 4 # Specifies that the given text will be classified. CLASSIFICATION = 5 # Specifies that the embeddings will be used for clustering. CLUSTERING = 6 # Specifies that the embeddings will be used for question answering. QUESTION_ANSWERING = 7 # Specifies that the embeddings will be used for fact verification. FACT_VERIFICATION = 8 # Specifies that the embeddings will be used for code retrieval. CODE_RETRIEVAL_QUERY = 9 end end |
#content ⇒ ::Google::Cloud::AIPlatform::V1::Content
Returns Required. Input content to be embedded. Required.
696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 |
# File 'proto_docs/google/cloud/aiplatform/v1/prediction_service.rb', line 696 class EmbedContentRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents a downstream task the embeddings will be used for. module EmbeddingTaskType # Unset value, which will default to one of the other enum values. UNSPECIFIED = 0 # Specifies the given text is a query in a search/retrieval setting. RETRIEVAL_QUERY = 2 # Specifies the given text is a document from the corpus being searched. RETRIEVAL_DOCUMENT = 3 # Specifies the given text will be used for STS. SEMANTIC_SIMILARITY = 4 # Specifies that the given text will be classified. CLASSIFICATION = 5 # Specifies that the embeddings will be used for clustering. CLUSTERING = 6 # Specifies that the embeddings will be used for question answering. QUESTION_ANSWERING = 7 # Specifies that the embeddings will be used for fact verification. FACT_VERIFICATION = 8 # Specifies that the embeddings will be used for code retrieval. CODE_RETRIEVAL_QUERY = 9 end end |
#model ⇒ ::String
Returns Required. The name of the publisher model requested to serve the
prediction. Format:
projects/{project}/locations/{location}/publishers/*/models/*.
696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 |
# File 'proto_docs/google/cloud/aiplatform/v1/prediction_service.rb', line 696 class EmbedContentRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents a downstream task the embeddings will be used for. module EmbeddingTaskType # Unset value, which will default to one of the other enum values. UNSPECIFIED = 0 # Specifies the given text is a query in a search/retrieval setting. RETRIEVAL_QUERY = 2 # Specifies the given text is a document from the corpus being searched. RETRIEVAL_DOCUMENT = 3 # Specifies the given text will be used for STS. SEMANTIC_SIMILARITY = 4 # Specifies that the given text will be classified. CLASSIFICATION = 5 # Specifies that the embeddings will be used for clustering. CLUSTERING = 6 # Specifies that the embeddings will be used for question answering. QUESTION_ANSWERING = 7 # Specifies that the embeddings will be used for fact verification. FACT_VERIFICATION = 8 # Specifies that the embeddings will be used for code retrieval. CODE_RETRIEVAL_QUERY = 9 end end |
#output_dimensionality ⇒ ::Integer
Returns Optional. Optional reduced dimension for the output embedding. If set, excessive values in the output embedding are truncated from the end.
696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 |
# File 'proto_docs/google/cloud/aiplatform/v1/prediction_service.rb', line 696 class EmbedContentRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents a downstream task the embeddings will be used for. module EmbeddingTaskType # Unset value, which will default to one of the other enum values. UNSPECIFIED = 0 # Specifies the given text is a query in a search/retrieval setting. RETRIEVAL_QUERY = 2 # Specifies the given text is a document from the corpus being searched. RETRIEVAL_DOCUMENT = 3 # Specifies the given text will be used for STS. SEMANTIC_SIMILARITY = 4 # Specifies that the given text will be classified. CLASSIFICATION = 5 # Specifies that the embeddings will be used for clustering. CLUSTERING = 6 # Specifies that the embeddings will be used for question answering. QUESTION_ANSWERING = 7 # Specifies that the embeddings will be used for fact verification. FACT_VERIFICATION = 8 # Specifies that the embeddings will be used for code retrieval. CODE_RETRIEVAL_QUERY = 9 end end |
#task_type ⇒ ::Google::Cloud::AIPlatform::V1::EmbedContentRequest::EmbeddingTaskType
Returns Optional. The task type of the embedding.
696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 |
# File 'proto_docs/google/cloud/aiplatform/v1/prediction_service.rb', line 696 class EmbedContentRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents a downstream task the embeddings will be used for. module EmbeddingTaskType # Unset value, which will default to one of the other enum values. UNSPECIFIED = 0 # Specifies the given text is a query in a search/retrieval setting. RETRIEVAL_QUERY = 2 # Specifies the given text is a document from the corpus being searched. RETRIEVAL_DOCUMENT = 3 # Specifies the given text will be used for STS. SEMANTIC_SIMILARITY = 4 # Specifies that the given text will be classified. CLASSIFICATION = 5 # Specifies that the embeddings will be used for clustering. CLUSTERING = 6 # Specifies that the embeddings will be used for question answering. QUESTION_ANSWERING = 7 # Specifies that the embeddings will be used for fact verification. FACT_VERIFICATION = 8 # Specifies that the embeddings will be used for code retrieval. CODE_RETRIEVAL_QUERY = 9 end end |
#title ⇒ ::String
Returns Optional. An optional title for the text.
696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 |
# File 'proto_docs/google/cloud/aiplatform/v1/prediction_service.rb', line 696 class EmbedContentRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Represents a downstream task the embeddings will be used for. module EmbeddingTaskType # Unset value, which will default to one of the other enum values. UNSPECIFIED = 0 # Specifies the given text is a query in a search/retrieval setting. RETRIEVAL_QUERY = 2 # Specifies the given text is a document from the corpus being searched. RETRIEVAL_DOCUMENT = 3 # Specifies the given text will be used for STS. SEMANTIC_SIMILARITY = 4 # Specifies that the given text will be classified. CLASSIFICATION = 5 # Specifies that the embeddings will be used for clustering. CLUSTERING = 6 # Specifies that the embeddings will be used for question answering. QUESTION_ANSWERING = 7 # Specifies that the embeddings will be used for fact verification. FACT_VERIFICATION = 8 # Specifies that the embeddings will be used for code retrieval. CODE_RETRIEVAL_QUERY = 9 end end |