Class: Google::Cloud::AIPlatform::V1::EmbedContentRequest::EmbedContentConfig
- Inherits:
-
Object
- Object
- Google::Cloud::AIPlatform::V1::EmbedContentRequest::EmbedContentConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/aiplatform/v1/prediction_service.rb
Overview
Configurations for the EmbedContent API.
Instance Attribute Summary collapse
-
#audio_track_extraction ⇒ ::Boolean
Optional.
-
#auto_truncate ⇒ ::Boolean
Optional.
-
#document_ocr ⇒ ::Boolean
Optional.
-
#output_dimensionality ⇒ ::Integer
Optional.
-
#task_type ⇒ ::Google::Cloud::AIPlatform::V1::EmbedContentRequest::EmbeddingTaskType
Optional.
-
#title ⇒ ::String
Optional.
Instance Attribute Details
#audio_track_extraction ⇒ ::Boolean
Returns Optional. Whether to extract audio from video content.
765 766 767 768 |
# File 'proto_docs/google/cloud/aiplatform/v1/prediction_service.rb', line 765 class EmbedContentConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#auto_truncate ⇒ ::Boolean
Returns Optional. Whether to silently truncate the input content if it's longer than the maximum sequence length.
Only applicable to text-only embedding models.
765 766 767 768 |
# File 'proto_docs/google/cloud/aiplatform/v1/prediction_service.rb', line 765 class EmbedContentConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#document_ocr ⇒ ::Boolean
Returns Optional. Whether to enable OCR for document content.
765 766 767 768 |
# File 'proto_docs/google/cloud/aiplatform/v1/prediction_service.rb', line 765 class EmbedContentConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#output_dimensionality ⇒ ::Integer
Returns Optional. Reduced dimension for the output embedding. If set, excessive values in the output embedding are truncated from the end.
765 766 767 768 |
# File 'proto_docs/google/cloud/aiplatform/v1/prediction_service.rb', line 765 class EmbedContentConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#task_type ⇒ ::Google::Cloud::AIPlatform::V1::EmbedContentRequest::EmbeddingTaskType
Returns Optional. The task type of the embedding.
Only applicable to text-only embedding models.
765 766 767 768 |
# File 'proto_docs/google/cloud/aiplatform/v1/prediction_service.rb', line 765 class EmbedContentConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#title ⇒ ::String
Returns Optional. The title for the text.
Only applicable to text-only embedding models.
765 766 767 768 |
# File 'proto_docs/google/cloud/aiplatform/v1/prediction_service.rb', line 765 class EmbedContentConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |