Class: Google::Cloud::AIPlatform::V1::EvaluationDataset
- Inherits:
-
Object
- Object
- Google::Cloud::AIPlatform::V1::EvaluationDataset
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/aiplatform/v1/evaluation_service.rb
Overview
The dataset used for evaluation.
Instance Attribute Summary collapse
-
#bigquery_source ⇒ ::Google::Cloud::AIPlatform::V1::BigQuerySource
BigQuery source holds the dataset.
-
#gcs_source ⇒ ::Google::Cloud::AIPlatform::V1::GcsSource
Cloud storage source holds the dataset.
Instance Attribute Details
#bigquery_source ⇒ ::Google::Cloud::AIPlatform::V1::BigQuerySource
Returns BigQuery source holds the dataset.
Note: The following fields are mutually exclusive: bigquery_source, gcs_source. If a field in that set is populated, all other fields in the set will automatically be cleared.
466 467 468 469 |
# File 'proto_docs/google/cloud/aiplatform/v1/evaluation_service.rb', line 466 class EvaluationDataset include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#gcs_source ⇒ ::Google::Cloud::AIPlatform::V1::GcsSource
Returns Cloud storage source holds the dataset. Currently only one Cloud Storage file path is supported.
Note: The following fields are mutually exclusive: gcs_source, bigquery_source. If a field in that set is populated, all other fields in the set will automatically be cleared.
466 467 468 469 |
# File 'proto_docs/google/cloud/aiplatform/v1/evaluation_service.rb', line 466 class EvaluationDataset include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |