Class: Google::Cloud::AIPlatform::V1::EventMetadata
- Inherits:
-
Object
- Object
- Google::Cloud::AIPlatform::V1::EventMetadata
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/aiplatform/v1/session.rb
Overview
Metadata relating to a LLM response event.
Instance Attribute Summary collapse
-
#branch ⇒ ::String
Optional.
-
#custom_metadata ⇒ ::Google::Protobuf::Struct
The custom metadata of the LlmResponse.
-
#grounding_metadata ⇒ ::Google::Cloud::AIPlatform::V1::GroundingMetadata
Optional.
-
#input_transcription ⇒ ::Google::Cloud::AIPlatform::V1::Transcription
Optional.
-
#interrupted ⇒ ::Boolean
Optional.
-
#long_running_tool_ids ⇒ ::Array<::String>
Optional.
-
#output_transcription ⇒ ::Google::Cloud::AIPlatform::V1::Transcription
Optional.
-
#partial ⇒ ::Boolean
Optional.
-
#turn_complete ⇒ ::Boolean
Optional.
Instance Attribute Details
#branch ⇒ ::String
Returns Optional. The branch of the event. The format is like agent_1.agent_2.agent_3, where agent_1 is the parent of agent_2, and agent_2 is the parent of agent_3. Branch is used when multiple child agents shouldn't see their siblings' conversation history.
157 158 159 160 |
# File 'proto_docs/google/cloud/aiplatform/v1/session.rb', line 157 class EventMetadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#custom_metadata ⇒ ::Google::Protobuf::Struct
Returns The custom metadata of the LlmResponse.
157 158 159 160 |
# File 'proto_docs/google/cloud/aiplatform/v1/session.rb', line 157 class EventMetadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#grounding_metadata ⇒ ::Google::Cloud::AIPlatform::V1::GroundingMetadata
Returns Optional. Metadata returned to client when grounding is enabled.
157 158 159 160 |
# File 'proto_docs/google/cloud/aiplatform/v1/session.rb', line 157 class EventMetadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#input_transcription ⇒ ::Google::Cloud::AIPlatform::V1::Transcription
Returns Optional. Audio transcription of user input.
157 158 159 160 |
# File 'proto_docs/google/cloud/aiplatform/v1/session.rb', line 157 class EventMetadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#interrupted ⇒ ::Boolean
Returns Optional. Flag indicating that LLM was interrupted when generating the content. Usually it's due to user interruption during a bidi streaming.
157 158 159 160 |
# File 'proto_docs/google/cloud/aiplatform/v1/session.rb', line 157 class EventMetadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#long_running_tool_ids ⇒ ::Array<::String>
Returns Optional. Set of ids of the long running function calls. Agent client will know from this field about which function call is long running. Only valid for function call event.
157 158 159 160 |
# File 'proto_docs/google/cloud/aiplatform/v1/session.rb', line 157 class EventMetadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#output_transcription ⇒ ::Google::Cloud::AIPlatform::V1::Transcription
Returns Optional. Audio transcription of model output.
157 158 159 160 |
# File 'proto_docs/google/cloud/aiplatform/v1/session.rb', line 157 class EventMetadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#partial ⇒ ::Boolean
Returns Optional. Indicates whether the text content is part of a unfinished text stream. Only used for streaming mode and when the content is plain text.
157 158 159 160 |
# File 'proto_docs/google/cloud/aiplatform/v1/session.rb', line 157 class EventMetadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#turn_complete ⇒ ::Boolean
Returns Optional. Indicates whether the response from the model is complete. Only used for streaming mode.
157 158 159 160 |
# File 'proto_docs/google/cloud/aiplatform/v1/session.rb', line 157 class EventMetadata include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |