Class: Google::Cloud::AIPlatform::V1::FunctionCallingConfig
- Inherits:
-
Object
- Object
- Google::Cloud::AIPlatform::V1::FunctionCallingConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/aiplatform/v1/tool.rb
Overview
Function calling config.
Defined Under Namespace
Modules: Mode
Instance Attribute Summary collapse
-
#allowed_function_names ⇒ ::Array<::String>
Optional.
-
#mode ⇒ ::Google::Cloud::AIPlatform::V1::FunctionCallingConfig::Mode
Optional.
-
#stream_function_call_arguments ⇒ ::Boolean
Optional.
Instance Attribute Details
#allowed_function_names ⇒ ::Array<::String>
Returns Optional. Function names to call. Only set when the Mode is ANY. Function names should match [FunctionDeclaration.name]. With mode set to ANY, model will predict a function call from the set of function names provided.
633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 |
# File 'proto_docs/google/cloud/aiplatform/v1/tool.rb', line 633 class FunctionCallingConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Function calling mode. module Mode # Unspecified function calling mode. This value should not be used. MODE_UNSPECIFIED = 0 # Default model behavior, model decides to predict either function calls # or natural language response. AUTO = 1 # Model is constrained to always predicting function calls only. # If "allowed_function_names" are set, the predicted function calls will be # limited to any one of "allowed_function_names", else the predicted # function calls will be any one of the provided "function_declarations". ANY = 2 # Model will not predict any function calls. Model behavior is same as when # not passing any function declarations. NONE = 3 end end |
#mode ⇒ ::Google::Cloud::AIPlatform::V1::FunctionCallingConfig::Mode
Returns Optional. Function calling mode.
633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 |
# File 'proto_docs/google/cloud/aiplatform/v1/tool.rb', line 633 class FunctionCallingConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Function calling mode. module Mode # Unspecified function calling mode. This value should not be used. MODE_UNSPECIFIED = 0 # Default model behavior, model decides to predict either function calls # or natural language response. AUTO = 1 # Model is constrained to always predicting function calls only. # If "allowed_function_names" are set, the predicted function calls will be # limited to any one of "allowed_function_names", else the predicted # function calls will be any one of the provided "function_declarations". ANY = 2 # Model will not predict any function calls. Model behavior is same as when # not passing any function declarations. NONE = 3 end end |
#stream_function_call_arguments ⇒ ::Boolean
Returns Optional. When set to true, arguments of a single function call will be streamed out in multiple parts/contents/responses. Partial parameter results will be returned in the [FunctionCall.partial_args] field.
633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 |
# File 'proto_docs/google/cloud/aiplatform/v1/tool.rb', line 633 class FunctionCallingConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Function calling mode. module Mode # Unspecified function calling mode. This value should not be used. MODE_UNSPECIFIED = 0 # Default model behavior, model decides to predict either function calls # or natural language response. AUTO = 1 # Model is constrained to always predicting function calls only. # If "allowed_function_names" are set, the predicted function calls will be # limited to any one of "allowed_function_names", else the predicted # function calls will be any one of the provided "function_declarations". ANY = 2 # Model will not predict any function calls. Model behavior is same as when # not passing any function declarations. NONE = 3 end end |