Class: Google::Cloud::AIPlatform::V1::GenerationConfig::RoutingConfig
- Inherits:
-
Object
- Object
- Google::Cloud::AIPlatform::V1::GenerationConfig::RoutingConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/aiplatform/v1/content.rb
Overview
The configuration for routing the request to a specific model.
Defined Under Namespace
Classes: AutoRoutingMode, ManualRoutingMode
Instance Attribute Summary collapse
-
#auto_mode ⇒ ::Google::Cloud::AIPlatform::V1::GenerationConfig::RoutingConfig::AutoRoutingMode
Automated routing.
-
#manual_mode ⇒ ::Google::Cloud::AIPlatform::V1::GenerationConfig::RoutingConfig::ManualRoutingMode
Manual routing.
Instance Attribute Details
#auto_mode ⇒ ::Google::Cloud::AIPlatform::V1::GenerationConfig::RoutingConfig::AutoRoutingMode
Returns Automated routing.
Note: The following fields are mutually exclusive: auto_mode, manual_mode. If a field in that set is populated, all other fields in the set will automatically be cleared.
456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 |
# File 'proto_docs/google/cloud/aiplatform/v1/content.rb', line 456 class RoutingConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # When automated routing is specified, the routing will be determined by # the pretrained routing model and customer provided model routing # preference. # @!attribute [rw] model_routing_preference # @return [::Google::Cloud::AIPlatform::V1::GenerationConfig::RoutingConfig::AutoRoutingMode::ModelRoutingPreference] # The model routing preference. class AutoRoutingMode include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The model routing preference. module ModelRoutingPreference # Unspecified model routing preference. UNKNOWN = 0 # Prefer higher quality over low cost. PRIORITIZE_QUALITY = 1 # Balanced model routing preference. BALANCED = 2 # Prefer lower cost over higher quality. PRIORITIZE_COST = 3 end end # When manual routing is set, the specified model will be used directly. # @!attribute [rw] model_name # @return [::String] # The model name to use. Only the public LLM models are accepted. e.g. # 'gemini-1.5-pro-001'. class ManualRoutingMode include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#manual_mode ⇒ ::Google::Cloud::AIPlatform::V1::GenerationConfig::RoutingConfig::ManualRoutingMode
Returns Manual routing.
Note: The following fields are mutually exclusive: manual_mode, auto_mode. If a field in that set is populated, all other fields in the set will automatically be cleared.
456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 |
# File 'proto_docs/google/cloud/aiplatform/v1/content.rb', line 456 class RoutingConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # When automated routing is specified, the routing will be determined by # the pretrained routing model and customer provided model routing # preference. # @!attribute [rw] model_routing_preference # @return [::Google::Cloud::AIPlatform::V1::GenerationConfig::RoutingConfig::AutoRoutingMode::ModelRoutingPreference] # The model routing preference. class AutoRoutingMode include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The model routing preference. module ModelRoutingPreference # Unspecified model routing preference. UNKNOWN = 0 # Prefer higher quality over low cost. PRIORITIZE_QUALITY = 1 # Balanced model routing preference. BALANCED = 2 # Prefer lower cost over higher quality. PRIORITIZE_COST = 3 end end # When manual routing is set, the specified model will be used directly. # @!attribute [rw] model_name # @return [::String] # The model name to use. Only the public LLM models are accepted. e.g. # 'gemini-1.5-pro-001'. class ManualRoutingMode include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |