Class: Google::Cloud::AIPlatform::V1::GenerationConfig::ThinkingConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/aiplatform/v1/content.rb

Overview

Config for thinking features.

Defined Under Namespace

Modules: ThinkingLevel

Instance Attribute Summary collapse

Instance Attribute Details

#include_thoughts::Boolean

Returns Indicates whether to include thoughts in the response. If true, thoughts are returned only when available.

Returns:

  • (::Boolean)

    Indicates whether to include thoughts in the response. If true, thoughts are returned only when available.



509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
# File 'proto_docs/google/cloud/aiplatform/v1/content.rb', line 509

class ThinkingConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The thinking level for the model.
  module ThinkingLevel
    # Unspecified thinking level.
    THINKING_LEVEL_UNSPECIFIED = 0

    # Low thinking level.
    LOW = 1

    # Medium thinking level.
    MEDIUM = 2

    # High thinking level.
    HIGH = 3

    # MINIMAL thinking level.
    MINIMAL = 4
  end
end

#thinking_budget::Integer

Returns Optional. Indicates the thinking budget in tokens. This is only applied when enable_thinking is true.

Returns:

  • (::Integer)

    Optional. Indicates the thinking budget in tokens. This is only applied when enable_thinking is true.



509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
# File 'proto_docs/google/cloud/aiplatform/v1/content.rb', line 509

class ThinkingConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The thinking level for the model.
  module ThinkingLevel
    # Unspecified thinking level.
    THINKING_LEVEL_UNSPECIFIED = 0

    # Low thinking level.
    LOW = 1

    # Medium thinking level.
    MEDIUM = 2

    # High thinking level.
    HIGH = 3

    # MINIMAL thinking level.
    MINIMAL = 4
  end
end

#thinking_level::Google::Cloud::AIPlatform::V1::GenerationConfig::ThinkingConfig::ThinkingLevel

Returns Optional. The number of thoughts tokens that the model should generate.

Returns:



509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
# File 'proto_docs/google/cloud/aiplatform/v1/content.rb', line 509

class ThinkingConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # The thinking level for the model.
  module ThinkingLevel
    # Unspecified thinking level.
    THINKING_LEVEL_UNSPECIFIED = 0

    # Low thinking level.
    LOW = 1

    # Medium thinking level.
    MEDIUM = 2

    # High thinking level.
    HIGH = 3

    # MINIMAL thinking level.
    MINIMAL = 4
  end
end