Class: Google::Cloud::AIPlatform::V1::GroundingChunk
- Inherits:
-
Object
- Object
- Google::Cloud::AIPlatform::V1::GroundingChunk
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/aiplatform/v1/content.rb
Overview
Grounding chunk.
Defined Under Namespace
Classes: Maps, RetrievedContext, Web
Instance Attribute Summary collapse
-
#maps ⇒ ::Google::Cloud::AIPlatform::V1::GroundingChunk::Maps
Grounding chunk from Google Maps.
-
#retrieved_context ⇒ ::Google::Cloud::AIPlatform::V1::GroundingChunk::RetrievedContext
Grounding chunk from context retrieved by the retrieval tools.
-
#web ⇒ ::Google::Cloud::AIPlatform::V1::GroundingChunk::Web
Grounding chunk from the web.
Instance Attribute Details
#maps ⇒ ::Google::Cloud::AIPlatform::V1::GroundingChunk::Maps
Returns Grounding chunk from Google Maps.
Note: The following fields are mutually exclusive: maps, web, retrieved_context. If a field in that set is populated, all other fields in the set will automatically be cleared.
898 899 900 901 902 903 904 905 906 907 908 909 910 911 912 913 914 915 916 917 918 919 920 921 922 923 924 925 926 927 928 929 930 931 932 933 934 935 936 937 938 939 940 941 942 943 944 945 946 947 948 949 950 951 952 953 954 955 956 957 958 959 960 961 962 963 964 965 966 967 968 969 970 971 972 973 974 975 976 977 978 979 980 981 982 983 |
# File 'proto_docs/google/cloud/aiplatform/v1/content.rb', line 898 class GroundingChunk include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Chunk from the web. # @!attribute [rw] uri # @return [::String] # URI reference of the chunk. # @!attribute [rw] title # @return [::String] # Title of the chunk. class Web include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Chunk from context retrieved by the retrieval tools. # @!attribute [rw] rag_chunk # @return [::Google::Cloud::AIPlatform::V1::RagChunk] # Additional context for the RAG retrieval result. This is only populated # when using the RAG retrieval tool. # @!attribute [rw] uri # @return [::String] # URI reference of the attribution. # @!attribute [rw] title # @return [::String] # Title of the attribution. # @!attribute [rw] text # @return [::String] # Text of the attribution. # @!attribute [r] document_name # @return [::String] # Output only. The full document name for the referenced Vertex AI Search # document. class RetrievedContext include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Chunk from Google Maps. # @!attribute [rw] uri # @return [::String] # URI reference of the chunk. # @!attribute [rw] title # @return [::String] # Title of the chunk. # @!attribute [rw] text # @return [::String] # Text of the chunk. # @!attribute [rw] place_id # @return [::String] # This Place's resource name, in `places/{place_id}` format. Can be used # to look up the Place. # @!attribute [rw] place_answer_sources # @return [::Google::Cloud::AIPlatform::V1::GroundingChunk::Maps::PlaceAnswerSources] # Sources used to generate the place answer. # This includes review snippets and photos that were used to generate the # answer, as well as uris to flag content. class Maps include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] review_snippets # @return [::Array<::Google::Cloud::AIPlatform::V1::GroundingChunk::Maps::PlaceAnswerSources::ReviewSnippet>] # Snippets of reviews that are used to generate the answer. class PlaceAnswerSources include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Encapsulates a review snippet. # @!attribute [rw] review_id # @return [::String] # Id of the review referencing the place. # @!attribute [rw] google_maps_uri # @return [::String] # A link to show the review on Google Maps. # @!attribute [rw] title # @return [::String] # Title of the review. class ReviewSnippet include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end end end |
#retrieved_context ⇒ ::Google::Cloud::AIPlatform::V1::GroundingChunk::RetrievedContext
Returns Grounding chunk from context retrieved by the retrieval tools.
Note: The following fields are mutually exclusive: retrieved_context, web, maps. If a field in that set is populated, all other fields in the set will automatically be cleared.
898 899 900 901 902 903 904 905 906 907 908 909 910 911 912 913 914 915 916 917 918 919 920 921 922 923 924 925 926 927 928 929 930 931 932 933 934 935 936 937 938 939 940 941 942 943 944 945 946 947 948 949 950 951 952 953 954 955 956 957 958 959 960 961 962 963 964 965 966 967 968 969 970 971 972 973 974 975 976 977 978 979 980 981 982 983 |
# File 'proto_docs/google/cloud/aiplatform/v1/content.rb', line 898 class GroundingChunk include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Chunk from the web. # @!attribute [rw] uri # @return [::String] # URI reference of the chunk. # @!attribute [rw] title # @return [::String] # Title of the chunk. class Web include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Chunk from context retrieved by the retrieval tools. # @!attribute [rw] rag_chunk # @return [::Google::Cloud::AIPlatform::V1::RagChunk] # Additional context for the RAG retrieval result. This is only populated # when using the RAG retrieval tool. # @!attribute [rw] uri # @return [::String] # URI reference of the attribution. # @!attribute [rw] title # @return [::String] # Title of the attribution. # @!attribute [rw] text # @return [::String] # Text of the attribution. # @!attribute [r] document_name # @return [::String] # Output only. The full document name for the referenced Vertex AI Search # document. class RetrievedContext include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Chunk from Google Maps. # @!attribute [rw] uri # @return [::String] # URI reference of the chunk. # @!attribute [rw] title # @return [::String] # Title of the chunk. # @!attribute [rw] text # @return [::String] # Text of the chunk. # @!attribute [rw] place_id # @return [::String] # This Place's resource name, in `places/{place_id}` format. Can be used # to look up the Place. # @!attribute [rw] place_answer_sources # @return [::Google::Cloud::AIPlatform::V1::GroundingChunk::Maps::PlaceAnswerSources] # Sources used to generate the place answer. # This includes review snippets and photos that were used to generate the # answer, as well as uris to flag content. class Maps include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] review_snippets # @return [::Array<::Google::Cloud::AIPlatform::V1::GroundingChunk::Maps::PlaceAnswerSources::ReviewSnippet>] # Snippets of reviews that are used to generate the answer. class PlaceAnswerSources include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Encapsulates a review snippet. # @!attribute [rw] review_id # @return [::String] # Id of the review referencing the place. # @!attribute [rw] google_maps_uri # @return [::String] # A link to show the review on Google Maps. # @!attribute [rw] title # @return [::String] # Title of the review. class ReviewSnippet include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end end end |
#web ⇒ ::Google::Cloud::AIPlatform::V1::GroundingChunk::Web
Returns Grounding chunk from the web.
Note: The following fields are mutually exclusive: web, retrieved_context, maps. If a field in that set is populated, all other fields in the set will automatically be cleared.
898 899 900 901 902 903 904 905 906 907 908 909 910 911 912 913 914 915 916 917 918 919 920 921 922 923 924 925 926 927 928 929 930 931 932 933 934 935 936 937 938 939 940 941 942 943 944 945 946 947 948 949 950 951 952 953 954 955 956 957 958 959 960 961 962 963 964 965 966 967 968 969 970 971 972 973 974 975 976 977 978 979 980 981 982 983 |
# File 'proto_docs/google/cloud/aiplatform/v1/content.rb', line 898 class GroundingChunk include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Chunk from the web. # @!attribute [rw] uri # @return [::String] # URI reference of the chunk. # @!attribute [rw] title # @return [::String] # Title of the chunk. class Web include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Chunk from context retrieved by the retrieval tools. # @!attribute [rw] rag_chunk # @return [::Google::Cloud::AIPlatform::V1::RagChunk] # Additional context for the RAG retrieval result. This is only populated # when using the RAG retrieval tool. # @!attribute [rw] uri # @return [::String] # URI reference of the attribution. # @!attribute [rw] title # @return [::String] # Title of the attribution. # @!attribute [rw] text # @return [::String] # Text of the attribution. # @!attribute [r] document_name # @return [::String] # Output only. The full document name for the referenced Vertex AI Search # document. class RetrievedContext include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Chunk from Google Maps. # @!attribute [rw] uri # @return [::String] # URI reference of the chunk. # @!attribute [rw] title # @return [::String] # Title of the chunk. # @!attribute [rw] text # @return [::String] # Text of the chunk. # @!attribute [rw] place_id # @return [::String] # This Place's resource name, in `places/{place_id}` format. Can be used # to look up the Place. # @!attribute [rw] place_answer_sources # @return [::Google::Cloud::AIPlatform::V1::GroundingChunk::Maps::PlaceAnswerSources] # Sources used to generate the place answer. # This includes review snippets and photos that were used to generate the # answer, as well as uris to flag content. class Maps include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] review_snippets # @return [::Array<::Google::Cloud::AIPlatform::V1::GroundingChunk::Maps::PlaceAnswerSources::ReviewSnippet>] # Snippets of reviews that are used to generate the answer. class PlaceAnswerSources include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Encapsulates a review snippet. # @!attribute [rw] review_id # @return [::String] # Id of the review referencing the place. # @!attribute [rw] google_maps_uri # @return [::String] # A link to show the review on Google Maps. # @!attribute [rw] title # @return [::String] # Title of the review. class ReviewSnippet include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end end end |