Class: Google::Cloud::AIPlatform::V1::GroundingChunk::Maps
- Inherits:
-
Object
- Object
- Google::Cloud::AIPlatform::V1::GroundingChunk::Maps
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/aiplatform/v1/content.rb
Overview
A Maps chunk is a piece of evidence that comes from Google Maps,
containing information about places or routes. This is used to provide
the user with rich, location-based information.
Defined Under Namespace
Classes: PlaceAnswerSources, Route
Instance Attribute Summary collapse
-
#place_answer_sources ⇒ ::Google::Cloud::AIPlatform::V1::GroundingChunk::Maps::PlaceAnswerSources
Sources used to generate the place answer.
-
#place_id ⇒ ::String
This Place's resource name, in
places/{place_id}format. -
#route ⇒ ::Google::Cloud::AIPlatform::V1::GroundingChunk::Maps::Route
readonly
Output only.
-
#text ⇒ ::String
Text of the chunk.
-
#title ⇒ ::String
Title of the chunk.
-
#uri ⇒ ::String
URI reference of the chunk.
Instance Attribute Details
#place_answer_sources ⇒ ::Google::Cloud::AIPlatform::V1::GroundingChunk::Maps::PlaceAnswerSources
Returns Sources used to generate the place answer. This includes review snippets and photos that were used to generate the answer, as well as uris to flag content.
961 962 963 964 965 966 967 968 969 970 971 972 973 974 975 976 977 978 979 980 981 982 983 984 985 986 987 988 989 990 991 992 993 994 995 996 997 998 999 1000 1001 1002 1003 |
# File 'proto_docs/google/cloud/aiplatform/v1/content.rb', line 961 class Maps include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] review_snippets # @return [::Array<::Google::Cloud::AIPlatform::V1::GroundingChunk::Maps::PlaceAnswerSources::ReviewSnippet>] # Snippets of reviews that are used to generate the answer. class PlaceAnswerSources include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Encapsulates a review snippet. # @!attribute [rw] review_id # @return [::String] # Id of the review referencing the place. # @!attribute [rw] google_maps_uri # @return [::String] # A link to show the review on Google Maps. # @!attribute [rw] title # @return [::String] # Title of the review. class ReviewSnippet include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end # Route information from Google Maps. # @!attribute [rw] distance_meters # @return [::Integer] # The total distance of the route, in meters. # @!attribute [rw] duration # @return [::Google::Protobuf::Duration] # The total duration of the route. # @!attribute [rw] encoded_polyline # @return [::String] # An encoded polyline of the route. See # https://developers.google.com/maps/documentation/utilities/polylinealgorithm class Route include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#place_id ⇒ ::String
Returns This Place's resource name, in places/{place_id} format. Can be used
to look up the Place.
961 962 963 964 965 966 967 968 969 970 971 972 973 974 975 976 977 978 979 980 981 982 983 984 985 986 987 988 989 990 991 992 993 994 995 996 997 998 999 1000 1001 1002 1003 |
# File 'proto_docs/google/cloud/aiplatform/v1/content.rb', line 961 class Maps include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] review_snippets # @return [::Array<::Google::Cloud::AIPlatform::V1::GroundingChunk::Maps::PlaceAnswerSources::ReviewSnippet>] # Snippets of reviews that are used to generate the answer. class PlaceAnswerSources include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Encapsulates a review snippet. # @!attribute [rw] review_id # @return [::String] # Id of the review referencing the place. # @!attribute [rw] google_maps_uri # @return [::String] # A link to show the review on Google Maps. # @!attribute [rw] title # @return [::String] # Title of the review. class ReviewSnippet include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end # Route information from Google Maps. # @!attribute [rw] distance_meters # @return [::Integer] # The total distance of the route, in meters. # @!attribute [rw] duration # @return [::Google::Protobuf::Duration] # The total duration of the route. # @!attribute [rw] encoded_polyline # @return [::String] # An encoded polyline of the route. See # https://developers.google.com/maps/documentation/utilities/polylinealgorithm class Route include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#route ⇒ ::Google::Cloud::AIPlatform::V1::GroundingChunk::Maps::Route (readonly)
Returns Output only. Route information.
961 962 963 964 965 966 967 968 969 970 971 972 973 974 975 976 977 978 979 980 981 982 983 984 985 986 987 988 989 990 991 992 993 994 995 996 997 998 999 1000 1001 1002 1003 |
# File 'proto_docs/google/cloud/aiplatform/v1/content.rb', line 961 class Maps include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] review_snippets # @return [::Array<::Google::Cloud::AIPlatform::V1::GroundingChunk::Maps::PlaceAnswerSources::ReviewSnippet>] # Snippets of reviews that are used to generate the answer. class PlaceAnswerSources include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Encapsulates a review snippet. # @!attribute [rw] review_id # @return [::String] # Id of the review referencing the place. # @!attribute [rw] google_maps_uri # @return [::String] # A link to show the review on Google Maps. # @!attribute [rw] title # @return [::String] # Title of the review. class ReviewSnippet include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end # Route information from Google Maps. # @!attribute [rw] distance_meters # @return [::Integer] # The total distance of the route, in meters. # @!attribute [rw] duration # @return [::Google::Protobuf::Duration] # The total duration of the route. # @!attribute [rw] encoded_polyline # @return [::String] # An encoded polyline of the route. See # https://developers.google.com/maps/documentation/utilities/polylinealgorithm class Route include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#text ⇒ ::String
Returns Text of the chunk.
961 962 963 964 965 966 967 968 969 970 971 972 973 974 975 976 977 978 979 980 981 982 983 984 985 986 987 988 989 990 991 992 993 994 995 996 997 998 999 1000 1001 1002 1003 |
# File 'proto_docs/google/cloud/aiplatform/v1/content.rb', line 961 class Maps include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] review_snippets # @return [::Array<::Google::Cloud::AIPlatform::V1::GroundingChunk::Maps::PlaceAnswerSources::ReviewSnippet>] # Snippets of reviews that are used to generate the answer. class PlaceAnswerSources include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Encapsulates a review snippet. # @!attribute [rw] review_id # @return [::String] # Id of the review referencing the place. # @!attribute [rw] google_maps_uri # @return [::String] # A link to show the review on Google Maps. # @!attribute [rw] title # @return [::String] # Title of the review. class ReviewSnippet include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end # Route information from Google Maps. # @!attribute [rw] distance_meters # @return [::Integer] # The total distance of the route, in meters. # @!attribute [rw] duration # @return [::Google::Protobuf::Duration] # The total duration of the route. # @!attribute [rw] encoded_polyline # @return [::String] # An encoded polyline of the route. See # https://developers.google.com/maps/documentation/utilities/polylinealgorithm class Route include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#title ⇒ ::String
Returns Title of the chunk.
961 962 963 964 965 966 967 968 969 970 971 972 973 974 975 976 977 978 979 980 981 982 983 984 985 986 987 988 989 990 991 992 993 994 995 996 997 998 999 1000 1001 1002 1003 |
# File 'proto_docs/google/cloud/aiplatform/v1/content.rb', line 961 class Maps include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] review_snippets # @return [::Array<::Google::Cloud::AIPlatform::V1::GroundingChunk::Maps::PlaceAnswerSources::ReviewSnippet>] # Snippets of reviews that are used to generate the answer. class PlaceAnswerSources include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Encapsulates a review snippet. # @!attribute [rw] review_id # @return [::String] # Id of the review referencing the place. # @!attribute [rw] google_maps_uri # @return [::String] # A link to show the review on Google Maps. # @!attribute [rw] title # @return [::String] # Title of the review. class ReviewSnippet include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end # Route information from Google Maps. # @!attribute [rw] distance_meters # @return [::Integer] # The total distance of the route, in meters. # @!attribute [rw] duration # @return [::Google::Protobuf::Duration] # The total duration of the route. # @!attribute [rw] encoded_polyline # @return [::String] # An encoded polyline of the route. See # https://developers.google.com/maps/documentation/utilities/polylinealgorithm class Route include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#uri ⇒ ::String
Returns URI reference of the chunk.
961 962 963 964 965 966 967 968 969 970 971 972 973 974 975 976 977 978 979 980 981 982 983 984 985 986 987 988 989 990 991 992 993 994 995 996 997 998 999 1000 1001 1002 1003 |
# File 'proto_docs/google/cloud/aiplatform/v1/content.rb', line 961 class Maps include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] review_snippets # @return [::Array<::Google::Cloud::AIPlatform::V1::GroundingChunk::Maps::PlaceAnswerSources::ReviewSnippet>] # Snippets of reviews that are used to generate the answer. class PlaceAnswerSources include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Encapsulates a review snippet. # @!attribute [rw] review_id # @return [::String] # Id of the review referencing the place. # @!attribute [rw] google_maps_uri # @return [::String] # A link to show the review on Google Maps. # @!attribute [rw] title # @return [::String] # Title of the review. class ReviewSnippet include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end # Route information from Google Maps. # @!attribute [rw] distance_meters # @return [::Integer] # The total distance of the route, in meters. # @!attribute [rw] duration # @return [::Google::Protobuf::Duration] # The total duration of the route. # @!attribute [rw] encoded_polyline # @return [::String] # An encoded polyline of the route. See # https://developers.google.com/maps/documentation/utilities/polylinealgorithm class Route include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |