Class: Google::Cloud::AIPlatform::V1::GroundingChunk::Maps

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/aiplatform/v1/content.rb

Overview

Chunk from Google Maps.

Defined Under Namespace

Classes: PlaceAnswerSources

Instance Attribute Summary collapse

Instance Attribute Details

#place_answer_sources::Google::Cloud::AIPlatform::V1::GroundingChunk::Maps::PlaceAnswerSources

Returns Sources used to generate the place answer. This includes review snippets and photos that were used to generate the answer, as well as uris to flag content.

Returns:



956
957
958
959
960
961
962
963
964
965
966
967
968
969
970
971
972
973
974
975
976
977
978
979
980
981
982
# File 'proto_docs/google/cloud/aiplatform/v1/content.rb', line 956

class Maps
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] review_snippets
  #   @return [::Array<::Google::Cloud::AIPlatform::V1::GroundingChunk::Maps::PlaceAnswerSources::ReviewSnippet>]
  #     Snippets of reviews that are used to generate the answer.
  class PlaceAnswerSources
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Encapsulates a review snippet.
    # @!attribute [rw] review_id
    #   @return [::String]
    #     Id of the review referencing the place.
    # @!attribute [rw] google_maps_uri
    #   @return [::String]
    #     A link to show the review on Google Maps.
    # @!attribute [rw] title
    #   @return [::String]
    #     Title of the review.
    class ReviewSnippet
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end
  end
end

#place_id::String

Returns This Place's resource name, in places/{place_id} format. Can be used to look up the Place.

Returns:

  • (::String)

    This Place's resource name, in places/{place_id} format. Can be used to look up the Place.



956
957
958
959
960
961
962
963
964
965
966
967
968
969
970
971
972
973
974
975
976
977
978
979
980
981
982
# File 'proto_docs/google/cloud/aiplatform/v1/content.rb', line 956

class Maps
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] review_snippets
  #   @return [::Array<::Google::Cloud::AIPlatform::V1::GroundingChunk::Maps::PlaceAnswerSources::ReviewSnippet>]
  #     Snippets of reviews that are used to generate the answer.
  class PlaceAnswerSources
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Encapsulates a review snippet.
    # @!attribute [rw] review_id
    #   @return [::String]
    #     Id of the review referencing the place.
    # @!attribute [rw] google_maps_uri
    #   @return [::String]
    #     A link to show the review on Google Maps.
    # @!attribute [rw] title
    #   @return [::String]
    #     Title of the review.
    class ReviewSnippet
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end
  end
end

#text::String

Returns Text of the chunk.

Returns:

  • (::String)

    Text of the chunk.



956
957
958
959
960
961
962
963
964
965
966
967
968
969
970
971
972
973
974
975
976
977
978
979
980
981
982
# File 'proto_docs/google/cloud/aiplatform/v1/content.rb', line 956

class Maps
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] review_snippets
  #   @return [::Array<::Google::Cloud::AIPlatform::V1::GroundingChunk::Maps::PlaceAnswerSources::ReviewSnippet>]
  #     Snippets of reviews that are used to generate the answer.
  class PlaceAnswerSources
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Encapsulates a review snippet.
    # @!attribute [rw] review_id
    #   @return [::String]
    #     Id of the review referencing the place.
    # @!attribute [rw] google_maps_uri
    #   @return [::String]
    #     A link to show the review on Google Maps.
    # @!attribute [rw] title
    #   @return [::String]
    #     Title of the review.
    class ReviewSnippet
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end
  end
end

#title::String

Returns Title of the chunk.

Returns:

  • (::String)

    Title of the chunk.



956
957
958
959
960
961
962
963
964
965
966
967
968
969
970
971
972
973
974
975
976
977
978
979
980
981
982
# File 'proto_docs/google/cloud/aiplatform/v1/content.rb', line 956

class Maps
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] review_snippets
  #   @return [::Array<::Google::Cloud::AIPlatform::V1::GroundingChunk::Maps::PlaceAnswerSources::ReviewSnippet>]
  #     Snippets of reviews that are used to generate the answer.
  class PlaceAnswerSources
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Encapsulates a review snippet.
    # @!attribute [rw] review_id
    #   @return [::String]
    #     Id of the review referencing the place.
    # @!attribute [rw] google_maps_uri
    #   @return [::String]
    #     A link to show the review on Google Maps.
    # @!attribute [rw] title
    #   @return [::String]
    #     Title of the review.
    class ReviewSnippet
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end
  end
end

#uri::String

Returns URI reference of the chunk.

Returns:

  • (::String)

    URI reference of the chunk.



956
957
958
959
960
961
962
963
964
965
966
967
968
969
970
971
972
973
974
975
976
977
978
979
980
981
982
# File 'proto_docs/google/cloud/aiplatform/v1/content.rb', line 956

class Maps
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] review_snippets
  #   @return [::Array<::Google::Cloud::AIPlatform::V1::GroundingChunk::Maps::PlaceAnswerSources::ReviewSnippet>]
  #     Snippets of reviews that are used to generate the answer.
  class PlaceAnswerSources
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Encapsulates a review snippet.
    # @!attribute [rw] review_id
    #   @return [::String]
    #     Id of the review referencing the place.
    # @!attribute [rw] google_maps_uri
    #   @return [::String]
    #     A link to show the review on Google Maps.
    # @!attribute [rw] title
    #   @return [::String]
    #     Title of the review.
    class ReviewSnippet
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods
    end
  end
end