Module: Google::Cloud::AIPlatform::V1::ImageConfig::PersonGeneration

Defined in:
proto_docs/google/cloud/aiplatform/v1/content.rb

Overview

Enum for controlling the generation of people in images.

Constant Summary collapse

PERSON_GENERATION_UNSPECIFIED =

The default behavior is unspecified. The model will decide whether to generate images of people.

0
ALLOW_ALL =

Allows the model to generate images of people, including adults and children.

1
ALLOW_ADULT =

Allows the model to generate images of adults, but not children.

2
ALLOW_NONE =

Prevents the model from generating images of people.

3