Class: Google::Cloud::AIPlatform::V1::PairwiseMetricSpec
- Inherits:
-
Object
- Object
- Google::Cloud::AIPlatform::V1::PairwiseMetricSpec
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/aiplatform/v1/evaluation_service.rb
Overview
Spec for pairwise metric.
Instance Attribute Summary collapse
-
#baseline_response_field_name ⇒ ::String
Optional.
-
#candidate_response_field_name ⇒ ::String
Optional.
-
#custom_output_format_config ⇒ ::Google::Cloud::AIPlatform::V1::CustomOutputFormatConfig
Optional.
-
#metric_prompt_template ⇒ ::String
Required.
-
#system_instruction ⇒ ::String
Optional.
Instance Attribute Details
#baseline_response_field_name ⇒ ::String
Returns Optional. The field name of the baseline response.
1678 1679 1680 1681 |
# File 'proto_docs/google/cloud/aiplatform/v1/evaluation_service.rb', line 1678 class PairwiseMetricSpec include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#candidate_response_field_name ⇒ ::String
Returns Optional. The field name of the candidate response.
1678 1679 1680 1681 |
# File 'proto_docs/google/cloud/aiplatform/v1/evaluation_service.rb', line 1678 class PairwiseMetricSpec include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#custom_output_format_config ⇒ ::Google::Cloud::AIPlatform::V1::CustomOutputFormatConfig
Returns Optional. CustomOutputFormatConfig allows customization of metric output.
When this config is set, the default output is replaced with
the raw output string.
If a custom format is chosen, the pairwise_choice and explanation
fields in the corresponding metric result will be empty.
1678 1679 1680 1681 |
# File 'proto_docs/google/cloud/aiplatform/v1/evaluation_service.rb', line 1678 class PairwiseMetricSpec include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#metric_prompt_template ⇒ ::String
Returns Required. Metric prompt template for pairwise metric.
1678 1679 1680 1681 |
# File 'proto_docs/google/cloud/aiplatform/v1/evaluation_service.rb', line 1678 class PairwiseMetricSpec include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#system_instruction ⇒ ::String
Returns Optional. System instructions for pairwise metric.
1678 1679 1680 1681 |
# File 'proto_docs/google/cloud/aiplatform/v1/evaluation_service.rb', line 1678 class PairwiseMetricSpec include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |