Class: Google::Cloud::AIPlatform::V1::Part
- Inherits:
-
Object
- Object
- Google::Cloud::AIPlatform::V1::Part
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/aiplatform/v1/content.rb
Overview
A datatype containing media that is part of a multi-part Content message.
A Part consists of data which has an associated datatype. A Part can only
contain one of the accepted types in Part.data.
A Part must have a fixed IANA MIME type identifying the type and subtype
of the media if inline_data or file_data field is filled with raw bytes.
Defined Under Namespace
Classes: MediaResolution
Instance Attribute Summary collapse
-
#code_execution_result ⇒ ::Google::Cloud::AIPlatform::V1::CodeExecutionResult
Optional.
-
#executable_code ⇒ ::Google::Cloud::AIPlatform::V1::ExecutableCode
Optional.
-
#file_data ⇒ ::Google::Cloud::AIPlatform::V1::FileData
Optional.
-
#function_call ⇒ ::Google::Cloud::AIPlatform::V1::FunctionCall
Optional.
-
#function_response ⇒ ::Google::Cloud::AIPlatform::V1::FunctionResponse
Optional.
-
#inline_data ⇒ ::Google::Cloud::AIPlatform::V1::Blob
Optional.
-
#media_resolution ⇒ ::Google::Cloud::AIPlatform::V1::Part::MediaResolution
Per part media resolution.
-
#text ⇒ ::String
Optional.
-
#thought ⇒ ::Boolean
Indicates if the part is thought from the model.
-
#thought_signature ⇒ ::String
An opaque signature for the thought so it can be reused in subsequent requests.
-
#video_metadata ⇒ ::Google::Cloud::AIPlatform::V1::VideoMetadata
Optional.
Instance Attribute Details
#code_execution_result ⇒ ::Google::Cloud::AIPlatform::V1::CodeExecutionResult
Returns Optional. Result of executing the [ExecutableCode].
Note: The following fields are mutually exclusive: code_execution_result, text, inline_data, file_data, function_call, function_response, executable_code. If a field in that set is populated, all other fields in the set will automatically be cleared.
106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 |
# File 'proto_docs/google/cloud/aiplatform/v1/content.rb', line 106 class Part include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # per part media resolution. # Media resolution for the input media. # @!attribute [rw] level # @return [::Google::Cloud::AIPlatform::V1::Part::MediaResolution::Level] # The tokenization quality used for given media. class MediaResolution include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The media resolution level. module Level # Media resolution has not been set. MEDIA_RESOLUTION_UNSPECIFIED = 0 # Media resolution set to low. MEDIA_RESOLUTION_LOW = 1 # Media resolution set to medium. MEDIA_RESOLUTION_MEDIUM = 2 # Media resolution set to high. MEDIA_RESOLUTION_HIGH = 3 # Media resolution set to ultra high. This is for image only. MEDIA_RESOLUTION_ULTRA_HIGH = 4 end end end |
#executable_code ⇒ ::Google::Cloud::AIPlatform::V1::ExecutableCode
Returns Optional. Code generated by the model that is meant to be executed.
Note: The following fields are mutually exclusive: executable_code, text, inline_data, file_data, function_call, function_response, code_execution_result. If a field in that set is populated, all other fields in the set will automatically be cleared.
106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 |
# File 'proto_docs/google/cloud/aiplatform/v1/content.rb', line 106 class Part include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # per part media resolution. # Media resolution for the input media. # @!attribute [rw] level # @return [::Google::Cloud::AIPlatform::V1::Part::MediaResolution::Level] # The tokenization quality used for given media. class MediaResolution include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The media resolution level. module Level # Media resolution has not been set. MEDIA_RESOLUTION_UNSPECIFIED = 0 # Media resolution set to low. MEDIA_RESOLUTION_LOW = 1 # Media resolution set to medium. MEDIA_RESOLUTION_MEDIUM = 2 # Media resolution set to high. MEDIA_RESOLUTION_HIGH = 3 # Media resolution set to ultra high. This is for image only. MEDIA_RESOLUTION_ULTRA_HIGH = 4 end end end |
#file_data ⇒ ::Google::Cloud::AIPlatform::V1::FileData
Returns Optional. URI based data.
Note: The following fields are mutually exclusive: file_data, text, inline_data, function_call, function_response, executable_code, code_execution_result. If a field in that set is populated, all other fields in the set will automatically be cleared.
106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 |
# File 'proto_docs/google/cloud/aiplatform/v1/content.rb', line 106 class Part include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # per part media resolution. # Media resolution for the input media. # @!attribute [rw] level # @return [::Google::Cloud::AIPlatform::V1::Part::MediaResolution::Level] # The tokenization quality used for given media. class MediaResolution include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The media resolution level. module Level # Media resolution has not been set. MEDIA_RESOLUTION_UNSPECIFIED = 0 # Media resolution set to low. MEDIA_RESOLUTION_LOW = 1 # Media resolution set to medium. MEDIA_RESOLUTION_MEDIUM = 2 # Media resolution set to high. MEDIA_RESOLUTION_HIGH = 3 # Media resolution set to ultra high. This is for image only. MEDIA_RESOLUTION_ULTRA_HIGH = 4 end end end |
#function_call ⇒ ::Google::Cloud::AIPlatform::V1::FunctionCall
Returns Optional. A predicted [FunctionCall] returned from the model that contains a string representing the [FunctionDeclaration.name] with the parameters and their values.
Note: The following fields are mutually exclusive: function_call, text, inline_data, file_data, function_response, executable_code, code_execution_result. If a field in that set is populated, all other fields in the set will automatically be cleared.
106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 |
# File 'proto_docs/google/cloud/aiplatform/v1/content.rb', line 106 class Part include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # per part media resolution. # Media resolution for the input media. # @!attribute [rw] level # @return [::Google::Cloud::AIPlatform::V1::Part::MediaResolution::Level] # The tokenization quality used for given media. class MediaResolution include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The media resolution level. module Level # Media resolution has not been set. MEDIA_RESOLUTION_UNSPECIFIED = 0 # Media resolution set to low. MEDIA_RESOLUTION_LOW = 1 # Media resolution set to medium. MEDIA_RESOLUTION_MEDIUM = 2 # Media resolution set to high. MEDIA_RESOLUTION_HIGH = 3 # Media resolution set to ultra high. This is for image only. MEDIA_RESOLUTION_ULTRA_HIGH = 4 end end end |
#function_response ⇒ ::Google::Cloud::AIPlatform::V1::FunctionResponse
Returns Optional. The result output of a [FunctionCall] that contains a string representing the [FunctionDeclaration.name] and a structured JSON object containing any output from the function call. It is used as context to the model.
Note: The following fields are mutually exclusive: function_response, text, inline_data, file_data, function_call, executable_code, code_execution_result. If a field in that set is populated, all other fields in the set will automatically be cleared.
106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 |
# File 'proto_docs/google/cloud/aiplatform/v1/content.rb', line 106 class Part include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # per part media resolution. # Media resolution for the input media. # @!attribute [rw] level # @return [::Google::Cloud::AIPlatform::V1::Part::MediaResolution::Level] # The tokenization quality used for given media. class MediaResolution include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The media resolution level. module Level # Media resolution has not been set. MEDIA_RESOLUTION_UNSPECIFIED = 0 # Media resolution set to low. MEDIA_RESOLUTION_LOW = 1 # Media resolution set to medium. MEDIA_RESOLUTION_MEDIUM = 2 # Media resolution set to high. MEDIA_RESOLUTION_HIGH = 3 # Media resolution set to ultra high. This is for image only. MEDIA_RESOLUTION_ULTRA_HIGH = 4 end end end |
#inline_data ⇒ ::Google::Cloud::AIPlatform::V1::Blob
Returns Optional. Inlined bytes data.
Note: The following fields are mutually exclusive: inline_data, text, file_data, function_call, function_response, executable_code, code_execution_result. If a field in that set is populated, all other fields in the set will automatically be cleared.
106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 |
# File 'proto_docs/google/cloud/aiplatform/v1/content.rb', line 106 class Part include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # per part media resolution. # Media resolution for the input media. # @!attribute [rw] level # @return [::Google::Cloud::AIPlatform::V1::Part::MediaResolution::Level] # The tokenization quality used for given media. class MediaResolution include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The media resolution level. module Level # Media resolution has not been set. MEDIA_RESOLUTION_UNSPECIFIED = 0 # Media resolution set to low. MEDIA_RESOLUTION_LOW = 1 # Media resolution set to medium. MEDIA_RESOLUTION_MEDIUM = 2 # Media resolution set to high. MEDIA_RESOLUTION_HIGH = 3 # Media resolution set to ultra high. This is for image only. MEDIA_RESOLUTION_ULTRA_HIGH = 4 end end end |
#media_resolution ⇒ ::Google::Cloud::AIPlatform::V1::Part::MediaResolution
Returns per part media resolution. Media resolution for the input media.
106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 |
# File 'proto_docs/google/cloud/aiplatform/v1/content.rb', line 106 class Part include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # per part media resolution. # Media resolution for the input media. # @!attribute [rw] level # @return [::Google::Cloud::AIPlatform::V1::Part::MediaResolution::Level] # The tokenization quality used for given media. class MediaResolution include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The media resolution level. module Level # Media resolution has not been set. MEDIA_RESOLUTION_UNSPECIFIED = 0 # Media resolution set to low. MEDIA_RESOLUTION_LOW = 1 # Media resolution set to medium. MEDIA_RESOLUTION_MEDIUM = 2 # Media resolution set to high. MEDIA_RESOLUTION_HIGH = 3 # Media resolution set to ultra high. This is for image only. MEDIA_RESOLUTION_ULTRA_HIGH = 4 end end end |
#text ⇒ ::String
Returns Optional. Text part (can be code).
Note: The following fields are mutually exclusive: text, inline_data, file_data, function_call, function_response, executable_code, code_execution_result. If a field in that set is populated, all other fields in the set will automatically be cleared.
106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 |
# File 'proto_docs/google/cloud/aiplatform/v1/content.rb', line 106 class Part include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # per part media resolution. # Media resolution for the input media. # @!attribute [rw] level # @return [::Google::Cloud::AIPlatform::V1::Part::MediaResolution::Level] # The tokenization quality used for given media. class MediaResolution include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The media resolution level. module Level # Media resolution has not been set. MEDIA_RESOLUTION_UNSPECIFIED = 0 # Media resolution set to low. MEDIA_RESOLUTION_LOW = 1 # Media resolution set to medium. MEDIA_RESOLUTION_MEDIUM = 2 # Media resolution set to high. MEDIA_RESOLUTION_HIGH = 3 # Media resolution set to ultra high. This is for image only. MEDIA_RESOLUTION_ULTRA_HIGH = 4 end end end |
#thought ⇒ ::Boolean
Returns Indicates if the part is thought from the model.
106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 |
# File 'proto_docs/google/cloud/aiplatform/v1/content.rb', line 106 class Part include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # per part media resolution. # Media resolution for the input media. # @!attribute [rw] level # @return [::Google::Cloud::AIPlatform::V1::Part::MediaResolution::Level] # The tokenization quality used for given media. class MediaResolution include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The media resolution level. module Level # Media resolution has not been set. MEDIA_RESOLUTION_UNSPECIFIED = 0 # Media resolution set to low. MEDIA_RESOLUTION_LOW = 1 # Media resolution set to medium. MEDIA_RESOLUTION_MEDIUM = 2 # Media resolution set to high. MEDIA_RESOLUTION_HIGH = 3 # Media resolution set to ultra high. This is for image only. MEDIA_RESOLUTION_ULTRA_HIGH = 4 end end end |
#thought_signature ⇒ ::String
Returns An opaque signature for the thought so it can be reused in subsequent requests.
106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 |
# File 'proto_docs/google/cloud/aiplatform/v1/content.rb', line 106 class Part include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # per part media resolution. # Media resolution for the input media. # @!attribute [rw] level # @return [::Google::Cloud::AIPlatform::V1::Part::MediaResolution::Level] # The tokenization quality used for given media. class MediaResolution include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The media resolution level. module Level # Media resolution has not been set. MEDIA_RESOLUTION_UNSPECIFIED = 0 # Media resolution set to low. MEDIA_RESOLUTION_LOW = 1 # Media resolution set to medium. MEDIA_RESOLUTION_MEDIUM = 2 # Media resolution set to high. MEDIA_RESOLUTION_HIGH = 3 # Media resolution set to ultra high. This is for image only. MEDIA_RESOLUTION_ULTRA_HIGH = 4 end end end |
#video_metadata ⇒ ::Google::Cloud::AIPlatform::V1::VideoMetadata
Returns Optional. Video metadata. The metadata should only be specified while the video data is presented in inline_data or file_data.
106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 |
# File 'proto_docs/google/cloud/aiplatform/v1/content.rb', line 106 class Part include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # per part media resolution. # Media resolution for the input media. # @!attribute [rw] level # @return [::Google::Cloud::AIPlatform::V1::Part::MediaResolution::Level] # The tokenization quality used for given media. class MediaResolution include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The media resolution level. module Level # Media resolution has not been set. MEDIA_RESOLUTION_UNSPECIFIED = 0 # Media resolution set to low. MEDIA_RESOLUTION_LOW = 1 # Media resolution set to medium. MEDIA_RESOLUTION_MEDIUM = 2 # Media resolution set to high. MEDIA_RESOLUTION_HIGH = 3 # Media resolution set to ultra high. This is for image only. MEDIA_RESOLUTION_ULTRA_HIGH = 4 end end end |