Class: Google::Cloud::AIPlatform::V1::RagRetrievalConfig
- Inherits:
-
Object
- Object
- Google::Cloud::AIPlatform::V1::RagRetrievalConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/aiplatform/v1/tool.rb
Overview
Specifies the context retrieval config.
Defined Under Namespace
Instance Attribute Summary collapse
-
#filter ⇒ ::Google::Cloud::AIPlatform::V1::RagRetrievalConfig::Filter
Optional.
-
#ranking ⇒ ::Google::Cloud::AIPlatform::V1::RagRetrievalConfig::Ranking
Optional.
-
#top_k ⇒ ::Integer
Optional.
Instance Attribute Details
#filter ⇒ ::Google::Cloud::AIPlatform::V1::RagRetrievalConfig::Filter
Returns Optional. Config for filters.
726 727 728 729 730 731 732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 757 758 759 760 761 762 763 764 765 766 767 768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 783 784 785 786 |
# File 'proto_docs/google/cloud/aiplatform/v1/tool.rb', line 726 class RagRetrievalConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Config for filters. # @!attribute [rw] vector_distance_threshold # @return [::Float] # Optional. Only returns contexts with vector distance smaller than the # threshold. # # Note: The following fields are mutually exclusive: `vector_distance_threshold`, `vector_similarity_threshold`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] vector_similarity_threshold # @return [::Float] # Optional. Only returns contexts with vector similarity larger than the # threshold. # # Note: The following fields are mutually exclusive: `vector_similarity_threshold`, `vector_distance_threshold`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] metadata_filter # @return [::String] # Optional. String for metadata filtering. class Filter include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Config for ranking and reranking. # @!attribute [rw] rank_service # @return [::Google::Cloud::AIPlatform::V1::RagRetrievalConfig::Ranking::RankService] # Optional. Config for Rank Service. # # Note: The following fields are mutually exclusive: `rank_service`, `llm_ranker`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] llm_ranker # @return [::Google::Cloud::AIPlatform::V1::RagRetrievalConfig::Ranking::LlmRanker] # Optional. Config for LlmRanker. # # Note: The following fields are mutually exclusive: `llm_ranker`, `rank_service`. If a field in that set is populated, all other fields in the set will automatically be cleared. class Ranking include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Config for Rank Service. # @!attribute [rw] model_name # @return [::String] # Optional. The model name of the rank service. # Format: `semantic-ranker-512@latest` class RankService include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Config for LlmRanker. # @!attribute [rw] model_name # @return [::String] # Optional. The model name used for ranking. # Format: `gemini-1.5-pro` class LlmRanker include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end end |
#ranking ⇒ ::Google::Cloud::AIPlatform::V1::RagRetrievalConfig::Ranking
Returns Optional. Config for ranking and reranking.
726 727 728 729 730 731 732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 757 758 759 760 761 762 763 764 765 766 767 768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 783 784 785 786 |
# File 'proto_docs/google/cloud/aiplatform/v1/tool.rb', line 726 class RagRetrievalConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Config for filters. # @!attribute [rw] vector_distance_threshold # @return [::Float] # Optional. Only returns contexts with vector distance smaller than the # threshold. # # Note: The following fields are mutually exclusive: `vector_distance_threshold`, `vector_similarity_threshold`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] vector_similarity_threshold # @return [::Float] # Optional. Only returns contexts with vector similarity larger than the # threshold. # # Note: The following fields are mutually exclusive: `vector_similarity_threshold`, `vector_distance_threshold`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] metadata_filter # @return [::String] # Optional. String for metadata filtering. class Filter include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Config for ranking and reranking. # @!attribute [rw] rank_service # @return [::Google::Cloud::AIPlatform::V1::RagRetrievalConfig::Ranking::RankService] # Optional. Config for Rank Service. # # Note: The following fields are mutually exclusive: `rank_service`, `llm_ranker`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] llm_ranker # @return [::Google::Cloud::AIPlatform::V1::RagRetrievalConfig::Ranking::LlmRanker] # Optional. Config for LlmRanker. # # Note: The following fields are mutually exclusive: `llm_ranker`, `rank_service`. If a field in that set is populated, all other fields in the set will automatically be cleared. class Ranking include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Config for Rank Service. # @!attribute [rw] model_name # @return [::String] # Optional. The model name of the rank service. # Format: `semantic-ranker-512@latest` class RankService include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Config for LlmRanker. # @!attribute [rw] model_name # @return [::String] # Optional. The model name used for ranking. # Format: `gemini-1.5-pro` class LlmRanker include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end end |
#top_k ⇒ ::Integer
Returns Optional. The number of contexts to retrieve.
726 727 728 729 730 731 732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 757 758 759 760 761 762 763 764 765 766 767 768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 783 784 785 786 |
# File 'proto_docs/google/cloud/aiplatform/v1/tool.rb', line 726 class RagRetrievalConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Config for filters. # @!attribute [rw] vector_distance_threshold # @return [::Float] # Optional. Only returns contexts with vector distance smaller than the # threshold. # # Note: The following fields are mutually exclusive: `vector_distance_threshold`, `vector_similarity_threshold`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] vector_similarity_threshold # @return [::Float] # Optional. Only returns contexts with vector similarity larger than the # threshold. # # Note: The following fields are mutually exclusive: `vector_similarity_threshold`, `vector_distance_threshold`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] metadata_filter # @return [::String] # Optional. String for metadata filtering. class Filter include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Config for ranking and reranking. # @!attribute [rw] rank_service # @return [::Google::Cloud::AIPlatform::V1::RagRetrievalConfig::Ranking::RankService] # Optional. Config for Rank Service. # # Note: The following fields are mutually exclusive: `rank_service`, `llm_ranker`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] llm_ranker # @return [::Google::Cloud::AIPlatform::V1::RagRetrievalConfig::Ranking::LlmRanker] # Optional. Config for LlmRanker. # # Note: The following fields are mutually exclusive: `llm_ranker`, `rank_service`. If a field in that set is populated, all other fields in the set will automatically be cleared. class Ranking include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Config for Rank Service. # @!attribute [rw] model_name # @return [::String] # Optional. The model name of the rank service. # Format: `semantic-ranker-512@latest` class RankService include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Config for LlmRanker. # @!attribute [rw] model_name # @return [::String] # Optional. The model name used for ranking. # Format: `gemini-1.5-pro` class LlmRanker include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end end |