Class: Google::Cloud::AIPlatform::V1::ReasoningEngineSpec::SourceCodeSpec
- Inherits:
-
Object
- Object
- Google::Cloud::AIPlatform::V1::ReasoningEngineSpec::SourceCodeSpec
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/aiplatform/v1/reasoning_engine.rb
Overview
Specification for deploying from source code.
Defined Under Namespace
Classes: DeveloperConnectConfig, DeveloperConnectSource, ImageSpec, InlineSource, PythonSpec
Instance Attribute Summary collapse
-
#developer_connect_source ⇒ ::Google::Cloud::AIPlatform::V1::ReasoningEngineSpec::SourceCodeSpec::DeveloperConnectSource
Source code is in a Git repository managed by Developer Connect.
-
#image_spec ⇒ ::Google::Cloud::AIPlatform::V1::ReasoningEngineSpec::SourceCodeSpec::ImageSpec
Optional.
-
#inline_source ⇒ ::Google::Cloud::AIPlatform::V1::ReasoningEngineSpec::SourceCodeSpec::InlineSource
Source code is provided directly in the request.
-
#python_spec ⇒ ::Google::Cloud::AIPlatform::V1::ReasoningEngineSpec::SourceCodeSpec::PythonSpec
Configuration for a Python application.
Instance Attribute Details
#developer_connect_source ⇒ ::Google::Cloud::AIPlatform::V1::ReasoningEngineSpec::SourceCodeSpec::DeveloperConnectSource
Returns Source code is in a Git repository managed by Developer Connect.
Note: The following fields are mutually exclusive: developer_connect_source, inline_source. If a field in that set is populated, all other fields in the set will automatically be cleared.
163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 |
# File 'proto_docs/google/cloud/aiplatform/v1/reasoning_engine.rb', line 163 class SourceCodeSpec include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies source code provided as a byte stream. # @!attribute [rw] source_archive # @return [::String] # Required. Input only. The application source code archive, provided as # a compressed tarball (.tar.gz) file. class InlineSource include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The image spec for building an image (within a single build step), based # on the config file (i.e. Dockerfile) in the source directory. # @!attribute [rw] build_args # @return [::Google::Protobuf::Map{::String => ::String}] # Optional. Build arguments to be used. They will be passed through # --build-arg flags. class ImageSpec include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class BuildArgsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end # Specifies the configuration for fetching source code from a Git # repository that is managed by Developer Connect. This includes the # repository, revision, and directory to use. # @!attribute [rw] git_repository_link # @return [::String] # Required. The Developer Connect Git repository link, formatted as # `projects/*/locations/*/connections/*/gitRepositoryLink/*`. # @!attribute [rw] dir # @return [::String] # Required. Directory, relative to the source root, in which to run the # build. # @!attribute [rw] revision # @return [::String] # Required. The revision to fetch from the Git repository such as a # branch, a tag, a commit SHA, or any Git ref. class DeveloperConnectConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Specifies source code to be fetched from a Git repository managed through # the Developer Connect service. # @!attribute [rw] config # @return [::Google::Cloud::AIPlatform::V1::ReasoningEngineSpec::SourceCodeSpec::DeveloperConnectConfig] # Required. The Developer Connect configuration that defines the # specific repository, revision, and directory to use as the source code # root. class DeveloperConnectSource include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Specification for running a Python application from source. # @!attribute [rw] version # @return [::String] # Optional. The version of Python to use. Support version # includes 3.9, 3.10, 3.11, 3.12, 3.13. # If not specified, default value is 3.10. # @!attribute [rw] entrypoint_module # @return [::String] # Optional. The Python module to load as the entrypoint, specified as a # fully qualified module name. For example: path.to.agent. # If not specified, defaults to "agent". # # The project root will be added to Python sys.path, allowing imports # to be specified relative to the root. # @!attribute [rw] entrypoint_object # @return [::String] # Optional. The name of the callable object within the # `entrypoint_module` to use as the application If not specified, # defaults to "root_agent". # @!attribute [rw] requirements_file # @return [::String] # Optional. The path to the requirements file, relative to the source # root. If not specified, defaults to "requirements.txt". class PythonSpec include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#image_spec ⇒ ::Google::Cloud::AIPlatform::V1::ReasoningEngineSpec::SourceCodeSpec::ImageSpec
Returns Optional. Configuration for building an image with custom config file.
Note: The following fields are mutually exclusive: image_spec, python_spec. If a field in that set is populated, all other fields in the set will automatically be cleared.
163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 |
# File 'proto_docs/google/cloud/aiplatform/v1/reasoning_engine.rb', line 163 class SourceCodeSpec include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies source code provided as a byte stream. # @!attribute [rw] source_archive # @return [::String] # Required. Input only. The application source code archive, provided as # a compressed tarball (.tar.gz) file. class InlineSource include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The image spec for building an image (within a single build step), based # on the config file (i.e. Dockerfile) in the source directory. # @!attribute [rw] build_args # @return [::Google::Protobuf::Map{::String => ::String}] # Optional. Build arguments to be used. They will be passed through # --build-arg flags. class ImageSpec include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class BuildArgsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end # Specifies the configuration for fetching source code from a Git # repository that is managed by Developer Connect. This includes the # repository, revision, and directory to use. # @!attribute [rw] git_repository_link # @return [::String] # Required. The Developer Connect Git repository link, formatted as # `projects/*/locations/*/connections/*/gitRepositoryLink/*`. # @!attribute [rw] dir # @return [::String] # Required. Directory, relative to the source root, in which to run the # build. # @!attribute [rw] revision # @return [::String] # Required. The revision to fetch from the Git repository such as a # branch, a tag, a commit SHA, or any Git ref. class DeveloperConnectConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Specifies source code to be fetched from a Git repository managed through # the Developer Connect service. # @!attribute [rw] config # @return [::Google::Cloud::AIPlatform::V1::ReasoningEngineSpec::SourceCodeSpec::DeveloperConnectConfig] # Required. The Developer Connect configuration that defines the # specific repository, revision, and directory to use as the source code # root. class DeveloperConnectSource include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Specification for running a Python application from source. # @!attribute [rw] version # @return [::String] # Optional. The version of Python to use. Support version # includes 3.9, 3.10, 3.11, 3.12, 3.13. # If not specified, default value is 3.10. # @!attribute [rw] entrypoint_module # @return [::String] # Optional. The Python module to load as the entrypoint, specified as a # fully qualified module name. For example: path.to.agent. # If not specified, defaults to "agent". # # The project root will be added to Python sys.path, allowing imports # to be specified relative to the root. # @!attribute [rw] entrypoint_object # @return [::String] # Optional. The name of the callable object within the # `entrypoint_module` to use as the application If not specified, # defaults to "root_agent". # @!attribute [rw] requirements_file # @return [::String] # Optional. The path to the requirements file, relative to the source # root. If not specified, defaults to "requirements.txt". class PythonSpec include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#inline_source ⇒ ::Google::Cloud::AIPlatform::V1::ReasoningEngineSpec::SourceCodeSpec::InlineSource
Returns Source code is provided directly in the request.
Note: The following fields are mutually exclusive: inline_source, developer_connect_source. If a field in that set is populated, all other fields in the set will automatically be cleared.
163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 |
# File 'proto_docs/google/cloud/aiplatform/v1/reasoning_engine.rb', line 163 class SourceCodeSpec include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies source code provided as a byte stream. # @!attribute [rw] source_archive # @return [::String] # Required. Input only. The application source code archive, provided as # a compressed tarball (.tar.gz) file. class InlineSource include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The image spec for building an image (within a single build step), based # on the config file (i.e. Dockerfile) in the source directory. # @!attribute [rw] build_args # @return [::Google::Protobuf::Map{::String => ::String}] # Optional. Build arguments to be used. They will be passed through # --build-arg flags. class ImageSpec include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class BuildArgsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end # Specifies the configuration for fetching source code from a Git # repository that is managed by Developer Connect. This includes the # repository, revision, and directory to use. # @!attribute [rw] git_repository_link # @return [::String] # Required. The Developer Connect Git repository link, formatted as # `projects/*/locations/*/connections/*/gitRepositoryLink/*`. # @!attribute [rw] dir # @return [::String] # Required. Directory, relative to the source root, in which to run the # build. # @!attribute [rw] revision # @return [::String] # Required. The revision to fetch from the Git repository such as a # branch, a tag, a commit SHA, or any Git ref. class DeveloperConnectConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Specifies source code to be fetched from a Git repository managed through # the Developer Connect service. # @!attribute [rw] config # @return [::Google::Cloud::AIPlatform::V1::ReasoningEngineSpec::SourceCodeSpec::DeveloperConnectConfig] # Required. The Developer Connect configuration that defines the # specific repository, revision, and directory to use as the source code # root. class DeveloperConnectSource include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Specification for running a Python application from source. # @!attribute [rw] version # @return [::String] # Optional. The version of Python to use. Support version # includes 3.9, 3.10, 3.11, 3.12, 3.13. # If not specified, default value is 3.10. # @!attribute [rw] entrypoint_module # @return [::String] # Optional. The Python module to load as the entrypoint, specified as a # fully qualified module name. For example: path.to.agent. # If not specified, defaults to "agent". # # The project root will be added to Python sys.path, allowing imports # to be specified relative to the root. # @!attribute [rw] entrypoint_object # @return [::String] # Optional. The name of the callable object within the # `entrypoint_module` to use as the application If not specified, # defaults to "root_agent". # @!attribute [rw] requirements_file # @return [::String] # Optional. The path to the requirements file, relative to the source # root. If not specified, defaults to "requirements.txt". class PythonSpec include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#python_spec ⇒ ::Google::Cloud::AIPlatform::V1::ReasoningEngineSpec::SourceCodeSpec::PythonSpec
Returns Configuration for a Python application.
Note: The following fields are mutually exclusive: python_spec, image_spec. If a field in that set is populated, all other fields in the set will automatically be cleared.
163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 |
# File 'proto_docs/google/cloud/aiplatform/v1/reasoning_engine.rb', line 163 class SourceCodeSpec include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Specifies source code provided as a byte stream. # @!attribute [rw] source_archive # @return [::String] # Required. Input only. The application source code archive, provided as # a compressed tarball (.tar.gz) file. class InlineSource include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The image spec for building an image (within a single build step), based # on the config file (i.e. Dockerfile) in the source directory. # @!attribute [rw] build_args # @return [::Google::Protobuf::Map{::String => ::String}] # Optional. Build arguments to be used. They will be passed through # --build-arg flags. class ImageSpec include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class BuildArgsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end # Specifies the configuration for fetching source code from a Git # repository that is managed by Developer Connect. This includes the # repository, revision, and directory to use. # @!attribute [rw] git_repository_link # @return [::String] # Required. The Developer Connect Git repository link, formatted as # `projects/*/locations/*/connections/*/gitRepositoryLink/*`. # @!attribute [rw] dir # @return [::String] # Required. Directory, relative to the source root, in which to run the # build. # @!attribute [rw] revision # @return [::String] # Required. The revision to fetch from the Git repository such as a # branch, a tag, a commit SHA, or any Git ref. class DeveloperConnectConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Specifies source code to be fetched from a Git repository managed through # the Developer Connect service. # @!attribute [rw] config # @return [::Google::Cloud::AIPlatform::V1::ReasoningEngineSpec::SourceCodeSpec::DeveloperConnectConfig] # Required. The Developer Connect configuration that defines the # specific repository, revision, and directory to use as the source code # root. class DeveloperConnectSource include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Specification for running a Python application from source. # @!attribute [rw] version # @return [::String] # Optional. The version of Python to use. Support version # includes 3.9, 3.10, 3.11, 3.12, 3.13. # If not specified, default value is 3.10. # @!attribute [rw] entrypoint_module # @return [::String] # Optional. The Python module to load as the entrypoint, specified as a # fully qualified module name. For example: path.to.agent. # If not specified, defaults to "agent". # # The project root will be added to Python sys.path, allowing imports # to be specified relative to the root. # @!attribute [rw] entrypoint_object # @return [::String] # Optional. The name of the callable object within the # `entrypoint_module` to use as the application If not specified, # defaults to "root_agent". # @!attribute [rw] requirements_file # @return [::String] # Optional. The path to the requirements file, relative to the source # root. If not specified, defaults to "requirements.txt". class PythonSpec include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |