Class: Google::Cloud::AIPlatform::V1::Session
- Inherits:
-
Object
- Object
- Google::Cloud::AIPlatform::V1::Session
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/aiplatform/v1/session.rb
Overview
A session contains a set of actions between users and Vertex agents.
Defined Under Namespace
Classes: LabelsEntry
Instance Attribute Summary collapse
-
#create_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#display_name ⇒ ::String
Optional.
-
#expire_time ⇒ ::Google::Protobuf::Timestamp
Optional.
-
#labels ⇒ ::Google::Protobuf::Map{::String => ::String}
The labels with user-defined metadata to organize your Sessions.
-
#name ⇒ ::String
Identifier.
-
#session_state ⇒ ::Google::Protobuf::Struct
Optional.
-
#ttl ⇒ ::Google::Protobuf::Duration
Optional.
-
#update_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#user_id ⇒ ::String
Required.
Instance Attribute Details
#create_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. Timestamp when the session was created.
68 69 70 71 72 73 74 75 76 77 78 79 80 |
# File 'proto_docs/google/cloud/aiplatform/v1/session.rb', line 68 class Session include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#display_name ⇒ ::String
Returns Optional. The display name of the session.
68 69 70 71 72 73 74 75 76 77 78 79 80 |
# File 'proto_docs/google/cloud/aiplatform/v1/session.rb', line 68 class Session include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#expire_time ⇒ ::Google::Protobuf::Timestamp
Returns Optional. Timestamp of when this session is considered expired. This is always provided on output, regardless of what was sent on input. The minimum value is 24 hours from the time of creation.
Note: The following fields are mutually exclusive: expire_time, ttl. If a field in that set is populated, all other fields in the set will automatically be cleared.
68 69 70 71 72 73 74 75 76 77 78 79 80 |
# File 'proto_docs/google/cloud/aiplatform/v1/session.rb', line 68 class Session include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#labels ⇒ ::Google::Protobuf::Map{::String => ::String}
Returns The labels with user-defined metadata to organize your Sessions.
Label keys and values can be no longer than 64 characters (Unicode codepoints), can only contain lowercase letters, numeric characters, underscores and dashes. International characters are allowed.
See https://goo.gl/xmQnxf for more information and examples of labels.
68 69 70 71 72 73 74 75 76 77 78 79 80 |
# File 'proto_docs/google/cloud/aiplatform/v1/session.rb', line 68 class Session include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#name ⇒ ::String
Returns Identifier. The resource name of the session. Format: 'projects/{project}/locations/{location}/reasoningEngines/{reasoning_engine}/sessions/{session}'.
68 69 70 71 72 73 74 75 76 77 78 79 80 |
# File 'proto_docs/google/cloud/aiplatform/v1/session.rb', line 68 class Session include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#session_state ⇒ ::Google::Protobuf::Struct
Returns Optional. Session specific memory which stores key conversation points.
68 69 70 71 72 73 74 75 76 77 78 79 80 |
# File 'proto_docs/google/cloud/aiplatform/v1/session.rb', line 68 class Session include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#ttl ⇒ ::Google::Protobuf::Duration
Returns Optional. Input only. The TTL for this session. The minimum value is 24 hours.
Note: The following fields are mutually exclusive: ttl, expire_time. If a field in that set is populated, all other fields in the set will automatically be cleared.
68 69 70 71 72 73 74 75 76 77 78 79 80 |
# File 'proto_docs/google/cloud/aiplatform/v1/session.rb', line 68 class Session include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#update_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. Timestamp when the session was updated.
68 69 70 71 72 73 74 75 76 77 78 79 80 |
# File 'proto_docs/google/cloud/aiplatform/v1/session.rb', line 68 class Session include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#user_id ⇒ ::String
Returns Required. Immutable. String id provided by the user.
68 69 70 71 72 73 74 75 76 77 78 79 80 |
# File 'proto_docs/google/cloud/aiplatform/v1/session.rb', line 68 class Session include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |