Class: Google::Cloud::AIPlatform::V1::SlackSource
- Inherits:
-
Object
- Object
- Google::Cloud::AIPlatform::V1::SlackSource
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/aiplatform/v1/io.rb
Overview
The Slack source for the ImportRagFilesRequest.
Defined Under Namespace
Classes: SlackChannels
Instance Attribute Summary collapse
Instance Attribute Details
#channels ⇒ ::Array<::Google::Cloud::AIPlatform::V1::SlackSource::SlackChannels>
Returns Required. The Slack channels.
200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 |
# File 'proto_docs/google/cloud/aiplatform/v1/io.rb', line 200 class SlackSource include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # SlackChannels contains the Slack channels and corresponding access token. # @!attribute [rw] channels # @return [::Array<::Google::Cloud::AIPlatform::V1::SlackSource::SlackChannels::SlackChannel>] # Required. The Slack channel IDs. # @!attribute [rw] api_key_config # @return [::Google::Cloud::AIPlatform::V1::ApiAuth::ApiKeyConfig] # Required. The SecretManager secret version resource name (e.g. # projects/\\{project}/secrets/\\{secret}/versions/\\{version}) storing the # Slack channel access token that has access to the slack channel IDs. # See: https://api.slack.com/tutorials/tracks/getting-a-token. class SlackChannels include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # SlackChannel contains the Slack channel ID and the time range to import. # @!attribute [rw] channel_id # @return [::String] # Required. The Slack channel ID. # @!attribute [rw] start_time # @return [::Google::Protobuf::Timestamp] # Optional. The starting timestamp for messages to import. # @!attribute [rw] end_time # @return [::Google::Protobuf::Timestamp] # Optional. The ending timestamp for messages to import. class SlackChannel include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end end |