Class: Google::Cloud::AIPlatform::V1::Tool::ParallelAiSearch
- Inherits:
-
Object
- Object
- Google::Cloud::AIPlatform::V1::Tool::ParallelAiSearch
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/aiplatform/v1/tool.rb
Overview
ParallelAiSearch tool type. A tool that uses the Parallel.ai search engine for grounding.
Instance Attribute Summary collapse
-
#api_key ⇒ ::String
Optional.
-
#custom_configs ⇒ ::Google::Protobuf::Struct
Optional.
Instance Attribute Details
#api_key ⇒ ::String
Returns Optional. The API key for ParallelAiSearch. If an API key is not provided, the system will attempt to verify access by checking for an active Parallel.ai subscription through the Google Cloud Marketplace. See https://docs.parallel.ai/search/search-quickstart for more details.
129 130 131 132 |
# File 'proto_docs/google/cloud/aiplatform/v1/tool.rb', line 129 class ParallelAiSearch include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#custom_configs ⇒ ::Google::Protobuf::Struct
Returns Optional. Custom configs for ParallelAiSearch.
This field can be used to pass any parameter from the Parallel.ai
Search API.
See the Parallel.ai documentation for the full list of available
parameters and their usage:
https://docs.parallel.ai/api-reference/search-beta/search
Currently only source_policy, excerpts, max_results, mode,
fetch_policy can be set via this field. For example:
{
"source_policy": {
"include_domains": ["google.com", "wikipedia.org"],
"exclude_domains": ["example.com"]
},
"fetch_policy": {
"max_age_seconds": 3600
}
}.
129 130 131 132 |
# File 'proto_docs/google/cloud/aiplatform/v1/tool.rb', line 129 class ParallelAiSearch include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |