Class: Google::Cloud::AIPlatform::V1::VertexAISearch
- Inherits:
-
Object
- Object
- Google::Cloud::AIPlatform::V1::VertexAISearch
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/aiplatform/v1/tool.rb
Overview
Retrieve from Vertex AI Search datastore or engine for grounding. datastore and engine are mutually exclusive. See https://cloud.google.com/products/agent-builder
Defined Under Namespace
Classes: DataStoreSpec
Instance Attribute Summary collapse
-
#data_store_specs ⇒ ::Array<::Google::Cloud::AIPlatform::V1::VertexAISearch::DataStoreSpec>
Specifications that define the specific DataStores to be searched, along with configurations for those data stores.
-
#datastore ⇒ ::String
Optional.
-
#engine ⇒ ::String
Optional.
-
#filter ⇒ ::String
Optional.
-
#max_results ⇒ ::Integer
Optional.
Instance Attribute Details
#data_store_specs ⇒ ::Array<::Google::Cloud::AIPlatform::V1::VertexAISearch::DataStoreSpec>
Returns Specifications that define the specific DataStores to be searched, along with configurations for those data stores. This is only considered for Engines with multiple data stores. It should only be set if engine is used.
529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 |
# File 'proto_docs/google/cloud/aiplatform/v1/tool.rb', line 529 class VertexAISearch include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Define data stores within engine to filter on in a search call and # configurations for those data stores. For more information, see # https://cloud.google.com/generative-ai-app-builder/docs/reference/rpc/google.cloud.discoveryengine.v1#datastorespec # @!attribute [rw] data_store # @return [::String] # Full resource name of DataStore, such as # Format: # `projects/{project}/locations/{location}/collections/{collection}/dataStores/{dataStore}` # @!attribute [rw] filter # @return [::String] # Optional. Filter specification to filter documents in the data store # specified by data_store field. For more information on filtering, see # [Filtering](https://cloud.google.com/generative-ai-app-builder/docs/filter-search-metadata) class DataStoreSpec include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#datastore ⇒ ::String
Returns Optional. Fully-qualified Vertex AI Search data store resource ID.
Format:
projects/{project}/locations/{location}/collections/{collection}/dataStores/{dataStore}.
529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 |
# File 'proto_docs/google/cloud/aiplatform/v1/tool.rb', line 529 class VertexAISearch include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Define data stores within engine to filter on in a search call and # configurations for those data stores. For more information, see # https://cloud.google.com/generative-ai-app-builder/docs/reference/rpc/google.cloud.discoveryengine.v1#datastorespec # @!attribute [rw] data_store # @return [::String] # Full resource name of DataStore, such as # Format: # `projects/{project}/locations/{location}/collections/{collection}/dataStores/{dataStore}` # @!attribute [rw] filter # @return [::String] # Optional. Filter specification to filter documents in the data store # specified by data_store field. For more information on filtering, see # [Filtering](https://cloud.google.com/generative-ai-app-builder/docs/filter-search-metadata) class DataStoreSpec include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#engine ⇒ ::String
Returns Optional. Fully-qualified Vertex AI Search engine resource ID.
Format:
projects/{project}/locations/{location}/collections/{collection}/engines/{engine}.
529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 |
# File 'proto_docs/google/cloud/aiplatform/v1/tool.rb', line 529 class VertexAISearch include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Define data stores within engine to filter on in a search call and # configurations for those data stores. For more information, see # https://cloud.google.com/generative-ai-app-builder/docs/reference/rpc/google.cloud.discoveryengine.v1#datastorespec # @!attribute [rw] data_store # @return [::String] # Full resource name of DataStore, such as # Format: # `projects/{project}/locations/{location}/collections/{collection}/dataStores/{dataStore}` # @!attribute [rw] filter # @return [::String] # Optional. Filter specification to filter documents in the data store # specified by data_store field. For more information on filtering, see # [Filtering](https://cloud.google.com/generative-ai-app-builder/docs/filter-search-metadata) class DataStoreSpec include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#filter ⇒ ::String
Returns Optional. Filter strings to be passed to the search API.
529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 |
# File 'proto_docs/google/cloud/aiplatform/v1/tool.rb', line 529 class VertexAISearch include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Define data stores within engine to filter on in a search call and # configurations for those data stores. For more information, see # https://cloud.google.com/generative-ai-app-builder/docs/reference/rpc/google.cloud.discoveryengine.v1#datastorespec # @!attribute [rw] data_store # @return [::String] # Full resource name of DataStore, such as # Format: # `projects/{project}/locations/{location}/collections/{collection}/dataStores/{dataStore}` # @!attribute [rw] filter # @return [::String] # Optional. Filter specification to filter documents in the data store # specified by data_store field. For more information on filtering, see # [Filtering](https://cloud.google.com/generative-ai-app-builder/docs/filter-search-metadata) class DataStoreSpec include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#max_results ⇒ ::Integer
Returns Optional. Number of search results to return per query. The default value is 10. The maximumm allowed value is 10.
529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 |
# File 'proto_docs/google/cloud/aiplatform/v1/tool.rb', line 529 class VertexAISearch include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Define data stores within engine to filter on in a search call and # configurations for those data stores. For more information, see # https://cloud.google.com/generative-ai-app-builder/docs/reference/rpc/google.cloud.discoveryengine.v1#datastorespec # @!attribute [rw] data_store # @return [::String] # Full resource name of DataStore, such as # Format: # `projects/{project}/locations/{location}/collections/{collection}/dataStores/{dataStore}` # @!attribute [rw] filter # @return [::String] # Optional. Filter specification to filter documents in the data store # specified by data_store field. For more information on filtering, see # [Filtering](https://cloud.google.com/generative-ai-app-builder/docs/filter-search-metadata) class DataStoreSpec include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |